// Code generated by "enumer -transform snake_upper -type Error -trimprefix Err -output error_enum.go"; DO NOT EDIT.

package proto

import (
	"fmt"
	"strings"
)

const _ErrorName = " "
const _ErrorLowerName = " "

var _ErrorMap = map[Error]string{
	1:    _ErrorName[0:18],
	2:    _ErrorName[18:39],
	3:    _ErrorName[39:61],
	4:    _ErrorName[61:81],
	6:    _ErrorName[81:98],
	7:    _ErrorName[98:125],
	8:    _ErrorName[125:143],
	9:    _ErrorName[143:172],
	10:   _ErrorName[172:197],
	11:   _ErrorName[197:218],
	12:   _ErrorName[218:240],
	13:   _ErrorName[240:278],
	15:   _ErrorName[278:294],
	16:   _ErrorName[294:317],
	17:   _ErrorName[317:357],
	18:   _ErrorName[357:399],
	19:   _ErrorName[399:432],
	20:   _ErrorName[432:462],
	21:   _ErrorName[462:507],
	22:   _ErrorName[507:554],
	23:   _ErrorName[554:578],
	24:   _ErrorName[578:601],
	25:   _ErrorName[601:629],
	26:   _ErrorName[629:655],
	27:   _ErrorName[655:690],
	28:   _ErrorName[690:725],
	29:   _ErrorName[725:745],
	30:   _ErrorName[745:781],
	31:   _ErrorName[781:809],
	32:   _ErrorName[809:834],
	33:   _ErrorName[834:854],
	34:   _ErrorName[854:885],
	35:   _ErrorName[885:915],
	36:   _ErrorName[915:928],
	37:   _ErrorName[928:950],
	38:   _ErrorName[950:967],
	39:   _ErrorName[967:992],
	40:   _ErrorName[992:1013],
	41:   _ErrorName[1013:1034],
	42:   _ErrorName[1034:1066],
	43:   _ErrorName[1066:1090],
	44:   _ErrorName[1090:1104],
	45:   _ErrorName[1104:1136],
	46:   _ErrorName[1136:1152],
	47:   _ErrorName[1152:1170],
	48:   _ErrorName[1170:1185],
	49:   _ErrorName[1185:1198],
	50:   _ErrorName[1198:1210],
	51:   _ErrorName[1210:1239],
	52:   _ErrorName[1239:1268],
	53:   _ErrorName[1268:1281],
	54:   _ErrorName[1281:1312],
	55:   _ErrorName[1312:1338],
	56:   _ErrorName[1338:1353],
	57:   _ErrorName[1353:1373],
	58:   _ErrorName[1373:1402],
	59:   _ErrorName[1402:1435],
	60:   _ErrorName[1435:1448],
	61:   _ErrorName[1448:1475],
	62:   _ErrorName[1475:1487],
	63:   _ErrorName[1487:1513],
	64:   _ErrorName[1513:1553],
	65:   _ErrorName[1553:1592],
	66:   _ErrorName[1592:1604],
	67:   _ErrorName[1604:1630],
	68:   _ErrorName[1630:1654],
	69:   _ErrorName[1654:1675],
	70:   _ErrorName[1675:1694],
	71:   _ErrorName[1694:1726],
	72:   _ErrorName[1726:1745],
	73:   _ErrorName[1745:1759],
	74:   _ErrorName[1759:1791],
	75:   _ErrorName[1791:1822],
	76:   _ErrorName[1822:1838],
	77:   _ErrorName[1838:1855],
	78:   _ErrorName[1855:1876],
	79:   _ErrorName[1876:1895],
	80:   _ErrorName[1895:1910],
	81:   _ErrorName[1910:1926],
	82:   _ErrorName[1926:1949],
	83:   _ErrorName[1949:1971],
	84:   _ErrorName[1971:1995],
	85:   _ErrorName[1995:2027],
	86:   _ErrorName[2027:2063],
	87:   _ErrorName[2063:2087],
	88:   _ErrorName[2087:2107],
	89:   _ErrorName[2107:2133],
	90:   _ErrorName[2133:2161],
	91:   _ErrorName[2161:2198],
	92:   _ErrorName[2198:2215],
	93:   _ErrorName[2215:2246],
	94:   _ErrorName[2246:2293],
	95:   _ErrorName[2293:2316],
	96:   _ErrorName[2316:2338],
	97:   _ErrorName[2338:2377],
	98:   _ErrorName[2377:2418],
	99:   _ErrorName[2418:2444],
	100:  _ErrorName[2444:2470],
	101:  _ErrorName[2470:2499],
	102:  _ErrorName[2499:2528],
	103:  _ErrorName[2528:2560],
	104:  _ErrorName[2560:2581],
	105:  _ErrorName[2581:2600],
	106:  _ErrorName[2600:2621],
	107:  _ErrorName[2621:2638],
	108:  _ErrorName[2638:2655],
	109:  _ErrorName[2655:2674],
	110:  _ErrorName[2674:2695],
	111:  _ErrorName[2695:2719],
	112:  _ErrorName[2719:2741],
	113:  _ErrorName[2741:2760],
	114:  _ErrorName[2760:2780],
	115:  _ErrorName[2780:2795],
	116:  _ErrorName[2795:2820],
	117:  _ErrorName[2820:2834],
	119:  _ErrorName[2834:2849],
	120:  _ErrorName[2849:2897],
	121:  _ErrorName[2897:2918],
	122:  _ErrorName[2918:2938],
	123:  _ErrorName[2938:2962],
	124:  _ErrorName[2962:2986],
	125:  _ErrorName[2986:3021],
	126:  _ErrorName[3021:3043],
	127:  _ErrorName[3043:3056],
	128:  _ErrorName[3056:3076],
	129:  _ErrorName[3076:3095],
	130:  _ErrorName[3095:3122],
	131:  _ErrorName[3122:3143],
	132:  _ErrorName[3143:3176],
	133:  _ErrorName[3176:3218],
	134:  _ErrorName[3218:3268],
	135:  _ErrorName[3268:3293],
	137:  _ErrorName[3293:3318],
	138:  _ErrorName[3318:3345],
	139:  _ErrorName[3345:3366],
	140:  _ErrorName[3366:3399],
	141:  _ErrorName[3399:3421],
	142:  _ErrorName[3421:3435],
	143:  _ErrorName[3435:3459],
	144:  _ErrorName[3459:3494],
	145:  _ErrorName[3494:3515],
	146:  _ErrorName[3515:3546],
	147:  _ErrorName[3546:3586],
	148:  _ErrorName[3586:3626],
	149:  _ErrorName[3626:3661],
	150:  _ErrorName[3661:3681],
	151:  _ErrorName[3681:3727],
	152:  _ErrorName[3727:3755],
	153:  _ErrorName[3755:3771],
	154:  _ErrorName[3771:3804],
	155:  _ErrorName[3804:3820],
	156:  _ErrorName[3820:3847],
	157:  _ErrorName[3847:3868],
	158:  _ErrorName[3868:3881],
	159:  _ErrorName[3881:3897],
	160:  _ErrorName[3897:3905],
	161:  _ErrorName[3905:3921],
	162:  _ErrorName[3921:3940],
	163:  _ErrorName[3940:3957],
	164:  _ErrorName[3957:3965],
	165:  _ErrorName[3965:3991],
	166:  _ErrorName[3991:4027],
	167:  _ErrorName[4027:4039],
	168:  _ErrorName[4039:4050],
	169:  _ErrorName[4050:4067],
	170:  _ErrorName[4067:4074],
	171:  _ErrorName[4074:4105],
	172:  _ErrorName[4105:4128],
	173:  _ErrorName[4128:4150],
	174:  _ErrorName[4150:4164],
	176:  _ErrorName[4164:4179],
	177:  _ErrorName[4179:4199],
	178:  _ErrorName[4199:4230],
	179:  _ErrorName[4230:4260],
	180:  _ErrorName[4260:4279],
	181:  _ErrorName[4279:4292],
	182:  _ErrorName[4292:4308],
	183:  _ErrorName[4308:4329],
	184:  _ErrorName[4329:4348],
	185:  _ErrorName[4348:4377],
	186:  _ErrorName[4377:4405],
	187:  _ErrorName[4405:4432],
	188:  _ErrorName[4432:4446],
	189:  _ErrorName[4446:4480],
	190:  _ErrorName[4480:4506],
	191:  _ErrorName[4506:4529],
	192:  _ErrorName[4529:4541],
	193:  _ErrorName[4541:4555],
	194:  _ErrorName[4555:4572],
	195:  _ErrorName[4572:4594],
	196:  _ErrorName[4594:4622],
	197:  _ErrorName[4622:4648],
	198:  _ErrorName[4648:4657],
	199:  _ErrorName[4657:4670],
	200:  _ErrorName[4670:4693],
	201:  _ErrorName[4693:4706],
	202:  _ErrorName[4706:4735],
	203:  _ErrorName[4735:4753],
	204:  _ErrorName[4753:4765],
	205:  _ErrorName[4765:4785],
	206:  _ErrorName[4785:4799],
	207:  _ErrorName[4799:4819],
	208:  _ErrorName[4819:4837],
	209:  _ErrorName[4837:4851],
	210:  _ErrorName[4851:4864],
	211:  _ErrorName[4864:4875],
	212:  _ErrorName[4875:4897],
	213:  _ErrorName[4897:4916],
	214:  _ErrorName[4916:4930],
	215:  _ErrorName[4930:4946],
	216:  _ErrorName[4946:4983],
	217:  _ErrorName[4983:5017],
	218:  _ErrorName[5017:5033],
	219:  _ErrorName[5033:5051],
	220:  _ErrorName[5051:5084],
	221:  _ErrorName[5084:5115],
	222:  _ErrorName[5115:5148],
	223:  _ErrorName[5148:5172],
	224:  _ErrorName[5172:5197],
	225:  _ErrorName[5197:5209],
	226:  _ErrorName[5209:5229],
	227:  _ErrorName[5229:5257],
	228:  _ErrorName[5257:5286],
	229:  _ErrorName[5286:5304],
	230:  _ErrorName[5304:5332],
	231:  _ErrorName[5332:5362],
	232:  _ErrorName[5362:5379],
	233:  _ErrorName[5379:5397],
	234:  _ErrorName[5397:5416],
	235:  _ErrorName[5416:5435],
	236:  _ErrorName[5435:5442],
	237:  _ErrorName[5442:5463],
	238:  _ErrorName[5463:5485],
	239:  _ErrorName[5485:5498],
	240:  _ErrorName[5498:5511],
	241:  _ErrorName[5511:5532],
	242:  _ErrorName[5532:5550],
	243:  _ErrorName[5550:5566],
	244:  _ErrorName[5566:5592],
	246:  _ErrorName[5592:5606],
	247:  _ErrorName[5606:5620],
	248:  _ErrorName[5620:5643],
	250:  _ErrorName[5643:5667],
	251:  _ErrorName[5667:5682],
	252:  _ErrorName[5682:5696],
	253:  _ErrorName[5696:5720],
	254:  _ErrorName[5720:5738],
	255:  _ErrorName[5738:5769],
	256:  _ErrorName[5769:5793],
	257:  _ErrorName[5793:5815],
	258:  _ErrorName[5815:5851],
	260:  _ErrorName[5851:5881],
	261:  _ErrorName[5881:5905],
	262:  _ErrorName[5905:5918],
	263:  _ErrorName[5918:5937],
	264:  _ErrorName[5937:5962],
	265:  _ErrorName[5962:5982],
	266:  _ErrorName[5982:6012],
	267:  _ErrorName[6012:6052],
	268:  _ErrorName[6052:6063],
	269:  _ErrorName[6063:6076],
	270:  _ErrorName[6076:6091],
	271:  _ErrorName[6091:6108],
	272:  _ErrorName[6108:6124],
	273:  _ErrorName[6124:6143],
	274:  _ErrorName[6143:6157],
	275:  _ErrorName[6157:6172],
	277:  _ErrorName[6172:6186],
	278:  _ErrorName[6186:6201],
	279:  _ErrorName[6201:6228],
	280:  _ErrorName[6228:6245],
	281:  _ErrorName[6245:6264],
	282:  _ErrorName[6264:6279],
	283:  _ErrorName[6279:6311],
	284:  _ErrorName[6311:6332],
	285:  _ErrorName[6332:6353],
	286:  _ErrorName[6353:6390],
	287:  _ErrorName[6390:6412],
	288:  _ErrorName[6412:6447],
	289:  _ErrorName[6447:6471],
	290:  _ErrorName[6471:6485],
	291:  _ErrorName[6485:6507],
	292:  _ErrorName[6507:6525],
	293:  _ErrorName[6525:6552],
	294:  _ErrorName[6552:6572],
	295:  _ErrorName[6572:6591],
	296:  _ErrorName[6591:6612],
	297:  _ErrorName[6612:6636],
	298:  _ErrorName[6636:6647],
	299:  _ErrorName[6647:6658],
	300:  _ErrorName[6658:6670],
	301:  _ErrorName[6670:6697],
	302:  _ErrorName[6697:6726],
	303:  _ErrorName[6726:6739],
	304:  _ErrorName[6739:6753],
	305:  _ErrorName[6753:6774],
	306:  _ErrorName[6774:6792],
	307:  _ErrorName[6792:6806],
	308:  _ErrorName[6806:6834],
	309:  _ErrorName[6834:6865],
	317:  _ErrorName[6865:6885],
	318:  _ErrorName[6885:6909],
	319:  _ErrorName[6909:6933],
	321:  _ErrorName[6933:6967],
	335:  _ErrorName[6967:6982],
	336:  _ErrorName[6982:7005],
	337:  _ErrorName[7005:7024],
	341:  _ErrorName[7024:7034],
	342:  _ErrorName[7034:7051],
	344:  _ErrorName[7051:7070],
	345:  _ErrorName[7070:7092],
	346:  _ErrorName[7092:7114],
	347:  _ErrorName[7114:7132],
	349:  _ErrorName[7132:7169],
	350:  _ErrorName[7169:7195],
	351:  _ErrorName[7195:7215],
	352:  _ErrorName[7215:7236],
	353:  _ErrorName[7236:7280],
	354:  _ErrorName[7280:7299],
	355:  _ErrorName[7299:7318],
	356:  _ErrorName[7318:7328],
	357:  _ErrorName[7328:7352],
	358:  _ErrorName[7352:7376],
	359:  _ErrorName[7376:7414],
	360:  _ErrorName[7414:7445],
	361:  _ErrorName[7445:7471],
	362:  _ErrorName[7471:7504],
	363:  _ErrorName[7504:7527],
	364:  _ErrorName[7527:7559],
	365:  _ErrorName[7559:7579],
	366:  _ErrorName[7579:7619],
	367:  _ErrorName[7619:7635],
	368:  _ErrorName[7635:7643],
	369:  _ErrorName[7643:7665],
	370:  _ErrorName[7665:7699],
	371:  _ErrorName[7699:7730],
	372:  _ErrorName[7730:7747],
	373:  _ErrorName[7747:7764],
	374:  _ErrorName[7764:7787],
	375:  _ErrorName[7787:7800],
	376:  _ErrorName[7800:7817],
	377:  _ErrorName[7817:7845],
	378:  _ErrorName[7845:7876],
	379:  _ErrorName[7876:7914],
	380:  _ErrorName[7914:7925],
	381:  _ErrorName[7925:7945],
	382:  _ErrorName[7945:7971],
	383:  _ErrorName[7971:7998],
	384:  _ErrorName[7998:8024],
	385:  _ErrorName[8024:8049],
	386:  _ErrorName[8049:8063],
	387:  _ErrorName[8063:8095],
	388:  _ErrorName[8095:8117],
	389:  _ErrorName[8117:8140],
	390:  _ErrorName[8140:8169],
	391:  _ErrorName[8169:8191],
	392:  _ErrorName[8191:8210],
	393:  _ErrorName[8210:8227],
	394:  _ErrorName[8227:8246],
	395:  _ErrorName[8246:8281],
	396:  _ErrorName[8281:8303],
	397:  _ErrorName[8303:8346],
	398:  _ErrorName[8346:8370],
	399:  _ErrorName[8370:8403],
	400:  _ErrorName[8403:8414],
	401:  _ErrorName[8414:8450],
	402:  _ErrorName[8450:8464],
	403:  _ErrorName[8464:8490],
	404:  _ErrorName[8490:8516],
	406:  _ErrorName[8516:8538],
	407:  _ErrorName[8538:8554],
	408:  _ErrorName[8554:8575],
	410:  _ErrorName[8575:8608],
	411:  _ErrorName[8608:8621],
	412:  _ErrorName[8621:8634],
	413:  _ErrorName[8634:8659],
	415:  _ErrorName[8659:8676],
	416:  _ErrorName[8676:8698],
	417:  _ErrorName[8698:8717],
	418:  _ErrorName[8717:8729],
	419:  _ErrorName[8729:8759],
	420:  _ErrorName[8759:8779],
	421:  _ErrorName[8779:8816],
	422:  _ErrorName[8816:8838],
	423:  _ErrorName[8838:8857],
	424:  _ErrorName[8857:8868],
	425:  _ErrorName[8868:8880],
	427:  _ErrorName[8880:8901],
	429:  _ErrorName[8901:8919],
	430:  _ErrorName[8919:8957],
	431:  _ErrorName[8957:8986],
	432:  _ErrorName[8986:8999],
	433:  _ErrorName[8999:9022],
	434:  _ErrorName[9022:9050],
	435:  _ErrorName[9050:9097],
	436:  _ErrorName[9097:9114],
	437:  _ErrorName[9114:9141],
	438:  _ErrorName[9141:9169],
	439:  _ErrorName[9169:9189],
	440:  _ErrorName[9189:9213],
	441:  _ErrorName[9213:9250],
	442:  _ErrorName[9250:9282],
	443:  _ErrorName[9282:9322],
	444:  _ErrorName[9322:9345],
	445:  _ErrorName[9345:9360],
	446:  _ErrorName[9360:9380],
	447:  _ErrorName[9380:9406],
	448:  _ErrorName[9406:9424],
	449:  _ErrorName[9424:9443],
	450:  _ErrorName[9443:9461],
	451:  _ErrorName[9461:9473],
	452:  _ErrorName[9473:9501],
	453:  _ErrorName[9501:9539],
	454:  _ErrorName[9539:9552],
	455:  _ErrorName[9552:9587],
	456:  _ErrorName[9587:9610],
	457:  _ErrorName[9610:9629],
	458:  _ErrorName[9629:9642],
	459:  _ErrorName[9642:9668],
	460:  _ErrorName[9668:9687],
	461:  _ErrorName[9687:9710],
	463:  _ErrorName[9710:9722],
	464:  _ErrorName[9722:9738],
	465:  _ErrorName[9738:9756],
	466:  _ErrorName[9756:9769],
	467:  _ErrorName[9769:9786],
	468:  _ErrorName[9786:9805],
	469:  _ErrorName[9805:9824],
	471:  _ErrorName[9824:9845],
	472:  _ErrorName[9845:9861],
	473:  _ErrorName[9861:9877],
	474:  _ErrorName[9877:9900],
	475:  _ErrorName[9900:9928],
	476:  _ErrorName[9928:9954],
	477:  _ErrorName[9954:9976],
	478:  _ErrorName[9976:9990],
	479:  _ErrorName[9990:10002],
	480:  _ErrorName[10002:10018],
	481:  _ErrorName[10018:10036],
	482:  _ErrorName[10036:10060],
	483:  _ErrorName[10060:10078],
	484:  _ErrorName[10078:10098],
	487:  _ErrorName[10098:10132],
	489:  _ErrorName[10132:10163],
	490:  _ErrorName[10163:10185],
	491:  _ErrorName[10185:10201],
	492:  _ErrorName[10201:10224],
	493:  _ErrorName[10224:10252],
	495:  _ErrorName[10252:10275],
	496:  _ErrorName[10275:10300],
	497:  _ErrorName[10300:10313],
	498:  _ErrorName[10313:10348],
	499:  _ErrorName[10348:10356],
	500:  _ErrorName[10356:10380],
	501:  _ErrorName[10380:10402],
	502:  _ErrorName[10402:10417],
	503:  _ErrorName[10417:10441],
	504:  _ErrorName[10441:10460],
	507:  _ErrorName[10460:10488],
	508:  _ErrorName[10488:10507],
	509:  _ErrorName[10507:10520],
	510:  _ErrorName[10520:10548],
	511:  _ErrorName[10548:10560],
	512:  _ErrorName[10560:10580],
	513:  _ErrorName[10580:10597],
	514:  _ErrorName[10597:10635],
	515:  _ErrorName[10635:10669],
	516:  _ErrorName[10669:10690],
	517:  _ErrorName[10690:10709],
	518:  _ErrorName[10709:10729],
	519:  _ErrorName[10729:10754],
	520:  _ErrorName[10754:10787],
	521:  _ErrorName[10787:10805],
	523:  _ErrorName[10805:10823],
	524:  _ErrorName[10823:10851],
	525:  _ErrorName[10851:10871],
	527:  _ErrorName[10871:10906],
	528:  _ErrorName[10906:10930],
	529:  _ErrorName[10930:10942],
	530:  _ErrorName[10942:10965],
	531:  _ErrorName[10965:10977],
	532:  _ErrorName[10977:10987],
	535:  _ErrorName[10987:11004],
	536:  _ErrorName[11004:11034],
	537:  _ErrorName[11034:11056],
	538:  _ErrorName[11056:11074],
	539:  _ErrorName[11074:11103],
	540:  _ErrorName[11103:11135],
	541:  _ErrorName[11135:11171],
	542:  _ErrorName[11171:11202],
	543:  _ErrorName[11202:11239],
	544:  _ErrorName[11239:11260],
	545:  _ErrorName[11260:11283],
	546:  _ErrorName[11283:11299],
	547:  _ErrorName[11299:11316],
	548:  _ErrorName[11316:11330],
	549:  _ErrorName[11330:11361],
	552:  _ErrorName[11361:11383],
	553:  _ErrorName[11383:11409],
	554:  _ErrorName[11409:11435],
	555:  _ErrorName[11435:11448],
	556:  _ErrorName[11448:11476],
	557:  _ErrorName[11476:11489],
	558:  _ErrorName[11489:11513],
	559:  _ErrorName[11513:11536],
	560:  _ErrorName[11536:11555],
	561:  _ErrorName[11555:11574],
	562:  _ErrorName[11574:11592],
	563:  _ErrorName[11592:11617],
	564:  _ErrorName[11617:11648],
	565:  _ErrorName[11648:11667],
	566:  _ErrorName[11667:11679],
	567:  _ErrorName[11679:11700],
	568:  _ErrorName[11700:11710],
	569:  _ErrorName[11710:11760],
	570:  _ErrorName[11760:11802],
	571:  _ErrorName[11802:11829],
	572:  _ErrorName[11829:11862],
	573:  _ErrorName[11862:11873],
	574:  _ErrorName[11873:11907],
	575:  _ErrorName[11907:11923],
	576:  _ErrorName[11923:11937],
	577:  _ErrorName[11937:11953],
	578:  _ErrorName[11953:11990],
	579:  _ErrorName[11990:12009],
	580:  _ErrorName[12009:12033],
	581:  _ErrorName[12033:12060],
	582:  _ErrorName[12060:12087],
	583:  _ErrorName[12087:12105],
	584:  _ErrorName[12105:12124],
	585:  _ErrorName[12124:12141],
	586:  _ErrorName[12141:12159],
	587:  _ErrorName[12159:12190],
	588:  _ErrorName[12190:12219],
	589:  _ErrorName[12219:12249],
	590:  _ErrorName[12249:12263],
	591:  _ErrorName[12263:12282],
	592:  _ErrorName[12282:12303],
	593:  _ErrorName[12303:12330],
	594:  _ErrorName[12330:12357],
	595:  _ErrorName[12357:12384],
	596:  _ErrorName[12384:12430],
	597:  _ErrorName[12430:12448],
	598:  _ErrorName[12448:12469],
	599:  _ErrorName[12469:12485],
	600:  _ErrorName[12485:12513],
	601:  _ErrorName[12513:12527],
	602:  _ErrorName[12527:12541],
	603:  _ErrorName[12541:12558],
	604:  _ErrorName[12558:12585],
	605:  _ErrorName[12585:12607],
	606:  _ErrorName[12607:12622],
	607:  _ErrorName[12622:12645],
	608:  _ErrorName[12645:12665],
	609:  _ErrorName[12665:12688],
	610:  _ErrorName[12688:12708],
	611:  _ErrorName[12708:12740],
	614:  _ErrorName[12740:12769],
	615:  _ErrorName[12769:12782],
	616:  _ErrorName[12782:12801],
	617:  _ErrorName[12801:12819],
	618:  _ErrorName[12819:12837],
	619:  _ErrorName[12837:12874],
	620:  _ErrorName[12874:12891],
	621:  _ErrorName[12891:12914],
	622:  _ErrorName[12914:12944],
	623:  _ErrorName[12944:12963],
	624:  _ErrorName[12963:12976],
	625:  _ErrorName[12976:12990],
	626:  _ErrorName[12990:13015],
	627:  _ErrorName[13015:13038],
	628:  _ErrorName[13038:13067],
	629:  _ErrorName[13067:13093],
	630:  _ErrorName[13093:13115],
	631:  _ErrorName[13115:13132],
	632:  _ErrorName[13132:13166],
	633:  _ErrorName[13166:13203],
	634:  _ErrorName[13203:13216],
	635:  _ErrorName[13216:13227],
	636:  _ErrorName[13227:13257],
	637:  _ErrorName[13257:13279],
	638:  _ErrorName[13279:13303],
	639:  _ErrorName[13303:13325],
	640:  _ErrorName[13325:13341],
	641:  _ErrorName[13341:13362],
	642:  _ErrorName[13362:13381],
	643:  _ErrorName[13381:13402],
	645:  _ErrorName[13402:13433],
	647:  _ErrorName[13433:13452],
	648:  _ErrorName[13452:13479],
	649:  _ErrorName[13479:13498],
	650:  _ErrorName[13498:13517],
	651:  _ErrorName[13517:13536],
	652:  _ErrorName[13536:13567],
	653:  _ErrorName[13567:13595],
	654:  _ErrorName[13595:13616],
	655:  _ErrorName[13616:13648],
	659:  _ErrorName[13648:13677],
	660:  _ErrorName[13677:13687],
	661:  _ErrorName[13687:13705],
	662:  _ErrorName[13705:13722],
	663:  _ErrorName[13722:13754],
	664:  _ErrorName[13754:13788],
	665:  _ErrorName[13788:13807],
	667:  _ErrorName[13807:13822],
	668:  _ErrorName[13822:13835],
	669:  _ErrorName[13835:13864],
	670:  _ErrorName[13864:13895],
	671:  _ErrorName[13895:13924],
	672:  _ErrorName[13924:13946],
	673:  _ErrorName[13946:13968],
	674:  _ErrorName[13968:13986],
	675:  _ErrorName[13986:14003],
	676:  _ErrorName[14003:14020],
	677:  _ErrorName[14020:14039],
	678:  _ErrorName[14039:14059],
	679:  _ErrorName[14059:14080],
	690:  _ErrorName[14080:14108],
	691:  _ErrorName[14108:14131],
	692:  _ErrorName[14131:14149],
	693:  _ErrorName[14149:14158],
	694:  _ErrorName[14158:14174],
	695:  _ErrorName[14174:14191],
	696:  _ErrorName[14191:14210],
	697:  _ErrorName[14210:14245],
	698:  _ErrorName[14245:14271],
	699:  _ErrorName[14271:14300],
	700:  _ErrorName[14300:14327],
	701:  _ErrorName[14327:14347],
	702:  _ErrorName[14347:14373],
	703:  _ErrorName[14373:14391],
	704:  _ErrorName[14391:14439],
	705:  _ErrorName[14439:14454],
	706:  _ErrorName[14454:14466],
	707:  _ErrorName[14466:14475],
	708:  _ErrorName[14475:14493],
	709:  _ErrorName[14493:14532],
	710:  _ErrorName[14532:14546],
	711:  _ErrorName[14546:14569],
	712:  _ErrorName[14569:14596],
	713:  _ErrorName[14596:14613],
	714:  _ErrorName[14613:14631],
	715:  _ErrorName[14631:14651],
	716:  _ErrorName[14651:14674],
	717:  _ErrorName[14674:14700],
	718:  _ErrorName[14700:14716],
	719:  _ErrorName[14716:14750],
	720:  _ErrorName[14750:14762],
	721:  _ErrorName[14762:14781],
	722:  _ErrorName[14781:14803],
	723:  _ErrorName[14803:14820],
	724:  _ErrorName[14820:14835],
	725:  _ErrorName[14835:14853],
	726:  _ErrorName[14853:14876],
	727:  _ErrorName[14876:14899],
	728:  _ErrorName[14899:14919],
	729:  _ErrorName[14919:14943],
	730:  _ErrorName[14943:14957],
	731:  _ErrorName[14957:15002],
	733:  _ErrorName[15002:15026],
	734:  _ErrorName[15026:15060],
	735:  _ErrorName[15060:15089],
	736:  _ErrorName[15089:15112],
	737:  _ErrorName[15112:15130],
	738:  _ErrorName[15130:15144],
	739:  _ErrorName[15144:15153],
	740:  _ErrorName[15153:15181],
	741:  _ErrorName[15181:15200],
	742:  _ErrorName[15200:15218],
	743:  _ErrorName[15218:15249],
	744:  _ErrorName[15249:15265],
	745:  _ErrorName[15265:15282],
	746:  _ErrorName[15282:15304],
	747:  _ErrorName[15304:15362],
	900:  _ErrorName[15362:15385],
	901:  _ErrorName[15385:15413],
	902:  _ErrorName[15413:15438],
	903:  _ErrorName[15438:15453],
	999:  _ErrorName[15453:15469],
	1000: _ErrorName[15469:15483],
	1001: _ErrorName[15483:15496],
	1002: _ErrorName[15496:15513],
	1003: _ErrorName[15513:15526],
	1004: _ErrorName[15526:15547],
	2001: _ErrorName[15547:15580],
	2002: _ErrorName[15580:15610],
}

func (i Error) String() string {
	if str, ok := _ErrorMap[i]; ok {
		return str
	}
	return fmt.Sprintf("Error(%d)", i)
}

// An "invalid array index" compiler error signifies that the constant values have changed.
// Re-run the stringer command to generate them again.
func _ErrorNoOp() {
	var x [1]struct{}
	_ = x[ErrUnsupportedMethod-(1)]
	_ = x[ErrUnsupportedParameter-(2)]
	_ = x[ErrUnexpectedEndOfFile-(3)]
	_ = x[ErrExpectedEndOfFile-(4)]
	_ = x[ErrCannotParseText-(6)]
	_ = x[ErrIncorrectNumberOfColumns-(7)]
	_ = x[ErrThereIsNoColumn-(8)]
	_ = x[ErrSizesOfColumnsDoesntMatch-(9)]
	_ = x[ErrNotFoundColumnInBlock-(10)]
	_ = x[ErrPositionOutOfBound-(11)]
	_ = x[ErrParameterOutOfBound-(12)]
	_ = x[ErrSizesOfColumnsInTupleDoesntMatch-(13)]
	_ = x[ErrDuplicateColumn-(15)]
	_ = x[ErrNoSuchColumnInTable-(16)]
	_ = x[ErrDelimiterInStringLiteralDoesntMatch-(17)]
	_ = x[ErrCannotInsertElementIntoConstantColumn-(18)]
	_ = x[ErrSizeOfFixedStringDoesntMatch-(19)]
	_ = x[ErrNumberOfColumnsDoesntMatch-(20)]
	_ = x[ErrCannotReadAllDataFromTabSeparatedInput-(21)]
	_ = x[ErrCannotParseAllValueFromTabSeparatedInput-(22)]
	_ = x[ErrCannotReadFromIstream-(23)]
	_ = x[ErrCannotWriteToOstream-(24)]
	_ = x[ErrCannotParseEscapeSequence-(25)]
	_ = x[ErrCannotParseQuotedString-(26)]
	_ = x[ErrCannotParseInputAssertionFailed-(27)]
	_ = x[ErrCannotPrintFloatOrDoubleNumber-(28)]
	_ = x[ErrCannotPrintInteger-(29)]
	_ = x[ErrCannotReadSizeOfCompressedChunk-(30)]
	_ = x[ErrCannotReadCompressedChunk-(31)]
	_ = x[ErrAttemptToReadAfterEOF-(32)]
	_ = x[ErrCannotReadAllData-(33)]
	_ = x[ErrTooManyArgumentsForFunction-(34)]
	_ = x[ErrTooFewArgumentsForFunction-(35)]
	_ = x[ErrBadArguments-(36)]
	_ = x[ErrUnknownElementInAst-(37)]
	_ = x[ErrCannotParseDate-(38)]
	_ = x[ErrTooLargeSizeCompressed-(39)]
	_ = x[ErrChecksumDoesntMatch-(40)]
	_ = x[ErrCannotParseDatetime-(41)]
	_ = x[ErrNumberOfArgumentsDoesntMatch-(42)]
	_ = x[ErrIllegalTypeOfArgument-(43)]
	_ = x[ErrIllegalColumn-(44)]
	_ = x[ErrIllegalNumberOfResultColumns-(45)]
	_ = x[ErrUnknownFunction-(46)]
	_ = x[ErrUnknownIdentifier-(47)]
	_ = x[ErrNotImplemented-(48)]
	_ = x[ErrLogicalError-(49)]
	_ = x[ErrUnknownType-(50)]
	_ = x[ErrEmptyListOfColumnsQueried-(51)]
	_ = x[ErrColumnQueriedMoreThanOnce-(52)]
	_ = x[ErrTypeMismatch-(53)]
	_ = x[ErrStorageDoesntAllowParameters-(54)]
	_ = x[ErrStorageRequiresParameter-(55)]
	_ = x[ErrUnknownStorage-(56)]
	_ = x[ErrTableAlreadyExists-(57)]
	_ = x[ErrTableMetadataAlreadyExists-(58)]
	_ = x[ErrIllegalTypeOfColumnForFilter-(59)]
	_ = x[ErrUnknownTable-(60)]
	_ = x[ErrOnlyFilterColumnInBlock-(61)]
	_ = x[ErrSyntaxError-(62)]
	_ = x[ErrUnknownAggregateFunction-(63)]
	_ = x[ErrCannotReadAggregateFunctionFromText-(64)]
	_ = x[ErrCannotWriteAggregateFunctionAsText-(65)]
	_ = x[ErrNotAColumn-(66)]
	_ = x[ErrIllegalKeyOfAggregation-(67)]
	_ = x[ErrCannotGetSizeOfField-(68)]
	_ = x[ErrArgumentOutOfBound-(69)]
	_ = x[ErrCannotConvertType-(70)]
	_ = x[ErrCannotWriteAfterEndOfBuffer-(71)]
	_ = x[ErrCannotParseNumber-(72)]
	_ = x[ErrUnknownFormat-(73)]
	_ = x[ErrCannotReadFromFileDescriptor-(74)]
	_ = x[ErrCannotWriteToFileDescriptor-(75)]
	_ = x[ErrCannotOpenFile-(76)]
	_ = x[ErrCannotCloseFile-(77)]
	_ = x[ErrUnknownTypeOfQuery-(78)]
	_ = x[ErrIncorrectFileName-(79)]
	_ = x[ErrIncorrectQuery-(80)]
	_ = x[ErrUnknownDatabase-(81)]
	_ = x[ErrDatabaseAlreadyExists-(82)]
	_ = x[ErrDirectoryDoesntExist-(83)]
	_ = x[ErrDirectoryAlreadyExists-(84)]
	_ = x[ErrFormatIsNotSuitableForInput-(85)]
	_ = x[ErrReceivedErrorFromRemoteIoServer-(86)]
	_ = x[ErrCannotSeekThroughFile-(87)]
	_ = x[ErrCannotTruncateFile-(88)]
	_ = x[ErrUnknownCompressionMethod-(89)]
	_ = x[ErrEmptyListOfColumnsPassed-(90)]
	_ = x[ErrSizesOfMarksFilesAreInconsistent-(91)]
	_ = x[ErrEmptyDataPassed-(92)]
	_ = x[ErrUnknownAggregatedDataVariant-(93)]
	_ = x[ErrCannotMergeDifferentAggregatedDataVariants-(94)]
	_ = x[ErrCannotReadFromSocket-(95)]
	_ = x[ErrCannotWriteToSocket-(96)]
	_ = x[ErrCannotReadAllDataFromChunkedInput-(97)]
	_ = x[ErrCannotWriteToEmptyBlockOutputStream-(98)]
	_ = x[ErrUnknownPacketFromClient-(99)]
	_ = x[ErrUnknownPacketFromServer-(100)]
	_ = x[ErrUnexpectedPacketFromClient-(101)]
	_ = x[ErrUnexpectedPacketFromServer-(102)]
	_ = x[ErrReceivedDataForWrongQueryID-(103)]
	_ = x[ErrTooSmallBufferSize-(104)]
	_ = x[ErrCannotReadHistory-(105)]
	_ = x[ErrCannotAppendHistory-(106)]
	_ = x[ErrFileDoesntExist-(107)]
	_ = x[ErrNoDataToInsert-(108)]
	_ = x[ErrCannotBlockSignal-(109)]
	_ = x[ErrCannotUnblockSignal-(110)]
	_ = x[ErrCannotManipulateSigset-(111)]
	_ = x[ErrCannotWaitForSignal-(112)]
	_ = x[ErrThereIsNoSession-(113)]
	_ = x[ErrCannotClockGettime-(114)]
	_ = x[ErrUnknownSetting-(115)]
	_ = x[ErrThereIsNoDefaultValue-(116)]
	_ = x[ErrIncorrectData-(117)]
	_ = x[ErrEngineRequired-(119)]
	_ = x[ErrCannotInsertValueOfDifferentSizeIntoTuple-(120)]
	_ = x[ErrUnsupportedJoinKeys-(121)]
	_ = x[ErrIncompatibleColumns-(122)]
	_ = x[ErrUnknownTypeOfAstNode-(123)]
	_ = x[ErrIncorrectElementOfSet-(124)]
	_ = x[ErrIncorrectResultOfScalarSubquery-(125)]
	_ = x[ErrCannotGetReturnType-(126)]
	_ = x[ErrIllegalIndex-(127)]
	_ = x[ErrTooLargeArraySize-(128)]
	_ = x[ErrFunctionIsSpecial-(129)]
	_ = x[ErrCannotReadArrayFromText-(130)]
	_ = x[ErrTooLargeStringSize-(131)]
	_ = x[ErrCannotCreateTableFromMetadata-(132)]
	_ = x[ErrAggregateFunctionDoesntAllowParameters-(133)]
	_ = x[ErrParametersToAggregateFunctionsMustBeLiterals-(134)]
	_ = x[ErrZeroArrayOrTupleIndex-(135)]
	_ = x[ErrUnknownElementInConfig-(137)]
	_ = x[ErrExcessiveElementInConfig-(138)]
	_ = x[ErrNoElementsInConfig-(139)]
	_ = x[ErrAllRequestedColumnsAreMissing-(140)]
	_ = x[ErrSamplingNotSupported-(141)]
	_ = x[ErrNotFoundNode-(142)]
	_ = x[ErrFoundMoreThanOneNode-(143)]
	_ = x[ErrFirstDateIsBiggerThanLastDate-(144)]
	_ = x[ErrUnknownOverflowMode-(145)]
	_ = x[ErrQuerySectionDoesntMakeSense-(146)]
	_ = x[ErrNotFoundFunctionElementForAggregate-(147)]
	_ = x[ErrNotFoundRelationElementForCondition-(148)]
	_ = x[ErrNotFoundRHSElementForCondition-(149)]
	_ = x[ErrNoAttributesListed-(150)]
	_ = x[ErrIndexOfColumnInSortClauseIsOutOfRange-(151)]
	_ = x[ErrUnknownDirectionOfSorting-(152)]
	_ = x[ErrIllegalDivision-(153)]
	_ = x[ErrAggregateFunctionNotApplicable-(154)]
	_ = x[ErrUnknownRelation-(155)]
	_ = x[ErrDictionariesWasNotLoaded-(156)]
	_ = x[ErrIllegalOverflowMode-(157)]
	_ = x[ErrTooManyRows-(158)]
	_ = x[ErrTimeoutExceeded-(159)]
	_ = x[ErrTooSlow-(160)]
	_ = x[ErrTooManyColumns-(161)]
	_ = x[ErrTooDeepSubqueries-(162)]
	_ = x[ErrTooDeepPipeline-(163)]
	_ = x[ErrReadonly-(164)]
	_ = x[ErrTooManyTemporaryColumns-(165)]
	_ = x[ErrTooManyTemporaryNonConstColumns-(166)]
	_ = x[ErrTooDeepAst-(167)]
	_ = x[ErrTooBigAst-(168)]
	_ = x[ErrBadTypeOfField-(169)]
	_ = x[ErrBadGet-(170)]
	_ = x[ErrBlocksHaveDifferentStructure-(171)]
	_ = x[ErrCannotCreateDirectory-(172)]
	_ = x[ErrCannotAllocateMemory-(173)]
	_ = x[ErrCyclicAliases-(174)]
	_ = x[ErrChunkNotFound-(176)]
	_ = x[ErrDuplicateChunkName-(177)]
	_ = x[ErrMultipleAliasesForExpression-(178)]
	_ = x[ErrMultipleExpressionsForAlias-(179)]
	_ = x[ErrThereIsNoProfile-(180)]
	_ = x[ErrIllegalFinal-(181)]
	_ = x[ErrIllegalPrewhere-(182)]
	_ = x[ErrUnexpectedExpression-(183)]
	_ = x[ErrIllegalAggregation-(184)]
	_ = x[ErrUnsupportedMyisamBlockType-(185)]
	_ = x[ErrUnsupportedCollationLocale-(186)]
	_ = x[ErrCollationComparisonFailed-(187)]
	_ = x[ErrUnknownAction-(188)]
	_ = x[ErrTableMustNotBeCreatedManually-(189)]
	_ = x[ErrSizesOfArraysDontMatch-(190)]
	_ = x[ErrSetSizeLimitExceeded-(191)]
	_ = x[ErrUnknownUser-(192)]
	_ = x[ErrWrongPassword-(193)]
	_ = x[ErrRequiredPassword-(194)]
	_ = x[ErrIPAddressNotAllowed-(195)]
	_ = x[ErrUnknownAddressPatternType-(196)]
	_ = x[ErrServerRevisionIsTooOld-(197)]
	_ = x[ErrDNSError-(198)]
	_ = x[ErrUnknownQuota-(199)]
	_ = x[ErrQuotaDoesntAllowKeys-(200)]
	_ = x[ErrQuotaExpired-(201)]
	_ = x[ErrTooManySimultaneousQueries-(202)]
	_ = x[ErrNoFreeConnection-(203)]
	_ = x[ErrCannotFsync-(204)]
	_ = x[ErrNestedTypeTooDeep-(205)]
	_ = x[ErrAliasRequired-(206)]
	_ = x[ErrAmbiguousIdentifier-(207)]
	_ = x[ErrEmptyNestedTable-(208)]
	_ = x[ErrSocketTimeout-(209)]
	_ = x[ErrNetworkError-(210)]
	_ = x[ErrEmptyQuery-(211)]
	_ = x[ErrUnknownLoadBalancing-(212)]
	_ = x[ErrUnknownTotalsMode-(213)]
	_ = x[ErrCannotStatvfs-(214)]
	_ = x[ErrNotAnAggregate-(215)]
	_ = x[ErrQueryWithSameIDIsAlreadyRunning-(216)]
	_ = x[ErrClientHasConnectedToWrongPort-(217)]
	_ = x[ErrTableIsDropped-(218)]
	_ = x[ErrDatabaseNotEmpty-(219)]
	_ = x[ErrDuplicateInterserverIOEndpoint-(220)]
	_ = x[ErrNoSuchInterserverIoEndpoint-(221)]
	_ = x[ErrAddingReplicaToNonEmptyTable-(222)]
	_ = x[ErrUnexpectedAstStructure-(223)]
	_ = x[ErrReplicaIsAlreadyActive-(224)]
	_ = x[ErrNoZookeeper-(225)]
	_ = x[ErrNoFileInDataPart-(226)]
	_ = x[ErrUnexpectedFileInDataPart-(227)]
	_ = x[ErrBadSizeOfFileInDataPart-(228)]
	_ = x[ErrQueryIsTooLarge-(229)]
	_ = x[ErrNotFoundExpectedDataPart-(230)]
	_ = x[ErrTooManyUnexpectedDataParts-(231)]
	_ = x[ErrNoSuchDataPart-(232)]
	_ = x[ErrBadDataPartName-(233)]
	_ = x[ErrNoReplicaHasPart-(234)]
	_ = x[ErrDuplicateDataPart-(235)]
	_ = x[ErrAborted-(236)]
	_ = x[ErrNoReplicaNameGiven-(237)]
	_ = x[ErrFormatVersionTooOld-(238)]
	_ = x[ErrCannotMunmap-(239)]
	_ = x[ErrCannotMremap-(240)]
	_ = x[ErrMemoryLimitExceeded-(241)]
	_ = x[ErrTableIsReadOnly-(242)]
	_ = x[ErrNotEnoughSpace-(243)]
	_ = x[ErrUnexpectedZookeeperError-(244)]
	_ = x[ErrCorruptedData-(246)]
	_ = x[ErrIncorrectMark-(247)]
	_ = x[ErrInvalidPartitionValue-(248)]
	_ = x[ErrNotEnoughBlockNumbers-(250)]
	_ = x[ErrNoSuchReplica-(251)]
	_ = x[ErrTooManyParts-(252)]
	_ = x[ErrReplicaIsAlreadyExist-(253)]
	_ = x[ErrNoActiveReplicas-(254)]
	_ = x[ErrTooManyRetriesToFetchParts-(255)]
	_ = x[ErrPartitionAlreadyExists-(256)]
	_ = x[ErrPartitionDoesntExist-(257)]
	_ = x[ErrUnionAllResultStructuresMismatch-(258)]
	_ = x[ErrClientOutputFormatSpecified-(260)]
	_ = x[ErrUnknownBlockInfoField-(261)]
	_ = x[ErrBadCollation-(262)]
	_ = x[ErrCannotCompileCode-(263)]
	_ = x[ErrIncompatibleTypeOfJoin-(264)]
	_ = x[ErrNoAvailableReplica-(265)]
	_ = x[ErrMismatchReplicasDataSources-(266)]
	_ = x[ErrStorageDoesntSupportParallelReplicas-(267)]
	_ = x[ErrCPUIDError-(268)]
	_ = x[ErrInfiniteLoop-(269)]
	_ = x[ErrCannotCompress-(270)]
	_ = x[ErrCannotDecompress-(271)]
	_ = x[ErrCannotIOSubmit-(272)]
	_ = x[ErrCannotIOGetevents-(273)]
	_ = x[ErrAioReadError-(274)]
	_ = x[ErrAioWriteError-(275)]
	_ = x[ErrIndexNotUsed-(277)]
	_ = x[ErrLeadershipLost-(278)]
	_ = x[ErrAllConnectionTriesFailed-(279)]
	_ = x[ErrNoAvailableData-(280)]
	_ = x[ErrDictionaryIsEmpty-(281)]
	_ = x[ErrIncorrectIndex-(282)]
	_ = x[ErrUnknownDistributedProductMode-(283)]
	_ = x[ErrWrongGlobalSubquery-(284)]
	_ = x[ErrTooFewLiveReplicas-(285)]
	_ = x[ErrUnsatisfiedQuorumForPreviousWrite-(286)]
	_ = x[ErrUnknownFormatVersion-(287)]
	_ = x[ErrDistributedInJoinSubqueryDenied-(288)]
	_ = x[ErrReplicaIsNotInQuorum-(289)]
	_ = x[ErrLimitExceeded-(290)]
	_ = x[ErrDatabaseAccessDenied-(291)]
	_ = x[ErrLeadershipChanged-(292)]
	_ = x[ErrMongodbCannotAuthenticate-(293)]
	_ = x[ErrCannotWriteToFile-(294)]
	_ = x[ErrReceivedEmptyData-(295)]
	_ = x[ErrNoRemoteShardFound-(296)]
	_ = x[ErrShardHasNoConnections-(297)]
	_ = x[ErrCannotPipe-(298)]
	_ = x[ErrCannotFork-(299)]
	_ = x[ErrCannotDlsym-(300)]
	_ = x[ErrCannotCreateChildProcess-(301)]
	_ = x[ErrChildWasNotExitedNormally-(302)]
	_ = x[ErrCannotSelect-(303)]
	_ = x[ErrCannotWaitpid-(304)]
	_ = x[ErrTableWasNotDropped-(305)]
	_ = x[ErrTooDeepRecursion-(306)]
	_ = x[ErrTooManyBytes-(307)]
	_ = x[ErrUnexpectedNodeInZookeeper-(308)]
	_ = x[ErrFunctionCannotHaveParameters-(309)]
	_ = x[ErrInvalidShardWeight-(317)]
	_ = x[ErrInvalidConfigParameter-(318)]
	_ = x[ErrUnknownStatusOfInsert-(319)]
	_ = x[ErrValueIsOutOfRangeOfDataType-(321)]
	_ = x[ErrBarrierTimeout-(335)]
	_ = x[ErrUnknownDatabaseEngine-(336)]
	_ = x[ErrDdlGuardIsActive-(337)]
	_ = x[ErrUnfinished-(341)]
	_ = x[ErrMetadataMismatch-(342)]
	_ = x[ErrSupportIsDisabled-(344)]
	_ = x[ErrTableDiffersTooMuch-(345)]
	_ = x[ErrCannotConvertCharset-(346)]
	_ = x[ErrCannotLoadConfig-(347)]
	_ = x[ErrCannotInsertNullInOrdinaryColumn-(349)]
	_ = x[ErrIncompatibleSourceTables-(350)]
	_ = x[ErrAmbiguousTableName-(351)]
	_ = x[ErrAmbiguousColumnName-(352)]
	_ = x[ErrIndexOfPositionalArgumentIsOutOfRange-(353)]
	_ = x[ErrZlibInflateFailed-(354)]
	_ = x[ErrZlibDeflateFailed-(355)]
	_ = x[ErrBadLambda-(356)]
	_ = x[ErrReservedIdentifierName-(357)]
	_ = x[ErrIntoOutfileNotAllowed-(358)]
	_ = x[ErrTableSizeExceedsMaxDropSizeLimit-(359)]
	_ = x[ErrCannotCreateCharsetConverter-(360)]
	_ = x[ErrSeekPositionOutOfBound-(361)]
	_ = x[ErrCurrentWriteBufferIsExhausted-(362)]
	_ = x[ErrCannotCreateIoBuffer-(363)]
	_ = x[ErrReceivedErrorTooManyRequests-(364)]
	_ = x[ErrOutputIsNotSorted-(365)]
	_ = x[ErrSizesOfNestedColumnsAreInconsistent-(366)]
	_ = x[ErrTooManyFetches-(367)]
	_ = x[ErrBadCast-(368)]
	_ = x[ErrAllReplicasAreStale-(369)]
	_ = x[ErrDataTypeCannotBeUsedInTables-(370)]
	_ = x[ErrInconsistentClusterDefinition-(371)]
	_ = x[ErrSessionNotFound-(372)]
	_ = x[ErrSessionIsLocked-(373)]
	_ = x[ErrInvalidSessionTimeout-(374)]
	_ = x[ErrCannotDlopen-(375)]
	_ = x[ErrCannotParseUUID-(376)]
	_ = x[ErrIllegalSyntaxForDataType-(377)]
	_ = x[ErrDataTypeCannotHaveArguments-(378)]
	_ = x[ErrUnknownStatusOfDistributedDdlTask-(379)]
	_ = x[ErrCannotKill-(380)]
	_ = x[ErrHTTPLengthRequired-(381)]
	_ = x[ErrCannotLoadCatboostModel-(382)]
	_ = x[ErrCannotApplyCatboostModel-(383)]
	_ = x[ErrPartIsTemporarilyLocked-(384)]
	_ = x[ErrMultipleStreamsRequired-(385)]
	_ = x[ErrNoCommonType-(386)]
	_ = x[ErrExternalLoadableAlreadyExists-(387)]
	_ = x[ErrCannotAssignOptimize-(388)]
	_ = x[ErrInsertWasDeduplicated-(389)]
	_ = x[ErrCannotGetCreateTableQuery-(390)]
	_ = x[ErrExternalLibraryError-(391)]
	_ = x[ErrQueryIsProhibited-(392)]
	_ = x[ErrThereIsNoQuery-(393)]
	_ = x[ErrQueryWasCancelled-(394)]
	_ = x[ErrFunctionThrowIfValueIsNonZero-(395)]
	_ = x[ErrTooManyRowsOrBytes-(396)]
	_ = x[ErrQueryIsNotSupportedInMaterializedView-(397)]
	_ = x[ErrUnknownMutationCommand-(398)]
	_ = x[ErrFormatIsNotSuitableForOutput-(399)]
	_ = x[ErrCannotStat-(400)]
	_ = x[ErrFeatureIsNotEnabledAtBuildTime-(401)]
	_ = x[ErrCannotIosetup-(402)]
	_ = x[ErrInvalidJoinOnExpression-(403)]
	_ = x[ErrBadOdbcConnectionString-(404)]
	_ = x[ErrTopAndLimitTogether-(406)]
	_ = x[ErrDecimalOverflow-(407)]
	_ = x[ErrBadRequestParameter-(408)]
	_ = x[ErrExternalServerIsNotResponding-(410)]
	_ = x[ErrPthreadError-(411)]
	_ = x[ErrNetlinkError-(412)]
	_ = x[ErrCannotSetSignalHandler-(413)]
	_ = x[ErrAllReplicasLost-(415)]
	_ = x[ErrReplicaStatusChanged-(416)]
	_ = x[ErrExpectedAllOrAny-(417)]
	_ = x[ErrUnknownJoin-(418)]
	_ = x[ErrMultipleAssignmentsToColumn-(419)]
	_ = x[ErrCannotUpdateColumn-(420)]
	_ = x[ErrCannotAddDifferentAggregateStates-(421)]
	_ = x[ErrUnsupportedURIScheme-(422)]
	_ = x[ErrCannotGettimeofday-(423)]
	_ = x[ErrCannotLink-(424)]
	_ = x[ErrSystemError-(425)]
	_ = x[ErrCannotCompileRegexp-(427)]
	_ = x[ErrFailedToGetpwuid-(429)]
	_ = x[ErrMismatchingUsersForProcessAndData-(430)]
	_ = x[ErrIllegalSyntaxForCodecType-(431)]
	_ = x[ErrUnknownCodec-(432)]
	_ = x[ErrIllegalCodecParameter-(433)]
	_ = x[ErrCannotParseProtobufSchema-(434)]
	_ = x[ErrNoColumnSerializedToRequiredProtobufField-(435)]
	_ = x[ErrProtobufBadCast-(436)]
	_ = x[ErrProtobufFieldNotRepeated-(437)]
	_ = x[ErrDataTypeCannotBePromoted-(438)]
	_ = x[ErrCannotScheduleTask-(439)]
	_ = x[ErrInvalidLimitExpression-(440)]
	_ = x[ErrCannotParseDomainValueFromString-(441)]
	_ = x[ErrBadDatabaseForTemporaryTable-(442)]
	_ = x[ErrNoColumnsSerializedToProtobufFields-(443)]
	_ = x[ErrUnknownProtobufFormat-(444)]
	_ = x[ErrCannotMprotect-(445)]
	_ = x[ErrFunctionNotAllowed-(446)]
	_ = x[ErrHyperscanCannotScanText-(447)]
	_ = x[ErrBrotliReadFailed-(448)]
	_ = x[ErrBrotliWriteFailed-(449)]
	_ = x[ErrBadTTLExpression-(450)]
	_ = x[ErrBadTTLFile-(451)]
	_ = x[ErrSettingConstraintViolation-(452)]
	_ = x[ErrMysqlClientInsufficientCapabilities-(453)]
	_ = x[ErrOpensslError-(454)]
	_ = x[ErrSuspiciousTypeForLowCardinality-(455)]
	_ = x[ErrUnknownQueryParameter-(456)]
	_ = x[ErrBadQueryParameter-(457)]
	_ = x[ErrCannotUnlink-(458)]
	_ = x[ErrCannotSetThreadPriority-(459)]
	_ = x[ErrCannotCreateTimer-(460)]
	_ = x[ErrCannotSetTimerPeriod-(461)]
	_ = x[ErrCannotFcntl-(463)]
	_ = x[ErrCannotParseElf-(464)]
	_ = x[ErrCannotParseDwarf-(465)]
	_ = x[ErrInsecurePath-(466)]
	_ = x[ErrCannotParseBool-(467)]
	_ = x[ErrCannotPthreadAttr-(468)]
	_ = x[ErrViolatedConstraint-(469)]
	_ = x[ErrInvalidSettingValue-(471)]
	_ = x[ErrReadonlySetting-(472)]
	_ = x[ErrDeadlockAvoided-(473)]
	_ = x[ErrInvalidTemplateFormat-(474)]
	_ = x[ErrInvalidWithFillExpression-(475)]
	_ = x[ErrWithTiesWithoutOrderBy-(476)]
	_ = x[ErrInvalidUsageOfInput-(477)]
	_ = x[ErrUnknownPolicy-(478)]
	_ = x[ErrUnknownDisk-(479)]
	_ = x[ErrUnknownProtocol-(480)]
	_ = x[ErrPathAccessDenied-(481)]
	_ = x[ErrDictionaryAccessDenied-(482)]
	_ = x[ErrTooManyRedirects-(483)]
	_ = x[ErrInternalRedisError-(484)]
	_ = x[ErrCannotGetCreateDictionaryQuery-(487)]
	_ = x[ErrIncorrectDictionaryDefinition-(489)]
	_ = x[ErrCannotFormatDatetime-(490)]
	_ = x[ErrUnacceptableURL-(491)]
	_ = x[ErrAccessEntityNotFound-(492)]
	_ = x[ErrAccessEntityAlreadyExists-(493)]
	_ = x[ErrAccessStorageReadonly-(495)]
	_ = x[ErrQuotaRequiresClientKey-(496)]
	_ = x[ErrAccessDenied-(497)]
	_ = x[ErrLimitByWithTiesIsNotSupported-(498)]
	_ = x[ErrS3Error-(499)]
	_ = x[ErrAzureBlobStorageError-(500)]
	_ = x[ErrCannotCreateDatabase-(501)]
	_ = x[ErrCannotSigqueue-(502)]
	_ = x[ErrAggregateFunctionThrow-(503)]
	_ = x[ErrFileAlreadyExists-(504)]
	_ = x[ErrUnableToSkipUnusedShards-(507)]
	_ = x[ErrUnknownAccessType-(508)]
	_ = x[ErrInvalidGrant-(509)]
	_ = x[ErrCacheDictionaryUpdateFail-(510)]
	_ = x[ErrUnknownRole-(511)]
	_ = x[ErrSetNonGrantedRole-(512)]
	_ = x[ErrUnknownPartType-(513)]
	_ = x[ErrAccessStorageForInsertionNotFound-(514)]
	_ = x[ErrIncorrectAccessEntityDefinition-(515)]
	_ = x[ErrAuthenticationFailed-(516)]
	_ = x[ErrCannotAssignAlter-(517)]
	_ = x[ErrCannotCommitOffset-(518)]
	_ = x[ErrNoRemoteShardAvailable-(519)]
	_ = x[ErrCannotDetachDictionaryAsTable-(520)]
	_ = x[ErrAtomicRenameFail-(521)]
	_ = x[ErrUnknownRowPolicy-(523)]
	_ = x[ErrAlterOfColumnIsForbidden-(524)]
	_ = x[ErrIncorrectDiskIndex-(525)]
	_ = x[ErrNoSuitableFunctionImplementation-(527)]
	_ = x[ErrCassandraInternalError-(528)]
	_ = x[ErrNotALeader-(529)]
	_ = x[ErrCannotConnectRabbitmq-(530)]
	_ = x[ErrCannotFstat-(531)]
	_ = x[ErrLdapError-(532)]
	_ = x[ErrUnknownRaidType-(535)]
	_ = x[ErrCannotRestoreFromFieldDump-(536)]
	_ = x[ErrIllegalMysqlVariable-(537)]
	_ = x[ErrMysqlSyntaxError-(538)]
	_ = x[ErrCannotBindRabbitmqExchange-(539)]
	_ = x[ErrCannotDeclareRabbitmqExchange-(540)]
	_ = x[ErrCannotCreateRabbitmqQueueBinding-(541)]
	_ = x[ErrCannotRemoveRabbitmqExchange-(542)]
	_ = x[ErrUnknownMysqlDatatypesSupportLevel-(543)]
	_ = x[ErrRowAndRowsTogether-(544)]
	_ = x[ErrFirstAndNextTogether-(545)]
	_ = x[ErrNoRowDelimiter-(546)]
	_ = x[ErrInvalidRaidType-(547)]
	_ = x[ErrUnknownVolume-(548)]
	_ = x[ErrDataTypeCannotBeUsedInKey-(549)]
	_ = x[ErrUnrecognizedArguments-(552)]
	_ = x[ErrLzmaStreamEncoderFailed-(553)]
	_ = x[ErrLzmaStreamDecoderFailed-(554)]
	_ = x[ErrRocksdbError-(555)]
	_ = x[ErrSyncMysqlUserAccessError-(556)]
	_ = x[ErrUnknownUnion-(557)]
	_ = x[ErrExpectedAllOrDistinct-(558)]
	_ = x[ErrInvalidGrpcQueryInfo-(559)]
	_ = x[ErrZstdEncoderFailed-(560)]
	_ = x[ErrZstdDecoderFailed-(561)]
	_ = x[ErrTldListNotFound-(562)]
	_ = x[ErrCannotReadMapFromText-(563)]
	_ = x[ErrInterserverSchemeDoesntMatch-(564)]
	_ = x[ErrTooManyPartitions-(565)]
	_ = x[ErrCannotRmdir-(566)]
	_ = x[ErrDuplicatedPartUuids-(567)]
	_ = x[ErrRaftError-(568)]
	_ = x[ErrMultipleColumnsSerializedToSameProtobufField-(569)]
	_ = x[ErrDataTypeIncompatibleWithProtobufField-(570)]
	_ = x[ErrDatabaseReplicationFailed-(571)]
	_ = x[ErrTooManyQueryPlanOptimizations-(572)]
	_ = x[ErrEpollError-(573)]
	_ = x[ErrDistributedTooManyPendingBytes-(574)]
	_ = x[ErrUnknownSnapshot-(575)]
	_ = x[ErrKerberosError-(576)]
	_ = x[ErrInvalidShardID-(577)]
	_ = x[ErrInvalidFormatInsertQueryWithData-(578)]
	_ = x[ErrIncorrectPartType-(579)]
	_ = x[ErrCannotSetRoundingMode-(580)]
	_ = x[ErrTooLargeDistributedDepth-(581)]
	_ = x[ErrNoSuchProjectionInTable-(582)]
	_ = x[ErrIllegalProjection-(583)]
	_ = x[ErrProjectionNotUsed-(584)]
	_ = x[ErrCannotParseYaml-(585)]
	_ = x[ErrCannotCreateFile-(586)]
	_ = x[ErrConcurrentAccessNotSupported-(587)]
	_ = x[ErrDistributedBrokenBatchInfo-(588)]
	_ = x[ErrDistributedBrokenBatchFiles-(589)]
	_ = x[ErrCannotSysconf-(590)]
	_ = x[ErrSqliteEngineError-(591)]
	_ = x[ErrDataEncryptionError-(592)]
	_ = x[ErrZeroCopyReplicationError-(593)]
	_ = x[ErrBzip2StreamDecoderFailed-(594)]
	_ = x[ErrBzip2StreamEncoderFailed-(595)]
	_ = x[ErrIntersectOrExceptResultStructuresMismatch-(596)]
	_ = x[ErrNoSuchErrorCode-(597)]
	_ = x[ErrBackupAlreadyExists-(598)]
	_ = x[ErrBackupNotFound-(599)]
	_ = x[ErrBackupVersionNotSupported-(600)]
	_ = x[ErrBackupDamaged-(601)]
	_ = x[ErrNoBaseBackup-(602)]
	_ = x[ErrWrongBaseBackup-(603)]
	_ = x[ErrBackupEntryAlreadyExists-(604)]
	_ = x[ErrBackupEntryNotFound-(605)]
	_ = x[ErrBackupIsEmpty-(606)]
	_ = x[ErrCannotRestoreDatabase-(607)]
	_ = x[ErrCannotRestoreTable-(608)]
	_ = x[ErrFunctionAlreadyExists-(609)]
	_ = x[ErrCannotDropFunction-(610)]
	_ = x[ErrCannotCreateRecursiveFunction-(611)]
	_ = x[ErrPostgresqlConnectionFailure-(614)]
	_ = x[ErrCannotAdvise-(615)]
	_ = x[ErrUnknownReadMethod-(616)]
	_ = x[ErrLz4EncoderFailed-(617)]
	_ = x[ErrLz4DecoderFailed-(618)]
	_ = x[ErrPostgresqlReplicationInternalError-(619)]
	_ = x[ErrQueryNotAllowed-(620)]
	_ = x[ErrCannotNormalizeString-(621)]
	_ = x[ErrCannotParseCapnProtoSchema-(622)]
	_ = x[ErrCapnProtoBadCast-(623)]
	_ = x[ErrBadFileType-(624)]
	_ = x[ErrIOSetupError-(625)]
	_ = x[ErrCannotSkipUnknownField-(626)]
	_ = x[ErrBackupEngineNotFound-(627)]
	_ = x[ErrOffsetFetchWithoutOrderBy-(628)]
	_ = x[ErrHTTPRangeNotSatisfiable-(629)]
	_ = x[ErrHaveDependentObjects-(630)]
	_ = x[ErrUnknownFileSize-(631)]
	_ = x[ErrUnexpectedDataAfterParsedValue-(632)]
	_ = x[ErrQueryIsNotSupportedInWindowView-(633)]
	_ = x[ErrMongodbError-(634)]
	_ = x[ErrCannotPoll-(635)]
	_ = x[ErrCannotExtractTableStructure-(636)]
	_ = x[ErrInvalidTableOverride-(637)]
	_ = x[ErrSnappyUncompressFailed-(638)]
	_ = x[ErrSnappyCompressFailed-(639)]
	_ = x[ErrNoHivemetastore-(640)]
	_ = x[ErrCannotAppendToFile-(641)]
	_ = x[ErrCannotPackArchive-(642)]
	_ = x[ErrCannotUnpackArchive-(643)]
	_ = x[ErrNumberOfDimensionsMismatched-(645)]
	_ = x[ErrCannotBackupTable-(647)]
	_ = x[ErrWrongDdlRenamingSettings-(648)]
	_ = x[ErrInvalidTransaction-(649)]
	_ = x[ErrSerializationError-(650)]
	_ = x[ErrCapnProtoBadType-(651)]
	_ = x[ErrOnlyNullsWhileReadingSchema-(652)]
	_ = x[ErrCannotParseBackupSettings-(653)]
	_ = x[ErrWrongBackupSettings-(654)]
	_ = x[ErrFailedToSyncBackupOrRestore-(655)]
	_ = x[ErrUnknownStatusOfTransaction-(659)]
	_ = x[ErrHdfsError-(660)]
	_ = x[ErrCannotSendSignal-(661)]
	_ = x[ErrFsMetadataError-(662)]
	_ = x[ErrInconsistentMetadataForBackup-(663)]
	_ = x[ErrAccessStorageDoesntAllowBackup-(664)]
	_ = x[ErrCannotConnectNats-(665)]
	_ = x[ErrNotInitialized-(667)]
	_ = x[ErrInvalidState-(668)]
	_ = x[ErrNamedCollectionDoesntExist-(669)]
	_ = x[ErrNamedCollectionAlreadyExists-(670)]
	_ = x[ErrNamedCollectionIsImmutable-(671)]
	_ = x[ErrInvalidSchedulerNode-(672)]
	_ = x[ErrResourceAccessDenied-(673)]
	_ = x[ErrResourceNotFound-(674)]
	_ = x[ErrCannotParseIpv4-(675)]
	_ = x[ErrCannotParseIpv6-(676)]
	_ = x[ErrThreadWasCanceled-(677)]
	_ = x[ErrIOUringInitFailed-(678)]
	_ = x[ErrIOUringSubmitError-(679)]
	_ = x[ErrMixedAccessParameterTypes-(690)]
	_ = x[ErrUnknownElementOfEnum-(691)]
	_ = x[ErrTooManyMutations-(692)]
	_ = x[ErrAwsError-(693)]
	_ = x[ErrAsyncLoadCycle-(694)]
	_ = x[ErrAsyncLoadFailed-(695)]
	_ = x[ErrAsyncLoadCanceled-(696)]
	_ = x[ErrCannotRestoreToNonencryptedDisk-(697)]
	_ = x[ErrInvalidRedisStorageType-(698)]
	_ = x[ErrInvalidRedisTableStructure-(699)]
	_ = x[ErrUserSessionLimitExceeded-(700)]
	_ = x[ErrClusterDoesntExist-(701)]
	_ = x[ErrClientInfoDoesNotMatch-(702)]
	_ = x[ErrInvalidIdentifier-(703)]
	_ = x[ErrQueryCacheUsedWithNondeterministicFunctions-(704)]
	_ = x[ErrTableNotEmpty-(705)]
	_ = x[ErrLibsshError-(706)]
	_ = x[ErrGcpError-(707)]
	_ = x[ErrIllegalStatistics-(708)]
	_ = x[ErrCannotGetReplicatedDatabaseSnapshot-(709)]
	_ = x[ErrFaultInjected-(710)]
	_ = x[ErrFilecacheAccessDenied-(711)]
	_ = x[ErrTooManyMaterializedViews-(712)]
	_ = x[ErrBrokenProjection-(713)]
	_ = x[ErrUnexpectedCluster-(714)]
	_ = x[ErrCannotDetectFormat-(715)]
	_ = x[ErrCannotForgetPartition-(716)]
	_ = x[ErrExperimentalFeatureError-(717)]
	_ = x[ErrTooSlowParsing-(718)]
	_ = x[ErrQueryCacheUsedWithSystemTable-(719)]
	_ = x[ErrUserExpired-(720)]
	_ = x[ErrDeprecatedFunction-(721)]
	_ = x[ErrAsyncLoadWaitFailed-(722)]
	_ = x[ErrParquetException-(723)]
	_ = x[ErrTooManyTables-(724)]
	_ = x[ErrTooManyDatabases-(725)]
	_ = x[ErrUnexpectedHTTPHeaders-(726)]
	_ = x[ErrUnexpectedTableEngine-(727)]
	_ = x[ErrUnexpectedDataType-(728)]
	_ = x[ErrIllegalTimeSeriesTags-(729)]
	_ = x[ErrRefreshFailed-(730)]
	_ = x[ErrQueryCacheUsedWithNonThrowOverflowMode-(731)]
	_ = x[ErrTableIsBeingRestarted-(733)]
	_ = x[ErrCannotWriteAfterBufferCanceled-(734)]
	_ = x[ErrQueryWasCancelledByClient-(735)]
	_ = x[ErrDatalakeDatabaseError-(736)]
	_ = x[ErrGoogleCloudError-(737)]
	_ = x[ErrPartIsLocked-(738)]
	_ = x[ErrBuzzhouse-(739)]
	_ = x[ErrPotentiallyBrokenDataPart-(740)]
	_ = x[ErrTableUUIDMismatch-(741)]
	_ = x[ErrDeltaKernelError-(742)]
	_ = x[ErrIcebergSpecificationViolation-(743)]
	_ = x[ErrSessionIDEmpty-(744)]
	_ = x[ErrServerOverloaded-(745)]
	_ = x[ErrDependenciesNotFound-(746)]
	_ = x[ErrFilecacheCannotWriteThroughCacheWithConcurrentReads-(747)]
	_ = x[ErrDistributedCacheError-(900)]
	_ = x[ErrCannotUseDistributedCache-(901)]
	_ = x[ErrProtocolVersionMismatch-(902)]
	_ = x[ErrLicenseExpired-(903)]
	_ = x[ErrKeeperException-(999)]
	_ = x[ErrPocoException-(1000)]
	_ = x[ErrStdException-(1001)]
	_ = x[ErrUnknownException-(1002)]
	_ = x[ErrSSHException-(1003)]
	_ = x[ErrStartupScriptsError-(1004)]
	_ = x[ErrConditionalTreeParentNotFound-(2001)]
	_ = x[ErrIllegalProjectionManipulator-(2002)]
}

var _ErrorValues = []Error{ErrUnsupportedMethod, ErrUnsupportedParameter, ErrUnexpectedEndOfFile, ErrExpectedEndOfFile, ErrCannotParseText, ErrIncorrectNumberOfColumns, ErrThereIsNoColumn, ErrSizesOfColumnsDoesntMatch, ErrNotFoundColumnInBlock, ErrPositionOutOfBound, ErrParameterOutOfBound, ErrSizesOfColumnsInTupleDoesntMatch, ErrDuplicateColumn, ErrNoSuchColumnInTable, ErrDelimiterInStringLiteralDoesntMatch, ErrCannotInsertElementIntoConstantColumn, ErrSizeOfFixedStringDoesntMatch, ErrNumberOfColumnsDoesntMatch, ErrCannotReadAllDataFromTabSeparatedInput, ErrCannotParseAllValueFromTabSeparatedInput, ErrCannotReadFromIstream, ErrCannotWriteToOstream, ErrCannotParseEscapeSequence, ErrCannotParseQuotedString, ErrCannotParseInputAssertionFailed, ErrCannotPrintFloatOrDoubleNumber, ErrCannotPrintInteger, ErrCannotReadSizeOfCompressedChunk, ErrCannotReadCompressedChunk, ErrAttemptToReadAfterEOF, ErrCannotReadAllData, ErrTooManyArgumentsForFunction, ErrTooFewArgumentsForFunction, ErrBadArguments, ErrUnknownElementInAst, ErrCannotParseDate, ErrTooLargeSizeCompressed, ErrChecksumDoesntMatch, ErrCannotParseDatetime, ErrNumberOfArgumentsDoesntMatch, ErrIllegalTypeOfArgument, ErrIllegalColumn, ErrIllegalNumberOfResultColumns, ErrUnknownFunction, ErrUnknownIdentifier, ErrNotImplemented, ErrLogicalError, ErrUnknownType, ErrEmptyListOfColumnsQueried, ErrColumnQueriedMoreThanOnce, ErrTypeMismatch, ErrStorageDoesntAllowParameters, ErrStorageRequiresParameter, ErrUnknownStorage, ErrTableAlreadyExists, ErrTableMetadataAlreadyExists, ErrIllegalTypeOfColumnForFilter, ErrUnknownTable, ErrOnlyFilterColumnInBlock, ErrSyntaxError, ErrUnknownAggregateFunction, ErrCannotReadAggregateFunctionFromText, ErrCannotWriteAggregateFunctionAsText, ErrNotAColumn, ErrIllegalKeyOfAggregation, ErrCannotGetSizeOfField, ErrArgumentOutOfBound, ErrCannotConvertType, ErrCannotWriteAfterEndOfBuffer, ErrCannotParseNumber, ErrUnknownFormat, ErrCannotReadFromFileDescriptor, ErrCannotWriteToFileDescriptor, ErrCannotOpenFile, ErrCannotCloseFile, ErrUnknownTypeOfQuery, ErrIncorrectFileName, ErrIncorrectQuery, ErrUnknownDatabase, ErrDatabaseAlreadyExists, ErrDirectoryDoesntExist, ErrDirectoryAlreadyExists, ErrFormatIsNotSuitableForInput, ErrReceivedErrorFromRemoteIoServer, ErrCannotSeekThroughFile, ErrCannotTruncateFile, ErrUnknownCompressionMethod, ErrEmptyListOfColumnsPassed, ErrSizesOfMarksFilesAreInconsistent, ErrEmptyDataPassed, ErrUnknownAggregatedDataVariant, ErrCannotMergeDifferentAggregatedDataVariants, ErrCannotReadFromSocket, ErrCannotWriteToSocket, ErrCannotReadAllDataFromChunkedInput, ErrCannotWriteToEmptyBlockOutputStream, ErrUnknownPacketFromClient, ErrUnknownPacketFromServer, ErrUnexpectedPacketFromClient, ErrUnexpectedPacketFromServer, ErrReceivedDataForWrongQueryID, ErrTooSmallBufferSize, ErrCannotReadHistory, ErrCannotAppendHistory, ErrFileDoesntExist, ErrNoDataToInsert, ErrCannotBlockSignal, ErrCannotUnblockSignal, ErrCannotManipulateSigset, ErrCannotWaitForSignal, ErrThereIsNoSession, ErrCannotClockGettime, ErrUnknownSetting, ErrThereIsNoDefaultValue, ErrIncorrectData, ErrEngineRequired, ErrCannotInsertValueOfDifferentSizeIntoTuple, ErrUnsupportedJoinKeys, ErrIncompatibleColumns, ErrUnknownTypeOfAstNode, ErrIncorrectElementOfSet, ErrIncorrectResultOfScalarSubquery, ErrCannotGetReturnType, ErrIllegalIndex, ErrTooLargeArraySize, ErrFunctionIsSpecial, ErrCannotReadArrayFromText, ErrTooLargeStringSize, ErrCannotCreateTableFromMetadata, ErrAggregateFunctionDoesntAllowParameters, ErrParametersToAggregateFunctionsMustBeLiterals, ErrZeroArrayOrTupleIndex, ErrUnknownElementInConfig, ErrExcessiveElementInConfig, ErrNoElementsInConfig, ErrAllRequestedColumnsAreMissing, ErrSamplingNotSupported, ErrNotFoundNode, ErrFoundMoreThanOneNode, ErrFirstDateIsBiggerThanLastDate, ErrUnknownOverflowMode, ErrQuerySectionDoesntMakeSense, ErrNotFoundFunctionElementForAggregate, ErrNotFoundRelationElementForCondition, ErrNotFoundRHSElementForCondition, ErrNoAttributesListed, ErrIndexOfColumnInSortClauseIsOutOfRange, ErrUnknownDirectionOfSorting, ErrIllegalDivision, ErrAggregateFunctionNotApplicable, ErrUnknownRelation, ErrDictionariesWasNotLoaded, ErrIllegalOverflowMode, ErrTooManyRows, ErrTimeoutExceeded, ErrTooSlow, ErrTooManyColumns, ErrTooDeepSubqueries, ErrTooDeepPipeline, ErrReadonly, ErrTooManyTemporaryColumns, ErrTooManyTemporaryNonConstColumns, ErrTooDeepAst, ErrTooBigAst, ErrBadTypeOfField, ErrBadGet, ErrBlocksHaveDifferentStructure, ErrCannotCreateDirectory, ErrCannotAllocateMemory, ErrCyclicAliases, ErrChunkNotFound, ErrDuplicateChunkName, ErrMultipleAliasesForExpression, ErrMultipleExpressionsForAlias, ErrThereIsNoProfile, ErrIllegalFinal, ErrIllegalPrewhere, ErrUnexpectedExpression, ErrIllegalAggregation, ErrUnsupportedMyisamBlockType, ErrUnsupportedCollationLocale, ErrCollationComparisonFailed, ErrUnknownAction, ErrTableMustNotBeCreatedManually, ErrSizesOfArraysDontMatch, ErrSetSizeLimitExceeded, ErrUnknownUser, ErrWrongPassword, ErrRequiredPassword, ErrIPAddressNotAllowed, ErrUnknownAddressPatternType, ErrServerRevisionIsTooOld, ErrDNSError, ErrUnknownQuota, ErrQuotaDoesntAllowKeys, ErrQuotaExpired, ErrTooManySimultaneousQueries, ErrNoFreeConnection, ErrCannotFsync, ErrNestedTypeTooDeep, ErrAliasRequired, ErrAmbiguousIdentifier, ErrEmptyNestedTable, ErrSocketTimeout, ErrNetworkError, ErrEmptyQuery, ErrUnknownLoadBalancing, ErrUnknownTotalsMode, ErrCannotStatvfs, ErrNotAnAggregate, ErrQueryWithSameIDIsAlreadyRunning, ErrClientHasConnectedToWrongPort, ErrTableIsDropped, ErrDatabaseNotEmpty, ErrDuplicateInterserverIOEndpoint, ErrNoSuchInterserverIoEndpoint, ErrAddingReplicaToNonEmptyTable, ErrUnexpectedAstStructure, ErrReplicaIsAlreadyActive, ErrNoZookeeper, ErrNoFileInDataPart, ErrUnexpectedFileInDataPart, ErrBadSizeOfFileInDataPart, ErrQueryIsTooLarge, ErrNotFoundExpectedDataPart, ErrTooManyUnexpectedDataParts, ErrNoSuchDataPart, ErrBadDataPartName, ErrNoReplicaHasPart, ErrDuplicateDataPart, ErrAborted, ErrNoReplicaNameGiven, ErrFormatVersionTooOld, ErrCannotMunmap, ErrCannotMremap, ErrMemoryLimitExceeded, ErrTableIsReadOnly, ErrNotEnoughSpace, ErrUnexpectedZookeeperError, ErrCorruptedData, ErrIncorrectMark, ErrInvalidPartitionValue, ErrNotEnoughBlockNumbers, ErrNoSuchReplica, ErrTooManyParts, ErrReplicaIsAlreadyExist, ErrNoActiveReplicas, ErrTooManyRetriesToFetchParts, ErrPartitionAlreadyExists, ErrPartitionDoesntExist, ErrUnionAllResultStructuresMismatch, ErrClientOutputFormatSpecified, ErrUnknownBlockInfoField, ErrBadCollation, ErrCannotCompileCode, ErrIncompatibleTypeOfJoin, ErrNoAvailableReplica, ErrMismatchReplicasDataSources, ErrStorageDoesntSupportParallelReplicas, ErrCPUIDError, ErrInfiniteLoop, ErrCannotCompress, ErrCannotDecompress, ErrCannotIOSubmit, ErrCannotIOGetevents, ErrAioReadError, ErrAioWriteError, ErrIndexNotUsed, ErrLeadershipLost, ErrAllConnectionTriesFailed, ErrNoAvailableData, ErrDictionaryIsEmpty, ErrIncorrectIndex, ErrUnknownDistributedProductMode, ErrWrongGlobalSubquery, ErrTooFewLiveReplicas, ErrUnsatisfiedQuorumForPreviousWrite, ErrUnknownFormatVersion, ErrDistributedInJoinSubqueryDenied, ErrReplicaIsNotInQuorum, ErrLimitExceeded, ErrDatabaseAccessDenied, ErrLeadershipChanged, ErrMongodbCannotAuthenticate, ErrCannotWriteToFile, ErrReceivedEmptyData, ErrNoRemoteShardFound, ErrShardHasNoConnections, ErrCannotPipe, ErrCannotFork, ErrCannotDlsym, ErrCannotCreateChildProcess, ErrChildWasNotExitedNormally, ErrCannotSelect, ErrCannotWaitpid, ErrTableWasNotDropped, ErrTooDeepRecursion, ErrTooManyBytes, ErrUnexpectedNodeInZookeeper, ErrFunctionCannotHaveParameters, ErrInvalidShardWeight, ErrInvalidConfigParameter, ErrUnknownStatusOfInsert, ErrValueIsOutOfRangeOfDataType, ErrBarrierTimeout, ErrUnknownDatabaseEngine, ErrDdlGuardIsActive, ErrUnfinished, ErrMetadataMismatch, ErrSupportIsDisabled, ErrTableDiffersTooMuch, ErrCannotConvertCharset, ErrCannotLoadConfig, ErrCannotInsertNullInOrdinaryColumn, ErrIncompatibleSourceTables, ErrAmbiguousTableName, ErrAmbiguousColumnName, ErrIndexOfPositionalArgumentIsOutOfRange, ErrZlibInflateFailed, ErrZlibDeflateFailed, ErrBadLambda, ErrReservedIdentifierName, ErrIntoOutfileNotAllowed, ErrTableSizeExceedsMaxDropSizeLimit, ErrCannotCreateCharsetConverter, ErrSeekPositionOutOfBound, ErrCurrentWriteBufferIsExhausted, ErrCannotCreateIoBuffer, ErrReceivedErrorTooManyRequests, ErrOutputIsNotSorted, ErrSizesOfNestedColumnsAreInconsistent, ErrTooManyFetches, ErrBadCast, ErrAllReplicasAreStale, ErrDataTypeCannotBeUsedInTables, ErrInconsistentClusterDefinition, ErrSessionNotFound, ErrSessionIsLocked, ErrInvalidSessionTimeout, ErrCannotDlopen, ErrCannotParseUUID, ErrIllegalSyntaxForDataType, ErrDataTypeCannotHaveArguments, ErrUnknownStatusOfDistributedDdlTask, ErrCannotKill, ErrHTTPLengthRequired, ErrCannotLoadCatboostModel, ErrCannotApplyCatboostModel, ErrPartIsTemporarilyLocked, ErrMultipleStreamsRequired, ErrNoCommonType, ErrExternalLoadableAlreadyExists, ErrCannotAssignOptimize, ErrInsertWasDeduplicated, ErrCannotGetCreateTableQuery, ErrExternalLibraryError, ErrQueryIsProhibited, ErrThereIsNoQuery, ErrQueryWasCancelled, ErrFunctionThrowIfValueIsNonZero, ErrTooManyRowsOrBytes, ErrQueryIsNotSupportedInMaterializedView, ErrUnknownMutationCommand, ErrFormatIsNotSuitableForOutput, ErrCannotStat, ErrFeatureIsNotEnabledAtBuildTime, ErrCannotIosetup, ErrInvalidJoinOnExpression, ErrBadOdbcConnectionString, ErrTopAndLimitTogether, ErrDecimalOverflow, ErrBadRequestParameter, ErrExternalServerIsNotResponding, ErrPthreadError, ErrNetlinkError, ErrCannotSetSignalHandler, ErrAllReplicasLost, ErrReplicaStatusChanged, ErrExpectedAllOrAny, ErrUnknownJoin, ErrMultipleAssignmentsToColumn, ErrCannotUpdateColumn, ErrCannotAddDifferentAggregateStates, ErrUnsupportedURIScheme, ErrCannotGettimeofday, ErrCannotLink, ErrSystemError, ErrCannotCompileRegexp, ErrFailedToGetpwuid, ErrMismatchingUsersForProcessAndData, ErrIllegalSyntaxForCodecType, ErrUnknownCodec, ErrIllegalCodecParameter, ErrCannotParseProtobufSchema, ErrNoColumnSerializedToRequiredProtobufField, ErrProtobufBadCast, ErrProtobufFieldNotRepeated, ErrDataTypeCannotBePromoted, ErrCannotScheduleTask, ErrInvalidLimitExpression, ErrCannotParseDomainValueFromString, ErrBadDatabaseForTemporaryTable, ErrNoColumnsSerializedToProtobufFields, ErrUnknownProtobufFormat, ErrCannotMprotect, ErrFunctionNotAllowed, ErrHyperscanCannotScanText, ErrBrotliReadFailed, ErrBrotliWriteFailed, ErrBadTTLExpression, ErrBadTTLFile, ErrSettingConstraintViolation, ErrMysqlClientInsufficientCapabilities, ErrOpensslError, ErrSuspiciousTypeForLowCardinality, ErrUnknownQueryParameter, ErrBadQueryParameter, ErrCannotUnlink, ErrCannotSetThreadPriority, ErrCannotCreateTimer, ErrCannotSetTimerPeriod, ErrCannotFcntl, ErrCannotParseElf, ErrCannotParseDwarf, ErrInsecurePath, ErrCannotParseBool, ErrCannotPthreadAttr, ErrViolatedConstraint, ErrInvalidSettingValue, ErrReadonlySetting, ErrDeadlockAvoided, ErrInvalidTemplateFormat, ErrInvalidWithFillExpression, ErrWithTiesWithoutOrderBy, ErrInvalidUsageOfInput, ErrUnknownPolicy, ErrUnknownDisk, ErrUnknownProtocol, ErrPathAccessDenied, ErrDictionaryAccessDenied, ErrTooManyRedirects, ErrInternalRedisError, ErrCannotGetCreateDictionaryQuery, ErrIncorrectDictionaryDefinition, ErrCannotFormatDatetime, ErrUnacceptableURL, ErrAccessEntityNotFound, ErrAccessEntityAlreadyExists, ErrAccessStorageReadonly, ErrQuotaRequiresClientKey, ErrAccessDenied, ErrLimitByWithTiesIsNotSupported, ErrS3Error, ErrAzureBlobStorageError, ErrCannotCreateDatabase, ErrCannotSigqueue, ErrAggregateFunctionThrow, ErrFileAlreadyExists, ErrUnableToSkipUnusedShards, ErrUnknownAccessType, ErrInvalidGrant, ErrCacheDictionaryUpdateFail, ErrUnknownRole, ErrSetNonGrantedRole, ErrUnknownPartType, ErrAccessStorageForInsertionNotFound, ErrIncorrectAccessEntityDefinition, ErrAuthenticationFailed, ErrCannotAssignAlter, ErrCannotCommitOffset, ErrNoRemoteShardAvailable, ErrCannotDetachDictionaryAsTable, ErrAtomicRenameFail, ErrUnknownRowPolicy, ErrAlterOfColumnIsForbidden, ErrIncorrectDiskIndex, ErrNoSuitableFunctionImplementation, ErrCassandraInternalError, ErrNotALeader, ErrCannotConnectRabbitmq, ErrCannotFstat, ErrLdapError, ErrUnknownRaidType, ErrCannotRestoreFromFieldDump, ErrIllegalMysqlVariable, ErrMysqlSyntaxError, ErrCannotBindRabbitmqExchange, ErrCannotDeclareRabbitmqExchange, ErrCannotCreateRabbitmqQueueBinding, ErrCannotRemoveRabbitmqExchange, ErrUnknownMysqlDatatypesSupportLevel, ErrRowAndRowsTogether, ErrFirstAndNextTogether, ErrNoRowDelimiter, ErrInvalidRaidType, ErrUnknownVolume, ErrDataTypeCannotBeUsedInKey, ErrUnrecognizedArguments, ErrLzmaStreamEncoderFailed, ErrLzmaStreamDecoderFailed, ErrRocksdbError, ErrSyncMysqlUserAccessError, ErrUnknownUnion, ErrExpectedAllOrDistinct, ErrInvalidGrpcQueryInfo, ErrZstdEncoderFailed, ErrZstdDecoderFailed, ErrTldListNotFound, ErrCannotReadMapFromText, ErrInterserverSchemeDoesntMatch, ErrTooManyPartitions, ErrCannotRmdir, ErrDuplicatedPartUuids, ErrRaftError, ErrMultipleColumnsSerializedToSameProtobufField, ErrDataTypeIncompatibleWithProtobufField, ErrDatabaseReplicationFailed, ErrTooManyQueryPlanOptimizations, ErrEpollError, ErrDistributedTooManyPendingBytes, ErrUnknownSnapshot, ErrKerberosError, ErrInvalidShardID, ErrInvalidFormatInsertQueryWithData, ErrIncorrectPartType, ErrCannotSetRoundingMode, ErrTooLargeDistributedDepth, ErrNoSuchProjectionInTable, ErrIllegalProjection, ErrProjectionNotUsed, ErrCannotParseYaml, ErrCannotCreateFile, ErrConcurrentAccessNotSupported, ErrDistributedBrokenBatchInfo, ErrDistributedBrokenBatchFiles, ErrCannotSysconf, ErrSqliteEngineError, ErrDataEncryptionError, ErrZeroCopyReplicationError, ErrBzip2StreamDecoderFailed, ErrBzip2StreamEncoderFailed, ErrIntersectOrExceptResultStructuresMismatch, ErrNoSuchErrorCode, ErrBackupAlreadyExists, ErrBackupNotFound, ErrBackupVersionNotSupported, ErrBackupDamaged, ErrNoBaseBackup, ErrWrongBaseBackup, ErrBackupEntryAlreadyExists, ErrBackupEntryNotFound, ErrBackupIsEmpty, ErrCannotRestoreDatabase, ErrCannotRestoreTable, ErrFunctionAlreadyExists, ErrCannotDropFunction, ErrCannotCreateRecursiveFunction, ErrPostgresqlConnectionFailure, ErrCannotAdvise, ErrUnknownReadMethod, ErrLz4EncoderFailed, ErrLz4DecoderFailed, ErrPostgresqlReplicationInternalError, ErrQueryNotAllowed, ErrCannotNormalizeString, ErrCannotParseCapnProtoSchema, ErrCapnProtoBadCast, ErrBadFileType, ErrIOSetupError, ErrCannotSkipUnknownField, ErrBackupEngineNotFound, ErrOffsetFetchWithoutOrderBy, ErrHTTPRangeNotSatisfiable, ErrHaveDependentObjects, ErrUnknownFileSize, ErrUnexpectedDataAfterParsedValue, ErrQueryIsNotSupportedInWindowView, ErrMongodbError, ErrCannotPoll, ErrCannotExtractTableStructure, ErrInvalidTableOverride, ErrSnappyUncompressFailed, ErrSnappyCompressFailed, ErrNoHivemetastore, ErrCannotAppendToFile, ErrCannotPackArchive, ErrCannotUnpackArchive, ErrNumberOfDimensionsMismatched, ErrCannotBackupTable, ErrWrongDdlRenamingSettings, ErrInvalidTransaction, ErrSerializationError, ErrCapnProtoBadType, ErrOnlyNullsWhileReadingSchema, ErrCannotParseBackupSettings, ErrWrongBackupSettings, ErrFailedToSyncBackupOrRestore, ErrUnknownStatusOfTransaction, ErrHdfsError, ErrCannotSendSignal, ErrFsMetadataError, ErrInconsistentMetadataForBackup, ErrAccessStorageDoesntAllowBackup, ErrCannotConnectNats, ErrNotInitialized, ErrInvalidState, ErrNamedCollectionDoesntExist, ErrNamedCollectionAlreadyExists, ErrNamedCollectionIsImmutable, ErrInvalidSchedulerNode, ErrResourceAccessDenied, ErrResourceNotFound, ErrCannotParseIpv4, ErrCannotParseIpv6, ErrThreadWasCanceled, ErrIOUringInitFailed, ErrIOUringSubmitError, ErrMixedAccessParameterTypes, ErrUnknownElementOfEnum, ErrTooManyMutations, ErrAwsError, ErrAsyncLoadCycle, ErrAsyncLoadFailed, ErrAsyncLoadCanceled, ErrCannotRestoreToNonencryptedDisk, ErrInvalidRedisStorageType, ErrInvalidRedisTableStructure, ErrUserSessionLimitExceeded, ErrClusterDoesntExist, ErrClientInfoDoesNotMatch, ErrInvalidIdentifier, ErrQueryCacheUsedWithNondeterministicFunctions, ErrTableNotEmpty, ErrLibsshError, ErrGcpError, ErrIllegalStatistics, ErrCannotGetReplicatedDatabaseSnapshot, ErrFaultInjected, ErrFilecacheAccessDenied, ErrTooManyMaterializedViews, ErrBrokenProjection, ErrUnexpectedCluster, ErrCannotDetectFormat, ErrCannotForgetPartition, ErrExperimentalFeatureError, ErrTooSlowParsing, ErrQueryCacheUsedWithSystemTable, ErrUserExpired, ErrDeprecatedFunction, ErrAsyncLoadWaitFailed, ErrParquetException, ErrTooManyTables, ErrTooManyDatabases, ErrUnexpectedHTTPHeaders, ErrUnexpectedTableEngine, ErrUnexpectedDataType, ErrIllegalTimeSeriesTags, ErrRefreshFailed, ErrQueryCacheUsedWithNonThrowOverflowMode, ErrTableIsBeingRestarted, ErrCannotWriteAfterBufferCanceled, ErrQueryWasCancelledByClient, ErrDatalakeDatabaseError, ErrGoogleCloudError, ErrPartIsLocked, ErrBuzzhouse, ErrPotentiallyBrokenDataPart, ErrTableUUIDMismatch, ErrDeltaKernelError, ErrIcebergSpecificationViolation, ErrSessionIDEmpty, ErrServerOverloaded, ErrDependenciesNotFound, ErrFilecacheCannotWriteThroughCacheWithConcurrentReads, ErrDistributedCacheError, ErrCannotUseDistributedCache, ErrProtocolVersionMismatch, ErrLicenseExpired, ErrKeeperException, ErrPocoException, ErrStdException, ErrUnknownException, ErrSSHException, ErrStartupScriptsError, ErrConditionalTreeParentNotFound, ErrIllegalProjectionManipulator}

var _ErrorNameToValueMap = map[string]Error{
	_ErrorName[0:18]:             ErrUnsupportedMethod,
	_ErrorLowerName[0:18]:        ErrUnsupportedMethod,
	_ErrorName[18:39]:            ErrUnsupportedParameter,
	_ErrorLowerName[18:39]:       ErrUnsupportedParameter,
	_ErrorName[39:61]:            ErrUnexpectedEndOfFile,
	_ErrorLowerName[39:61]:       ErrUnexpectedEndOfFile,
	_ErrorName[61:81]:            ErrExpectedEndOfFile,
	_ErrorLowerName[61:81]:       ErrExpectedEndOfFile,
	_ErrorName[81:98]:            ErrCannotParseText,
	_ErrorLowerName[81:98]:       ErrCannotParseText,
	_ErrorName[98:125]:           ErrIncorrectNumberOfColumns,
	_ErrorLowerName[98:125]:      ErrIncorrectNumberOfColumns,
	_ErrorName[125:143]:          ErrThereIsNoColumn,
	_ErrorLowerName[125:143]:     ErrThereIsNoColumn,
	_ErrorName[143:172]:          ErrSizesOfColumnsDoesntMatch,
	_ErrorLowerName[143:172]:     ErrSizesOfColumnsDoesntMatch,
	_ErrorName[172:197]:          ErrNotFoundColumnInBlock,
	_ErrorLowerName[172:197]:     ErrNotFoundColumnInBlock,
	_ErrorName[197:218]:          ErrPositionOutOfBound,
	_ErrorLowerName[197:218]:     ErrPositionOutOfBound,
	_ErrorName[218:240]:          ErrParameterOutOfBound,
	_ErrorLowerName[218:240]:     ErrParameterOutOfBound,
	_ErrorName[240:278]:          ErrSizesOfColumnsInTupleDoesntMatch,
	_ErrorLowerName[240:278]:     ErrSizesOfColumnsInTupleDoesntMatch,
	_ErrorName[278:294]:          ErrDuplicateColumn,
	_ErrorLowerName[278:294]:     ErrDuplicateColumn,
	_ErrorName[294:317]:          ErrNoSuchColumnInTable,
	_ErrorLowerName[294:317]:     ErrNoSuchColumnInTable,
	_ErrorName[317:357]:          ErrDelimiterInStringLiteralDoesntMatch,
	_ErrorLowerName[317:357]:     ErrDelimiterInStringLiteralDoesntMatch,
	_ErrorName[357:399]:          ErrCannotInsertElementIntoConstantColumn,
	_ErrorLowerName[357:399]:     ErrCannotInsertElementIntoConstantColumn,
	_ErrorName[399:432]:          ErrSizeOfFixedStringDoesntMatch,
	_ErrorLowerName[399:432]:     ErrSizeOfFixedStringDoesntMatch,
	_ErrorName[432:462]:          ErrNumberOfColumnsDoesntMatch,
	_ErrorLowerName[432:462]:     ErrNumberOfColumnsDoesntMatch,
	_ErrorName[462:507]:          ErrCannotReadAllDataFromTabSeparatedInput,
	_ErrorLowerName[462:507]:     ErrCannotReadAllDataFromTabSeparatedInput,
	_ErrorName[507:554]:          ErrCannotParseAllValueFromTabSeparatedInput,
	_ErrorLowerName[507:554]:     ErrCannotParseAllValueFromTabSeparatedInput,
	_ErrorName[554:578]:          ErrCannotReadFromIstream,
	_ErrorLowerName[554:578]:     ErrCannotReadFromIstream,
	_ErrorName[578:601]:          ErrCannotWriteToOstream,
	_ErrorLowerName[578:601]:     ErrCannotWriteToOstream,
	_ErrorName[601:629]:          ErrCannotParseEscapeSequence,
	_ErrorLowerName[601:629]:     ErrCannotParseEscapeSequence,
	_ErrorName[629:655]:          ErrCannotParseQuotedString,
	_ErrorLowerName[629:655]:     ErrCannotParseQuotedString,
	_ErrorName[655:690]:          ErrCannotParseInputAssertionFailed,
	_ErrorLowerName[655:690]:     ErrCannotParseInputAssertionFailed,
	_ErrorName[690:725]:          ErrCannotPrintFloatOrDoubleNumber,
	_ErrorLowerName[690:725]:     ErrCannotPrintFloatOrDoubleNumber,
	_ErrorName[725:745]:          ErrCannotPrintInteger,
	_ErrorLowerName[725:745]:     ErrCannotPrintInteger,
	_ErrorName[745:781]:          ErrCannotReadSizeOfCompressedChunk,
	_ErrorLowerName[745:781]:     ErrCannotReadSizeOfCompressedChunk,
	_ErrorName[781:809]:          ErrCannotReadCompressedChunk,
	_ErrorLowerName[781:809]:     ErrCannotReadCompressedChunk,
	_ErrorName[809:834]:          ErrAttemptToReadAfterEOF,
	_ErrorLowerName[809:834]:     ErrAttemptToReadAfterEOF,
	_ErrorName[834:854]:          ErrCannotReadAllData,
	_ErrorLowerName[834:854]:     ErrCannotReadAllData,
	_ErrorName[854:885]:          ErrTooManyArgumentsForFunction,
	_ErrorLowerName[854:885]:     ErrTooManyArgumentsForFunction,
	_ErrorName[885:915]:          ErrTooFewArgumentsForFunction,
	_ErrorLowerName[885:915]:     ErrTooFewArgumentsForFunction,
	_ErrorName[915:928]:          ErrBadArguments,
	_ErrorLowerName[915:928]:     ErrBadArguments,
	_ErrorName[928:950]:          ErrUnknownElementInAst,
	_ErrorLowerName[928:950]:     ErrUnknownElementInAst,
	_ErrorName[950:967]:          ErrCannotParseDate,
	_ErrorLowerName[950:967]:     ErrCannotParseDate,
	_ErrorName[967:992]:          ErrTooLargeSizeCompressed,
	_ErrorLowerName[967:992]:     ErrTooLargeSizeCompressed,
	_ErrorName[992:1013]:         ErrChecksumDoesntMatch,
	_ErrorLowerName[992:1013]:    ErrChecksumDoesntMatch,
	_ErrorName[1013:1034]:        ErrCannotParseDatetime,
	_ErrorLowerName[1013:1034]:   ErrCannotParseDatetime,
	_ErrorName[1034:1066]:        ErrNumberOfArgumentsDoesntMatch,
	_ErrorLowerName[1034:1066]:   ErrNumberOfArgumentsDoesntMatch,
	_ErrorName[1066:1090]:        ErrIllegalTypeOfArgument,
	_ErrorLowerName[1066:1090]:   ErrIllegalTypeOfArgument,
	_ErrorName[1090:1104]:        ErrIllegalColumn,
	_ErrorLowerName[1090:1104]:   ErrIllegalColumn,
	_ErrorName[1104:1136]:        ErrIllegalNumberOfResultColumns,
	_ErrorLowerName[1104:1136]:   ErrIllegalNumberOfResultColumns,
	_ErrorName[1136:1152]:        ErrUnknownFunction,
	_ErrorLowerName[1136:1152]:   ErrUnknownFunction,
	_ErrorName[1152:1170]:        ErrUnknownIdentifier,
	_ErrorLowerName[1152:1170]:   ErrUnknownIdentifier,
	_ErrorName[1170:1185]:        ErrNotImplemented,
	_ErrorLowerName[1170:1185]:   ErrNotImplemented,
	_ErrorName[1185:1198]:        ErrLogicalError,
	_ErrorLowerName[1185:1198]:   ErrLogicalError,
	_ErrorName[1198:1210]:        ErrUnknownType,
	_ErrorLowerName[1198:1210]:   ErrUnknownType,
	_ErrorName[1210:1239]:        ErrEmptyListOfColumnsQueried,
	_ErrorLowerName[1210:1239]:   ErrEmptyListOfColumnsQueried,
	_ErrorName[1239:1268]:        ErrColumnQueriedMoreThanOnce,
	_ErrorLowerName[1239:1268]:   ErrColumnQueriedMoreThanOnce,
	_ErrorName[1268:1281]:        ErrTypeMismatch,
	_ErrorLowerName[1268:1281]:   ErrTypeMismatch,
	_ErrorName[1281:1312]:        ErrStorageDoesntAllowParameters,
	_ErrorLowerName[1281:1312]:   ErrStorageDoesntAllowParameters,
	_ErrorName[1312:1338]:        ErrStorageRequiresParameter,
	_ErrorLowerName[1312:1338]:   ErrStorageRequiresParameter,
	_ErrorName[1338:1353]:        ErrUnknownStorage,
	_ErrorLowerName[1338:1353]:   ErrUnknownStorage,
	_ErrorName[1353:1373]:        ErrTableAlreadyExists,
	_ErrorLowerName[1353:1373]:   ErrTableAlreadyExists,
	_ErrorName[1373:1402]:        ErrTableMetadataAlreadyExists,
	_ErrorLowerName[1373:1402]:   ErrTableMetadataAlreadyExists,
	_ErrorName[1402:1435]:        ErrIllegalTypeOfColumnForFilter,
	_ErrorLowerName[1402:1435]:   ErrIllegalTypeOfColumnForFilter,
	_ErrorName[1435:1448]:        ErrUnknownTable,
	_ErrorLowerName[1435:1448]:   ErrUnknownTable,
	_ErrorName[1448:1475]:        ErrOnlyFilterColumnInBlock,
	_ErrorLowerName[1448:1475]:   ErrOnlyFilterColumnInBlock,
	_ErrorName[1475:1487]:        ErrSyntaxError,
	_ErrorLowerName[1475:1487]:   ErrSyntaxError,
	_ErrorName[1487:1513]:        ErrUnknownAggregateFunction,
	_ErrorLowerName[1487:1513]:   ErrUnknownAggregateFunction,
	_ErrorName[1513:1553]:        ErrCannotReadAggregateFunctionFromText,
	_ErrorLowerName[1513:1553]:   ErrCannotReadAggregateFunctionFromText,
	_ErrorName[1553:1592]:        ErrCannotWriteAggregateFunctionAsText,
	_ErrorLowerName[1553:1592]:   ErrCannotWriteAggregateFunctionAsText,
	_ErrorName[1592:1604]:        ErrNotAColumn,
	_ErrorLowerName[1592:1604]:   ErrNotAColumn,
	_ErrorName[1604:1630]:        ErrIllegalKeyOfAggregation,
	_ErrorLowerName[1604:1630]:   ErrIllegalKeyOfAggregation,
	_ErrorName[1630:1654]:        ErrCannotGetSizeOfField,
	_ErrorLowerName[1630:1654]:   ErrCannotGetSizeOfField,
	_ErrorName[1654:1675]:        ErrArgumentOutOfBound,
	_ErrorLowerName[1654:1675]:   ErrArgumentOutOfBound,
	_ErrorName[1675:1694]:        ErrCannotConvertType,
	_ErrorLowerName[1675:1694]:   ErrCannotConvertType,
	_ErrorName[1694:1726]:        ErrCannotWriteAfterEndOfBuffer,
	_ErrorLowerName[1694:1726]:   ErrCannotWriteAfterEndOfBuffer,
	_ErrorName[1726:1745]:        ErrCannotParseNumber,
	_ErrorLowerName[1726:1745]:   ErrCannotParseNumber,
	_ErrorName[1745:1759]:        ErrUnknownFormat,
	_ErrorLowerName[1745:1759]:   ErrUnknownFormat,
	_ErrorName[1759:1791]:        ErrCannotReadFromFileDescriptor,
	_ErrorLowerName[1759:1791]:   ErrCannotReadFromFileDescriptor,
	_ErrorName[1791:1822]:        ErrCannotWriteToFileDescriptor,
	_ErrorLowerName[1791:1822]:   ErrCannotWriteToFileDescriptor,
	_ErrorName[1822:1838]:        ErrCannotOpenFile,
	_ErrorLowerName[1822:1838]:   ErrCannotOpenFile,
	_ErrorName[1838:1855]:        ErrCannotCloseFile,
	_ErrorLowerName[1838:1855]:   ErrCannotCloseFile,
	_ErrorName[1855:1876]:        ErrUnknownTypeOfQuery,
	_ErrorLowerName[1855:1876]:   ErrUnknownTypeOfQuery,
	_ErrorName[1876:1895]:        ErrIncorrectFileName,
	_ErrorLowerName[1876:1895]:   ErrIncorrectFileName,
	_ErrorName[1895:1910]:        ErrIncorrectQuery,
	_ErrorLowerName[1895:1910]:   ErrIncorrectQuery,
	_ErrorName[1910:1926]:        ErrUnknownDatabase,
	_ErrorLowerName[1910:1926]:   ErrUnknownDatabase,
	_ErrorName[1926:1949]:        ErrDatabaseAlreadyExists,
	_ErrorLowerName[1926:1949]:   ErrDatabaseAlreadyExists,
	_ErrorName[1949:1971]:        ErrDirectoryDoesntExist,
	_ErrorLowerName[1949:1971]:   ErrDirectoryDoesntExist,
	_ErrorName[1971:1995]:        ErrDirectoryAlreadyExists,
	_ErrorLowerName[1971:1995]:   ErrDirectoryAlreadyExists,
	_ErrorName[1995:2027]:        ErrFormatIsNotSuitableForInput,
	_ErrorLowerName[1995:2027]:   ErrFormatIsNotSuitableForInput,
	_ErrorName[2027:2063]:        ErrReceivedErrorFromRemoteIoServer,
	_ErrorLowerName[2027:2063]:   ErrReceivedErrorFromRemoteIoServer,
	_ErrorName[2063:2087]:        ErrCannotSeekThroughFile,
	_ErrorLowerName[2063:2087]:   ErrCannotSeekThroughFile,
	_ErrorName[2087:2107]:        ErrCannotTruncateFile,
	_ErrorLowerName[2087:2107]:   ErrCannotTruncateFile,
	_ErrorName[2107:2133]:        ErrUnknownCompressionMethod,
	_ErrorLowerName[2107:2133]:   ErrUnknownCompressionMethod,
	_ErrorName[2133:2161]:        ErrEmptyListOfColumnsPassed,
	_ErrorLowerName[2133:2161]:   ErrEmptyListOfColumnsPassed,
	_ErrorName[2161:2198]:        ErrSizesOfMarksFilesAreInconsistent,
	_ErrorLowerName[2161:2198]:   ErrSizesOfMarksFilesAreInconsistent,
	_ErrorName[2198:2215]:        ErrEmptyDataPassed,
	_ErrorLowerName[2198:2215]:   ErrEmptyDataPassed,
	_ErrorName[2215:2246]:        ErrUnknownAggregatedDataVariant,
	_ErrorLowerName[2215:2246]:   ErrUnknownAggregatedDataVariant,
	_ErrorName[2246:2293]:        ErrCannotMergeDifferentAggregatedDataVariants,
	_ErrorLowerName[2246:2293]:   ErrCannotMergeDifferentAggregatedDataVariants,
	_ErrorName[2293:2316]:        ErrCannotReadFromSocket,
	_ErrorLowerName[2293:2316]:   ErrCannotReadFromSocket,
	_ErrorName[2316:2338]:        ErrCannotWriteToSocket,
	_ErrorLowerName[2316:2338]:   ErrCannotWriteToSocket,
	_ErrorName[2338:2377]:        ErrCannotReadAllDataFromChunkedInput,
	_ErrorLowerName[2338:2377]:   ErrCannotReadAllDataFromChunkedInput,
	_ErrorName[2377:2418]:        ErrCannotWriteToEmptyBlockOutputStream,
	_ErrorLowerName[2377:2418]:   ErrCannotWriteToEmptyBlockOutputStream,
	_ErrorName[2418:2444]:        ErrUnknownPacketFromClient,
	_ErrorLowerName[2418:2444]:   ErrUnknownPacketFromClient,
	_ErrorName[2444:2470]:        ErrUnknownPacketFromServer,
	_ErrorLowerName[2444:2470]:   ErrUnknownPacketFromServer,
	_ErrorName[2470:2499]:        ErrUnexpectedPacketFromClient,
	_ErrorLowerName[2470:2499]:   ErrUnexpectedPacketFromClient,
	_ErrorName[2499:2528]:        ErrUnexpectedPacketFromServer,
	_ErrorLowerName[2499:2528]:   ErrUnexpectedPacketFromServer,
	_ErrorName[2528:2560]:        ErrReceivedDataForWrongQueryID,
	_ErrorLowerName[2528:2560]:   ErrReceivedDataForWrongQueryID,
	_ErrorName[2560:2581]:        ErrTooSmallBufferSize,
	_ErrorLowerName[2560:2581]:   ErrTooSmallBufferSize,
	_ErrorName[2581:2600]:        ErrCannotReadHistory,
	_ErrorLowerName[2581:2600]:   ErrCannotReadHistory,
	_ErrorName[2600:2621]:        ErrCannotAppendHistory,
	_ErrorLowerName[2600:2621]:   ErrCannotAppendHistory,
	_ErrorName[2621:2638]:        ErrFileDoesntExist,
	_ErrorLowerName[2621:2638]:   ErrFileDoesntExist,
	_ErrorName[2638:2655]:        ErrNoDataToInsert,
	_ErrorLowerName[2638:2655]:   ErrNoDataToInsert,
	_ErrorName[2655:2674]:        ErrCannotBlockSignal,
	_ErrorLowerName[2655:2674]:   ErrCannotBlockSignal,
	_ErrorName[2674:2695]:        ErrCannotUnblockSignal,
	_ErrorLowerName[2674:2695]:   ErrCannotUnblockSignal,
	_ErrorName[2695:2719]:        ErrCannotManipulateSigset,
	_ErrorLowerName[2695:2719]:   ErrCannotManipulateSigset,
	_ErrorName[2719:2741]:        ErrCannotWaitForSignal,
	_ErrorLowerName[2719:2741]:   ErrCannotWaitForSignal,
	_ErrorName[2741:2760]:        ErrThereIsNoSession,
	_ErrorLowerName[2741:2760]:   ErrThereIsNoSession,
	_ErrorName[2760:2780]:        ErrCannotClockGettime,
	_ErrorLowerName[2760:2780]:   ErrCannotClockGettime,
	_ErrorName[2780:2795]:        ErrUnknownSetting,
	_ErrorLowerName[2780:2795]:   ErrUnknownSetting,
	_ErrorName[2795:2820]:        ErrThereIsNoDefaultValue,
	_ErrorLowerName[2795:2820]:   ErrThereIsNoDefaultValue,
	_ErrorName[2820:2834]:        ErrIncorrectData,
	_ErrorLowerName[2820:2834]:   ErrIncorrectData,
	_ErrorName[2834:2849]:        ErrEngineRequired,
	_ErrorLowerName[2834:2849]:   ErrEngineRequired,
	_ErrorName[2849:2897]:        ErrCannotInsertValueOfDifferentSizeIntoTuple,
	_ErrorLowerName[2849:2897]:   ErrCannotInsertValueOfDifferentSizeIntoTuple,
	_ErrorName[2897:2918]:        ErrUnsupportedJoinKeys,
	_ErrorLowerName[2897:2918]:   ErrUnsupportedJoinKeys,
	_ErrorName[2918:2938]:        ErrIncompatibleColumns,
	_ErrorLowerName[2918:2938]:   ErrIncompatibleColumns,
	_ErrorName[2938:2962]:        ErrUnknownTypeOfAstNode,
	_ErrorLowerName[2938:2962]:   ErrUnknownTypeOfAstNode,
	_ErrorName[2962:2986]:        ErrIncorrectElementOfSet,
	_ErrorLowerName[2962:2986]:   ErrIncorrectElementOfSet,
	_ErrorName[2986:3021]:        ErrIncorrectResultOfScalarSubquery,
	_ErrorLowerName[2986:3021]:   ErrIncorrectResultOfScalarSubquery,
	_ErrorName[3021:3043]:        ErrCannotGetReturnType,
	_ErrorLowerName[3021:3043]:   ErrCannotGetReturnType,
	_ErrorName[3043:3056]:        ErrIllegalIndex,
	_ErrorLowerName[3043:3056]:   ErrIllegalIndex,
	_ErrorName[3056:3076]:        ErrTooLargeArraySize,
	_ErrorLowerName[3056:3076]:   ErrTooLargeArraySize,
	_ErrorName[3076:3095]:        ErrFunctionIsSpecial,
	_ErrorLowerName[3076:3095]:   ErrFunctionIsSpecial,
	_ErrorName[3095:3122]:        ErrCannotReadArrayFromText,
	_ErrorLowerName[3095:3122]:   ErrCannotReadArrayFromText,
	_ErrorName[3122:3143]:        ErrTooLargeStringSize,
	_ErrorLowerName[3122:3143]:   ErrTooLargeStringSize,
	_ErrorName[3143:3176]:        ErrCannotCreateTableFromMetadata,
	_ErrorLowerName[3143:3176]:   ErrCannotCreateTableFromMetadata,
	_ErrorName[3176:3218]:        ErrAggregateFunctionDoesntAllowParameters,
	_ErrorLowerName[3176:3218]:   ErrAggregateFunctionDoesntAllowParameters,
	_ErrorName[3218:3268]:        ErrParametersToAggregateFunctionsMustBeLiterals,
	_ErrorLowerName[3218:3268]:   ErrParametersToAggregateFunctionsMustBeLiterals,
	_ErrorName[3268:3293]:        ErrZeroArrayOrTupleIndex,
	_ErrorLowerName[3268:3293]:   ErrZeroArrayOrTupleIndex,
	_ErrorName[3293:3318]:        ErrUnknownElementInConfig,
	_ErrorLowerName[3293:3318]:   ErrUnknownElementInConfig,
	_ErrorName[3318:3345]:        ErrExcessiveElementInConfig,
	_ErrorLowerName[3318:3345]:   ErrExcessiveElementInConfig,
	_ErrorName[3345:3366]:        ErrNoElementsInConfig,
	_ErrorLowerName[3345:3366]:   ErrNoElementsInConfig,
	_ErrorName[3366:3399]:        ErrAllRequestedColumnsAreMissing,
	_ErrorLowerName[3366:3399]:   ErrAllRequestedColumnsAreMissing,
	_ErrorName[3399:3421]:        ErrSamplingNotSupported,
	_ErrorLowerName[3399:3421]:   ErrSamplingNotSupported,
	_ErrorName[3421:3435]:        ErrNotFoundNode,
	_ErrorLowerName[3421:3435]:   ErrNotFoundNode,
	_ErrorName[3435:3459]:        ErrFoundMoreThanOneNode,
	_ErrorLowerName[3435:3459]:   ErrFoundMoreThanOneNode,
	_ErrorName[3459:3494]:        ErrFirstDateIsBiggerThanLastDate,
	_ErrorLowerName[3459:3494]:   ErrFirstDateIsBiggerThanLastDate,
	_ErrorName[3494:3515]:        ErrUnknownOverflowMode,
	_ErrorLowerName[3494:3515]:   ErrUnknownOverflowMode,
	_ErrorName[3515:3546]:        ErrQuerySectionDoesntMakeSense,
	_ErrorLowerName[3515:3546]:   ErrQuerySectionDoesntMakeSense,
	_ErrorName[3546:3586]:        ErrNotFoundFunctionElementForAggregate,
	_ErrorLowerName[3546:3586]:   ErrNotFoundFunctionElementForAggregate,
	_ErrorName[3586:3626]:        ErrNotFoundRelationElementForCondition,
	_ErrorLowerName[3586:3626]:   ErrNotFoundRelationElementForCondition,
	_ErrorName[3626:3661]:        ErrNotFoundRHSElementForCondition,
	_ErrorLowerName[3626:3661]:   ErrNotFoundRHSElementForCondition,
	_ErrorName[3661:3681]:        ErrNoAttributesListed,
	_ErrorLowerName[3661:3681]:   ErrNoAttributesListed,
	_ErrorName[3681:3727]:        ErrIndexOfColumnInSortClauseIsOutOfRange,
	_ErrorLowerName[3681:3727]:   ErrIndexOfColumnInSortClauseIsOutOfRange,
	_ErrorName[3727:3755]:        ErrUnknownDirectionOfSorting,
	_ErrorLowerName[3727:3755]:   ErrUnknownDirectionOfSorting,
	_ErrorName[3755:3771]:        ErrIllegalDivision,
	_ErrorLowerName[3755:3771]:   ErrIllegalDivision,
	_ErrorName[3771:3804]:        ErrAggregateFunctionNotApplicable,
	_ErrorLowerName[3771:3804]:   ErrAggregateFunctionNotApplicable,
	_ErrorName[3804:3820]:        ErrUnknownRelation,
	_ErrorLowerName[3804:3820]:   ErrUnknownRelation,
	_ErrorName[3820:3847]:        ErrDictionariesWasNotLoaded,
	_ErrorLowerName[3820:3847]:   ErrDictionariesWasNotLoaded,
	_ErrorName[3847:3868]:        ErrIllegalOverflowMode,
	_ErrorLowerName[3847:3868]:   ErrIllegalOverflowMode,
	_ErrorName[3868:3881]:        ErrTooManyRows,
	_ErrorLowerName[3868:3881]:   ErrTooManyRows,
	_ErrorName[3881:3897]:        ErrTimeoutExceeded,
	_ErrorLowerName[3881:3897]:   ErrTimeoutExceeded,
	_ErrorName[3897:3905]:        ErrTooSlow,
	_ErrorLowerName[3897:3905]:   ErrTooSlow,
	_ErrorName[3905:3921]:        ErrTooManyColumns,
	_ErrorLowerName[3905:3921]:   ErrTooManyColumns,
	_ErrorName[3921:3940]:        ErrTooDeepSubqueries,
	_ErrorLowerName[3921:3940]:   ErrTooDeepSubqueries,
	_ErrorName[3940:3957]:        ErrTooDeepPipeline,
	_ErrorLowerName[3940:3957]:   ErrTooDeepPipeline,
	_ErrorName[3957:3965]:        ErrReadonly,
	_ErrorLowerName[3957:3965]:   ErrReadonly,
	_ErrorName[3965:3991]:        ErrTooManyTemporaryColumns,
	_ErrorLowerName[3965:3991]:   ErrTooManyTemporaryColumns,
	_ErrorName[3991:4027]:        ErrTooManyTemporaryNonConstColumns,
	_ErrorLowerName[3991:4027]:   ErrTooManyTemporaryNonConstColumns,
	_ErrorName[4027:4039]:        ErrTooDeepAst,
	_ErrorLowerName[4027:4039]:   ErrTooDeepAst,
	_ErrorName[4039:4050]:        ErrTooBigAst,
	_ErrorLowerName[4039:4050]:   ErrTooBigAst,
	_ErrorName[4050:4067]:        ErrBadTypeOfField,
	_ErrorLowerName[4050:4067]:   ErrBadTypeOfField,
	_ErrorName[4067:4074]:        ErrBadGet,
	_ErrorLowerName[4067:4074]:   ErrBadGet,
	_ErrorName[4074:4105]:        ErrBlocksHaveDifferentStructure,
	_ErrorLowerName[4074:4105]:   ErrBlocksHaveDifferentStructure,
	_ErrorName[4105:4128]:        ErrCannotCreateDirectory,
	_ErrorLowerName[4105:4128]:   ErrCannotCreateDirectory,
	_ErrorName[4128:4150]:        ErrCannotAllocateMemory,
	_ErrorLowerName[4128:4150]:   ErrCannotAllocateMemory,
	_ErrorName[4150:4164]:        ErrCyclicAliases,
	_ErrorLowerName[4150:4164]:   ErrCyclicAliases,
	_ErrorName[4164:4179]:        ErrChunkNotFound,
	_ErrorLowerName[4164:4179]:   ErrChunkNotFound,
	_ErrorName[4179:4199]:        ErrDuplicateChunkName,
	_ErrorLowerName[4179:4199]:   ErrDuplicateChunkName,
	_ErrorName[4199:4230]:        ErrMultipleAliasesForExpression,
	_ErrorLowerName[4199:4230]:   ErrMultipleAliasesForExpression,
	_ErrorName[4230:4260]:        ErrMultipleExpressionsForAlias,
	_ErrorLowerName[4230:4260]:   ErrMultipleExpressionsForAlias,
	_ErrorName[4260:4279]:        ErrThereIsNoProfile,
	_ErrorLowerName[4260:4279]:   ErrThereIsNoProfile,
	_ErrorName[4279:4292]:        ErrIllegalFinal,
	_ErrorLowerName[4279:4292]:   ErrIllegalFinal,
	_ErrorName[4292:4308]:        ErrIllegalPrewhere,
	_ErrorLowerName[4292:4308]:   ErrIllegalPrewhere,
	_ErrorName[4308:4329]:        ErrUnexpectedExpression,
	_ErrorLowerName[4308:4329]:   ErrUnexpectedExpression,
	_ErrorName[4329:4348]:        ErrIllegalAggregation,
	_ErrorLowerName[4329:4348]:   ErrIllegalAggregation,
	_ErrorName[4348:4377]:        ErrUnsupportedMyisamBlockType,
	_ErrorLowerName[4348:4377]:   ErrUnsupportedMyisamBlockType,
	_ErrorName[4377:4405]:        ErrUnsupportedCollationLocale,
	_ErrorLowerName[4377:4405]:   ErrUnsupportedCollationLocale,
	_ErrorName[4405:4432]:        ErrCollationComparisonFailed,
	_ErrorLowerName[4405:4432]:   ErrCollationComparisonFailed,
	_ErrorName[4432:4446]:        ErrUnknownAction,
	_ErrorLowerName[4432:4446]:   ErrUnknownAction,
	_ErrorName[4446:4480]:        ErrTableMustNotBeCreatedManually,
	_ErrorLowerName[4446:4480]:   ErrTableMustNotBeCreatedManually,
	_ErrorName[4480:4506]:        ErrSizesOfArraysDontMatch,
	_ErrorLowerName[4480:4506]:   ErrSizesOfArraysDontMatch,
	_ErrorName[4506:4529]:        ErrSetSizeLimitExceeded,
	_ErrorLowerName[4506:4529]:   ErrSetSizeLimitExceeded,
	_ErrorName[4529:4541]:        ErrUnknownUser,
	_ErrorLowerName[4529:4541]:   ErrUnknownUser,
	_ErrorName[4541:4555]:        ErrWrongPassword,
	_ErrorLowerName[4541:4555]:   ErrWrongPassword,
	_ErrorName[4555:4572]:        ErrRequiredPassword,
	_ErrorLowerName[4555:4572]:   ErrRequiredPassword,
	_ErrorName[4572:4594]:        ErrIPAddressNotAllowed,
	_ErrorLowerName[4572:4594]:   ErrIPAddressNotAllowed,
	_ErrorName[4594:4622]:        ErrUnknownAddressPatternType,
	_ErrorLowerName[4594:4622]:   ErrUnknownAddressPatternType,
	_ErrorName[4622:4648]:        ErrServerRevisionIsTooOld,
	_ErrorLowerName[4622:4648]:   ErrServerRevisionIsTooOld,
	_ErrorName[4648:4657]:        ErrDNSError,
	_ErrorLowerName[4648:4657]:   ErrDNSError,
	_ErrorName[4657:4670]:        ErrUnknownQuota,
	_ErrorLowerName[4657:4670]:   ErrUnknownQuota,
	_ErrorName[4670:4693]:        ErrQuotaDoesntAllowKeys,
	_ErrorLowerName[4670:4693]:   ErrQuotaDoesntAllowKeys,
	_ErrorName[4693:4706]:        ErrQuotaExpired,
	_ErrorLowerName[4693:4706]:   ErrQuotaExpired,
	_ErrorName[4706:4735]:        ErrTooManySimultaneousQueries,
	_ErrorLowerName[4706:4735]:   ErrTooManySimultaneousQueries,
	_ErrorName[4735:4753]:        ErrNoFreeConnection,
	_ErrorLowerName[4735:4753]:   ErrNoFreeConnection,
	_ErrorName[4753:4765]:        ErrCannotFsync,
	_ErrorLowerName[4753:4765]:   ErrCannotFsync,
	_ErrorName[4765:4785]:        ErrNestedTypeTooDeep,
	_ErrorLowerName[4765:4785]:   ErrNestedTypeTooDeep,
	_ErrorName[4785:4799]:        ErrAliasRequired,
	_ErrorLowerName[4785:4799]:   ErrAliasRequired,
	_ErrorName[4799:4819]:        ErrAmbiguousIdentifier,
	_ErrorLowerName[4799:4819]:   ErrAmbiguousIdentifier,
	_ErrorName[4819:4837]:        ErrEmptyNestedTable,
	_ErrorLowerName[4819:4837]:   ErrEmptyNestedTable,
	_ErrorName[4837:4851]:        ErrSocketTimeout,
	_ErrorLowerName[4837:4851]:   ErrSocketTimeout,
	_ErrorName[4851:4864]:        ErrNetworkError,
	_ErrorLowerName[4851:4864]:   ErrNetworkError,
	_ErrorName[4864:4875]:        ErrEmptyQuery,
	_ErrorLowerName[4864:4875]:   ErrEmptyQuery,
	_ErrorName[4875:4897]:        ErrUnknownLoadBalancing,
	_ErrorLowerName[4875:4897]:   ErrUnknownLoadBalancing,
	_ErrorName[4897:4916]:        ErrUnknownTotalsMode,
	_ErrorLowerName[4897:4916]:   ErrUnknownTotalsMode,
	_ErrorName[4916:4930]:        ErrCannotStatvfs,
	_ErrorLowerName[4916:4930]:   ErrCannotStatvfs,
	_ErrorName[4930:4946]:        ErrNotAnAggregate,
	_ErrorLowerName[4930:4946]:   ErrNotAnAggregate,
	_ErrorName[4946:4983]:        ErrQueryWithSameIDIsAlreadyRunning,
	_ErrorLowerName[4946:4983]:   ErrQueryWithSameIDIsAlreadyRunning,
	_ErrorName[4983:5017]:        ErrClientHasConnectedToWrongPort,
	_ErrorLowerName[4983:5017]:   ErrClientHasConnectedToWrongPort,
	_ErrorName[5017:5033]:        ErrTableIsDropped,
	_ErrorLowerName[5017:5033]:   ErrTableIsDropped,
	_ErrorName[5033:5051]:        ErrDatabaseNotEmpty,
	_ErrorLowerName[5033:5051]:   ErrDatabaseNotEmpty,
	_ErrorName[5051:5084]:        ErrDuplicateInterserverIOEndpoint,
	_ErrorLowerName[5051:5084]:   ErrDuplicateInterserverIOEndpoint,
	_ErrorName[5084:5115]:        ErrNoSuchInterserverIoEndpoint,
	_ErrorLowerName[5084:5115]:   ErrNoSuchInterserverIoEndpoint,
	_ErrorName[5115:5148]:        ErrAddingReplicaToNonEmptyTable,
	_ErrorLowerName[5115:5148]:   ErrAddingReplicaToNonEmptyTable,
	_ErrorName[5148:5172]:        ErrUnexpectedAstStructure,
	_ErrorLowerName[5148:5172]:   ErrUnexpectedAstStructure,
	_ErrorName[5172:5197]:        ErrReplicaIsAlreadyActive,
	_ErrorLowerName[5172:5197]:   ErrReplicaIsAlreadyActive,
	_ErrorName[5197:5209]:        ErrNoZookeeper,
	_ErrorLowerName[5197:5209]:   ErrNoZookeeper,
	_ErrorName[5209:5229]:        ErrNoFileInDataPart,
	_ErrorLowerName[5209:5229]:   ErrNoFileInDataPart,
	_ErrorName[5229:5257]:        ErrUnexpectedFileInDataPart,
	_ErrorLowerName[5229:5257]:   ErrUnexpectedFileInDataPart,
	_ErrorName[5257:5286]:        ErrBadSizeOfFileInDataPart,
	_ErrorLowerName[5257:5286]:   ErrBadSizeOfFileInDataPart,
	_ErrorName[5286:5304]:        ErrQueryIsTooLarge,
	_ErrorLowerName[5286:5304]:   ErrQueryIsTooLarge,
	_ErrorName[5304:5332]:        ErrNotFoundExpectedDataPart,
	_ErrorLowerName[5304:5332]:   ErrNotFoundExpectedDataPart,
	_ErrorName[5332:5362]:        ErrTooManyUnexpectedDataParts,
	_ErrorLowerName[5332:5362]:   ErrTooManyUnexpectedDataParts,
	_ErrorName[5362:5379]:        ErrNoSuchDataPart,
	_ErrorLowerName[5362:5379]:   ErrNoSuchDataPart,
	_ErrorName[5379:5397]:        ErrBadDataPartName,
	_ErrorLowerName[5379:5397]:   ErrBadDataPartName,
	_ErrorName[5397:5416]:        ErrNoReplicaHasPart,
	_ErrorLowerName[5397:5416]:   ErrNoReplicaHasPart,
	_ErrorName[5416:5435]:        ErrDuplicateDataPart,
	_ErrorLowerName[5416:5435]:   ErrDuplicateDataPart,
	_ErrorName[5435:5442]:        ErrAborted,
	_ErrorLowerName[5435:5442]:   ErrAborted,
	_ErrorName[5442:5463]:        ErrNoReplicaNameGiven,
	_ErrorLowerName[5442:5463]:   ErrNoReplicaNameGiven,
	_ErrorName[5463:5485]:        ErrFormatVersionTooOld,
	_ErrorLowerName[5463:5485]:   ErrFormatVersionTooOld,
	_ErrorName[5485:5498]:        ErrCannotMunmap,
	_ErrorLowerName[5485:5498]:   ErrCannotMunmap,
	_ErrorName[5498:5511]:        ErrCannotMremap,
	_ErrorLowerName[5498:5511]:   ErrCannotMremap,
	_ErrorName[5511:5532]:        ErrMemoryLimitExceeded,
	_ErrorLowerName[5511:5532]:   ErrMemoryLimitExceeded,
	_ErrorName[5532:5550]:        ErrTableIsReadOnly,
	_ErrorLowerName[5532:5550]:   ErrTableIsReadOnly,
	_ErrorName[5550:5566]:        ErrNotEnoughSpace,
	_ErrorLowerName[5550:5566]:   ErrNotEnoughSpace,
	_ErrorName[5566:5592]:        ErrUnexpectedZookeeperError,
	_ErrorLowerName[5566:5592]:   ErrUnexpectedZookeeperError,
	_ErrorName[5592:5606]:        ErrCorruptedData,
	_ErrorLowerName[5592:5606]:   ErrCorruptedData,
	_ErrorName[5606:5620]:        ErrIncorrectMark,
	_ErrorLowerName[5606:5620]:   ErrIncorrectMark,
	_ErrorName[5620:5643]:        ErrInvalidPartitionValue,
	_ErrorLowerName[5620:5643]:   ErrInvalidPartitionValue,
	_ErrorName[5643:5667]:        ErrNotEnoughBlockNumbers,
	_ErrorLowerName[5643:5667]:   ErrNotEnoughBlockNumbers,
	_ErrorName[5667:5682]:        ErrNoSuchReplica,
	_ErrorLowerName[5667:5682]:   ErrNoSuchReplica,
	_ErrorName[5682:5696]:        ErrTooManyParts,
	_ErrorLowerName[5682:5696]:   ErrTooManyParts,
	_ErrorName[5696:5720]:        ErrReplicaIsAlreadyExist,
	_ErrorLowerName[5696:5720]:   ErrReplicaIsAlreadyExist,
	_ErrorName[5720:5738]:        ErrNoActiveReplicas,
	_ErrorLowerName[5720:5738]:   ErrNoActiveReplicas,
	_ErrorName[5738:5769]:        ErrTooManyRetriesToFetchParts,
	_ErrorLowerName[5738:5769]:   ErrTooManyRetriesToFetchParts,
	_ErrorName[5769:5793]:        ErrPartitionAlreadyExists,
	_ErrorLowerName[5769:5793]:   ErrPartitionAlreadyExists,
	_ErrorName[5793:5815]:        ErrPartitionDoesntExist,
	_ErrorLowerName[5793:5815]:   ErrPartitionDoesntExist,
	_ErrorName[5815:5851]:        ErrUnionAllResultStructuresMismatch,
	_ErrorLowerName[5815:5851]:   ErrUnionAllResultStructuresMismatch,
	_ErrorName[5851:5881]:        ErrClientOutputFormatSpecified,
	_ErrorLowerName[5851:5881]:   ErrClientOutputFormatSpecified,
	_ErrorName[5881:5905]:        ErrUnknownBlockInfoField,
	_ErrorLowerName[5881:5905]:   ErrUnknownBlockInfoField,
	_ErrorName[5905:5918]:        ErrBadCollation,
	_ErrorLowerName[5905:5918]:   ErrBadCollation,
	_ErrorName[5918:5937]:        ErrCannotCompileCode,
	_ErrorLowerName[5918:5937]:   ErrCannotCompileCode,
	_ErrorName[5937:5962]:        ErrIncompatibleTypeOfJoin,
	_ErrorLowerName[5937:5962]:   ErrIncompatibleTypeOfJoin,
	_ErrorName[5962:5982]:        ErrNoAvailableReplica,
	_ErrorLowerName[5962:5982]:   ErrNoAvailableReplica,
	_ErrorName[5982:6012]:        ErrMismatchReplicasDataSources,
	_ErrorLowerName[5982:6012]:   ErrMismatchReplicasDataSources,
	_ErrorName[6012:6052]:        ErrStorageDoesntSupportParallelReplicas,
	_ErrorLowerName[6012:6052]:   ErrStorageDoesntSupportParallelReplicas,
	_ErrorName[6052:6063]:        ErrCPUIDError,
	_ErrorLowerName[6052:6063]:   ErrCPUIDError,
	_ErrorName[6063:6076]:        ErrInfiniteLoop,
	_ErrorLowerName[6063:6076]:   ErrInfiniteLoop,
	_ErrorName[6076:6091]:        ErrCannotCompress,
	_ErrorLowerName[6076:6091]:   ErrCannotCompress,
	_ErrorName[6091:6108]:        ErrCannotDecompress,
	_ErrorLowerName[6091:6108]:   ErrCannotDecompress,
	_ErrorName[6108:6124]:        ErrCannotIOSubmit,
	_ErrorLowerName[6108:6124]:   ErrCannotIOSubmit,
	_ErrorName[6124:6143]:        ErrCannotIOGetevents,
	_ErrorLowerName[6124:6143]:   ErrCannotIOGetevents,
	_ErrorName[6143:6157]:        ErrAioReadError,
	_ErrorLowerName[6143:6157]:   ErrAioReadError,
	_ErrorName[6157:6172]:        ErrAioWriteError,
	_ErrorLowerName[6157:6172]:   ErrAioWriteError,
	_ErrorName[6172:6186]:        ErrIndexNotUsed,
	_ErrorLowerName[6172:6186]:   ErrIndexNotUsed,
	_ErrorName[6186:6201]:        ErrLeadershipLost,
	_ErrorLowerName[6186:6201]:   ErrLeadershipLost,
	_ErrorName[6201:6228]:        ErrAllConnectionTriesFailed,
	_ErrorLowerName[6201:6228]:   ErrAllConnectionTriesFailed,
	_ErrorName[6228:6245]:        ErrNoAvailableData,
	_ErrorLowerName[6228:6245]:   ErrNoAvailableData,
	_ErrorName[6245:6264]:        ErrDictionaryIsEmpty,
	_ErrorLowerName[6245:6264]:   ErrDictionaryIsEmpty,
	_ErrorName[6264:6279]:        ErrIncorrectIndex,
	_ErrorLowerName[6264:6279]:   ErrIncorrectIndex,
	_ErrorName[6279:6311]:        ErrUnknownDistributedProductMode,
	_ErrorLowerName[6279:6311]:   ErrUnknownDistributedProductMode,
	_ErrorName[6311:6332]:        ErrWrongGlobalSubquery,
	_ErrorLowerName[6311:6332]:   ErrWrongGlobalSubquery,
	_ErrorName[6332:6353]:        ErrTooFewLiveReplicas,
	_ErrorLowerName[6332:6353]:   ErrTooFewLiveReplicas,
	_ErrorName[6353:6390]:        ErrUnsatisfiedQuorumForPreviousWrite,
	_ErrorLowerName[6353:6390]:   ErrUnsatisfiedQuorumForPreviousWrite,
	_ErrorName[6390:6412]:        ErrUnknownFormatVersion,
	_ErrorLowerName[6390:6412]:   ErrUnknownFormatVersion,
	_ErrorName[6412:6447]:        ErrDistributedInJoinSubqueryDenied,
	_ErrorLowerName[6412:6447]:   ErrDistributedInJoinSubqueryDenied,
	_ErrorName[6447:6471]:        ErrReplicaIsNotInQuorum,
	_ErrorLowerName[6447:6471]:   ErrReplicaIsNotInQuorum,
	_ErrorName[6471:6485]:        ErrLimitExceeded,
	_ErrorLowerName[6471:6485]:   ErrLimitExceeded,
	_ErrorName[6485:6507]:        ErrDatabaseAccessDenied,
	_ErrorLowerName[6485:6507]:   ErrDatabaseAccessDenied,
	_ErrorName[6507:6525]:        ErrLeadershipChanged,
	_ErrorLowerName[6507:6525]:   ErrLeadershipChanged,
	_ErrorName[6525:6552]:        ErrMongodbCannotAuthenticate,
	_ErrorLowerName[6525:6552]:   ErrMongodbCannotAuthenticate,
	_ErrorName[6552:6572]:        ErrCannotWriteToFile,
	_ErrorLowerName[6552:6572]:   ErrCannotWriteToFile,
	_ErrorName[6572:6591]:        ErrReceivedEmptyData,
	_ErrorLowerName[6572:6591]:   ErrReceivedEmptyData,
	_ErrorName[6591:6612]:        ErrNoRemoteShardFound,
	_ErrorLowerName[6591:6612]:   ErrNoRemoteShardFound,
	_ErrorName[6612:6636]:        ErrShardHasNoConnections,
	_ErrorLowerName[6612:6636]:   ErrShardHasNoConnections,
	_ErrorName[6636:6647]:        ErrCannotPipe,
	_ErrorLowerName[6636:6647]:   ErrCannotPipe,
	_ErrorName[6647:6658]:        ErrCannotFork,
	_ErrorLowerName[6647:6658]:   ErrCannotFork,
	_ErrorName[6658:6670]:        ErrCannotDlsym,
	_ErrorLowerName[6658:6670]:   ErrCannotDlsym,
	_ErrorName[6670:6697]:        ErrCannotCreateChildProcess,
	_ErrorLowerName[6670:6697]:   ErrCannotCreateChildProcess,
	_ErrorName[6697:6726]:        ErrChildWasNotExitedNormally,
	_ErrorLowerName[6697:6726]:   ErrChildWasNotExitedNormally,
	_ErrorName[6726:6739]:        ErrCannotSelect,
	_ErrorLowerName[6726:6739]:   ErrCannotSelect,
	_ErrorName[6739:6753]:        ErrCannotWaitpid,
	_ErrorLowerName[6739:6753]:   ErrCannotWaitpid,
	_ErrorName[6753:6774]:        ErrTableWasNotDropped,
	_ErrorLowerName[6753:6774]:   ErrTableWasNotDropped,
	_ErrorName[6774:6792]:        ErrTooDeepRecursion,
	_ErrorLowerName[6774:6792]:   ErrTooDeepRecursion,
	_ErrorName[6792:6806]:        ErrTooManyBytes,
	_ErrorLowerName[6792:6806]:   ErrTooManyBytes,
	_ErrorName[6806:6834]:        ErrUnexpectedNodeInZookeeper,
	_ErrorLowerName[6806:6834]:   ErrUnexpectedNodeInZookeeper,
	_ErrorName[6834:6865]:        ErrFunctionCannotHaveParameters,
	_ErrorLowerName[6834:6865]:   ErrFunctionCannotHaveParameters,
	_ErrorName[6865:6885]:        ErrInvalidShardWeight,
	_ErrorLowerName[6865:6885]:   ErrInvalidShardWeight,
	_ErrorName[6885:6909]:        ErrInvalidConfigParameter,
	_ErrorLowerName[6885:6909]:   ErrInvalidConfigParameter,
	_ErrorName[6909:6933]:        ErrUnknownStatusOfInsert,
	_ErrorLowerName[6909:6933]:   ErrUnknownStatusOfInsert,
	_ErrorName[6933:6967]:        ErrValueIsOutOfRangeOfDataType,
	_ErrorLowerName[6933:6967]:   ErrValueIsOutOfRangeOfDataType,
	_ErrorName[6967:6982]:        ErrBarrierTimeout,
	_ErrorLowerName[6967:6982]:   ErrBarrierTimeout,
	_ErrorName[6982:7005]:        ErrUnknownDatabaseEngine,
	_ErrorLowerName[6982:7005]:   ErrUnknownDatabaseEngine,
	_ErrorName[7005:7024]:        ErrDdlGuardIsActive,
	_ErrorLowerName[7005:7024]:   ErrDdlGuardIsActive,
	_ErrorName[7024:7034]:        ErrUnfinished,
	_ErrorLowerName[7024:7034]:   ErrUnfinished,
	_ErrorName[7034:7051]:        ErrMetadataMismatch,
	_ErrorLowerName[7034:7051]:   ErrMetadataMismatch,
	_ErrorName[7051:7070]:        ErrSupportIsDisabled,
	_ErrorLowerName[7051:7070]:   ErrSupportIsDisabled,
	_ErrorName[7070:7092]:        ErrTableDiffersTooMuch,
	_ErrorLowerName[7070:7092]:   ErrTableDiffersTooMuch,
	_ErrorName[7092:7114]:        ErrCannotConvertCharset,
	_ErrorLowerName[7092:7114]:   ErrCannotConvertCharset,
	_ErrorName[7114:7132]:        ErrCannotLoadConfig,
	_ErrorLowerName[7114:7132]:   ErrCannotLoadConfig,
	_ErrorName[7132:7169]:        ErrCannotInsertNullInOrdinaryColumn,
	_ErrorLowerName[7132:7169]:   ErrCannotInsertNullInOrdinaryColumn,
	_ErrorName[7169:7195]:        ErrIncompatibleSourceTables,
	_ErrorLowerName[7169:7195]:   ErrIncompatibleSourceTables,
	_ErrorName[7195:7215]:        ErrAmbiguousTableName,
	_ErrorLowerName[7195:7215]:   ErrAmbiguousTableName,
	_ErrorName[7215:7236]:        ErrAmbiguousColumnName,
	_ErrorLowerName[7215:7236]:   ErrAmbiguousColumnName,
	_ErrorName[7236:7280]:        ErrIndexOfPositionalArgumentIsOutOfRange,
	_ErrorLowerName[7236:7280]:   ErrIndexOfPositionalArgumentIsOutOfRange,
	_ErrorName[7280:7299]:        ErrZlibInflateFailed,
	_ErrorLowerName[7280:7299]:   ErrZlibInflateFailed,
	_ErrorName[7299:7318]:        ErrZlibDeflateFailed,
	_ErrorLowerName[7299:7318]:   ErrZlibDeflateFailed,
	_ErrorName[7318:7328]:        ErrBadLambda,
	_ErrorLowerName[7318:7328]:   ErrBadLambda,
	_ErrorName[7328:7352]:        ErrReservedIdentifierName,
	_ErrorLowerName[7328:7352]:   ErrReservedIdentifierName,
	_ErrorName[7352:7376]:        ErrIntoOutfileNotAllowed,
	_ErrorLowerName[7352:7376]:   ErrIntoOutfileNotAllowed,
	_ErrorName[7376:7414]:        ErrTableSizeExceedsMaxDropSizeLimit,
	_ErrorLowerName[7376:7414]:   ErrTableSizeExceedsMaxDropSizeLimit,
	_ErrorName[7414:7445]:        ErrCannotCreateCharsetConverter,
	_ErrorLowerName[7414:7445]:   ErrCannotCreateCharsetConverter,
	_ErrorName[7445:7471]:        ErrSeekPositionOutOfBound,
	_ErrorLowerName[7445:7471]:   ErrSeekPositionOutOfBound,
	_ErrorName[7471:7504]:        ErrCurrentWriteBufferIsExhausted,
	_ErrorLowerName[7471:7504]:   ErrCurrentWriteBufferIsExhausted,
	_ErrorName[7504:7527]:        ErrCannotCreateIoBuffer,
	_ErrorLowerName[7504:7527]:   ErrCannotCreateIoBuffer,
	_ErrorName[7527:7559]:        ErrReceivedErrorTooManyRequests,
	_ErrorLowerName[7527:7559]:   ErrReceivedErrorTooManyRequests,
	_ErrorName[7559:7579]:        ErrOutputIsNotSorted,
	_ErrorLowerName[7559:7579]:   ErrOutputIsNotSorted,
	_ErrorName[7579:7619]:        ErrSizesOfNestedColumnsAreInconsistent,
	_ErrorLowerName[7579:7619]:   ErrSizesOfNestedColumnsAreInconsistent,
	_ErrorName[7619:7635]:        ErrTooManyFetches,
	_ErrorLowerName[7619:7635]:   ErrTooManyFetches,
	_ErrorName[7635:7643]:        ErrBadCast,
	_ErrorLowerName[7635:7643]:   ErrBadCast,
	_ErrorName[7643:7665]:        ErrAllReplicasAreStale,
	_ErrorLowerName[7643:7665]:   ErrAllReplicasAreStale,
	_ErrorName[7665:7699]:        ErrDataTypeCannotBeUsedInTables,
	_ErrorLowerName[7665:7699]:   ErrDataTypeCannotBeUsedInTables,
	_ErrorName[7699:7730]:        ErrInconsistentClusterDefinition,
	_ErrorLowerName[7699:7730]:   ErrInconsistentClusterDefinition,
	_ErrorName[7730:7747]:        ErrSessionNotFound,
	_ErrorLowerName[7730:7747]:   ErrSessionNotFound,
	_ErrorName[7747:7764]:        ErrSessionIsLocked,
	_ErrorLowerName[7747:7764]:   ErrSessionIsLocked,
	_ErrorName[7764:7787]:        ErrInvalidSessionTimeout,
	_ErrorLowerName[7764:7787]:   ErrInvalidSessionTimeout,
	_ErrorName[7787:7800]:        ErrCannotDlopen,
	_ErrorLowerName[7787:7800]:   ErrCannotDlopen,
	_ErrorName[7800:7817]:        ErrCannotParseUUID,
	_ErrorLowerName[7800:7817]:   ErrCannotParseUUID,
	_ErrorName[7817:7845]:        ErrIllegalSyntaxForDataType,
	_ErrorLowerName[7817:7845]:   ErrIllegalSyntaxForDataType,
	_ErrorName[7845:7876]:        ErrDataTypeCannotHaveArguments,
	_ErrorLowerName[7845:7876]:   ErrDataTypeCannotHaveArguments,
	_ErrorName[7876:7914]:        ErrUnknownStatusOfDistributedDdlTask,
	_ErrorLowerName[7876:7914]:   ErrUnknownStatusOfDistributedDdlTask,
	_ErrorName[7914:7925]:        ErrCannotKill,
	_ErrorLowerName[7914:7925]:   ErrCannotKill,
	_ErrorName[7925:7945]:        ErrHTTPLengthRequired,
	_ErrorLowerName[7925:7945]:   ErrHTTPLengthRequired,
	_ErrorName[7945:7971]:        ErrCannotLoadCatboostModel,
	_ErrorLowerName[7945:7971]:   ErrCannotLoadCatboostModel,
	_ErrorName[7971:7998]:        ErrCannotApplyCatboostModel,
	_ErrorLowerName[7971:7998]:   ErrCannotApplyCatboostModel,
	_ErrorName[7998:8024]:        ErrPartIsTemporarilyLocked,
	_ErrorLowerName[7998:8024]:   ErrPartIsTemporarilyLocked,
	_ErrorName[8024:8049]:        ErrMultipleStreamsRequired,
	_ErrorLowerName[8024:8049]:   ErrMultipleStreamsRequired,
	_ErrorName[8049:8063]:        ErrNoCommonType,
	_ErrorLowerName[8049:8063]:   ErrNoCommonType,
	_ErrorName[8063:8095]:        ErrExternalLoadableAlreadyExists,
	_ErrorLowerName[8063:8095]:   ErrExternalLoadableAlreadyExists,
	_ErrorName[8095:8117]:        ErrCannotAssignOptimize,
	_ErrorLowerName[8095:8117]:   ErrCannotAssignOptimize,
	_ErrorName[8117:8140]:        ErrInsertWasDeduplicated,
	_ErrorLowerName[8117:8140]:   ErrInsertWasDeduplicated,
	_ErrorName[8140:8169]:        ErrCannotGetCreateTableQuery,
	_ErrorLowerName[8140:8169]:   ErrCannotGetCreateTableQuery,
	_ErrorName[8169:8191]:        ErrExternalLibraryError,
	_ErrorLowerName[8169:8191]:   ErrExternalLibraryError,
	_ErrorName[8191:8210]:        ErrQueryIsProhibited,
	_ErrorLowerName[8191:8210]:   ErrQueryIsProhibited,
	_ErrorName[8210:8227]:        ErrThereIsNoQuery,
	_ErrorLowerName[8210:8227]:   ErrThereIsNoQuery,
	_ErrorName[8227:8246]:        ErrQueryWasCancelled,
	_ErrorLowerName[8227:8246]:   ErrQueryWasCancelled,
	_ErrorName[8246:8281]:        ErrFunctionThrowIfValueIsNonZero,
	_ErrorLowerName[8246:8281]:   ErrFunctionThrowIfValueIsNonZero,
	_ErrorName[8281:8303]:        ErrTooManyRowsOrBytes,
	_ErrorLowerName[8281:8303]:   ErrTooManyRowsOrBytes,
	_ErrorName[8303:8346]:        ErrQueryIsNotSupportedInMaterializedView,
	_ErrorLowerName[8303:8346]:   ErrQueryIsNotSupportedInMaterializedView,
	_ErrorName[8346:8370]:        ErrUnknownMutationCommand,
	_ErrorLowerName[8346:8370]:   ErrUnknownMutationCommand,
	_ErrorName[8370:8403]:        ErrFormatIsNotSuitableForOutput,
	_ErrorLowerName[8370:8403]:   ErrFormatIsNotSuitableForOutput,
	_ErrorName[8403:8414]:        ErrCannotStat,
	_ErrorLowerName[8403:8414]:   ErrCannotStat,
	_ErrorName[8414:8450]:        ErrFeatureIsNotEnabledAtBuildTime,
	_ErrorLowerName[8414:8450]:   ErrFeatureIsNotEnabledAtBuildTime,
	_ErrorName[8450:8464]:        ErrCannotIosetup,
	_ErrorLowerName[8450:8464]:   ErrCannotIosetup,
	_ErrorName[8464:8490]:        ErrInvalidJoinOnExpression,
	_ErrorLowerName[8464:8490]:   ErrInvalidJoinOnExpression,
	_ErrorName[8490:8516]:        ErrBadOdbcConnectionString,
	_ErrorLowerName[8490:8516]:   ErrBadOdbcConnectionString,
	_ErrorName[8516:8538]:        ErrTopAndLimitTogether,
	_ErrorLowerName[8516:8538]:   ErrTopAndLimitTogether,
	_ErrorName[8538:8554]:        ErrDecimalOverflow,
	_ErrorLowerName[8538:8554]:   ErrDecimalOverflow,
	_ErrorName[8554:8575]:        ErrBadRequestParameter,
	_ErrorLowerName[8554:8575]:   ErrBadRequestParameter,
	_ErrorName[8575:8608]:        ErrExternalServerIsNotResponding,
	_ErrorLowerName[8575:8608]:   ErrExternalServerIsNotResponding,
	_ErrorName[8608:8621]:        ErrPthreadError,
	_ErrorLowerName[8608:8621]:   ErrPthreadError,
	_ErrorName[8621:8634]:        ErrNetlinkError,
	_ErrorLowerName[8621:8634]:   ErrNetlinkError,
	_ErrorName[8634:8659]:        ErrCannotSetSignalHandler,
	_ErrorLowerName[8634:8659]:   ErrCannotSetSignalHandler,
	_ErrorName[8659:8676]:        ErrAllReplicasLost,
	_ErrorLowerName[8659:8676]:   ErrAllReplicasLost,
	_ErrorName[8676:8698]:        ErrReplicaStatusChanged,
	_ErrorLowerName[8676:8698]:   ErrReplicaStatusChanged,
	_ErrorName[8698:8717]:        ErrExpectedAllOrAny,
	_ErrorLowerName[8698:8717]:   ErrExpectedAllOrAny,
	_ErrorName[8717:8729]:        ErrUnknownJoin,
	_ErrorLowerName[8717:8729]:   ErrUnknownJoin,
	_ErrorName[8729:8759]:        ErrMultipleAssignmentsToColumn,
	_ErrorLowerName[8729:8759]:   ErrMultipleAssignmentsToColumn,
	_ErrorName[8759:8779]:        ErrCannotUpdateColumn,
	_ErrorLowerName[8759:8779]:   ErrCannotUpdateColumn,
	_ErrorName[8779:8816]:        ErrCannotAddDifferentAggregateStates,
	_ErrorLowerName[8779:8816]:   ErrCannotAddDifferentAggregateStates,
	_ErrorName[8816:8838]:        ErrUnsupportedURIScheme,
	_ErrorLowerName[8816:8838]:   ErrUnsupportedURIScheme,
	_ErrorName[8838:8857]:        ErrCannotGettimeofday,
	_ErrorLowerName[8838:8857]:   ErrCannotGettimeofday,
	_ErrorName[8857:8868]:        ErrCannotLink,
	_ErrorLowerName[8857:8868]:   ErrCannotLink,
	_ErrorName[8868:8880]:        ErrSystemError,
	_ErrorLowerName[8868:8880]:   ErrSystemError,
	_ErrorName[8880:8901]:        ErrCannotCompileRegexp,
	_ErrorLowerName[8880:8901]:   ErrCannotCompileRegexp,
	_ErrorName[8901:8919]:        ErrFailedToGetpwuid,
	_ErrorLowerName[8901:8919]:   ErrFailedToGetpwuid,
	_ErrorName[8919:8957]:        ErrMismatchingUsersForProcessAndData,
	_ErrorLowerName[8919:8957]:   ErrMismatchingUsersForProcessAndData,
	_ErrorName[8957:8986]:        ErrIllegalSyntaxForCodecType,
	_ErrorLowerName[8957:8986]:   ErrIllegalSyntaxForCodecType,
	_ErrorName[8986:8999]:        ErrUnknownCodec,
	_ErrorLowerName[8986:8999]:   ErrUnknownCodec,
	_ErrorName[8999:9022]:        ErrIllegalCodecParameter,
	_ErrorLowerName[8999:9022]:   ErrIllegalCodecParameter,
	_ErrorName[9022:9050]:        ErrCannotParseProtobufSchema,
	_ErrorLowerName[9022:9050]:   ErrCannotParseProtobufSchema,
	_ErrorName[9050:9097]:        ErrNoColumnSerializedToRequiredProtobufField,
	_ErrorLowerName[9050:9097]:   ErrNoColumnSerializedToRequiredProtobufField,
	_ErrorName[9097:9114]:        ErrProtobufBadCast,
	_ErrorLowerName[9097:9114]:   ErrProtobufBadCast,
	_ErrorName[9114:9141]:        ErrProtobufFieldNotRepeated,
	_ErrorLowerName[9114:9141]:   ErrProtobufFieldNotRepeated,
	_ErrorName[9141:9169]:        ErrDataTypeCannotBePromoted,
	_ErrorLowerName[9141:9169]:   ErrDataTypeCannotBePromoted,
	_ErrorName[9169:9189]:        ErrCannotScheduleTask,
	_ErrorLowerName[9169:9189]:   ErrCannotScheduleTask,
	_ErrorName[9189:9213]:        ErrInvalidLimitExpression,
	_ErrorLowerName[9189:9213]:   ErrInvalidLimitExpression,
	_ErrorName[9213:9250]:        ErrCannotParseDomainValueFromString,
	_ErrorLowerName[9213:9250]:   ErrCannotParseDomainValueFromString,
	_ErrorName[9250:9282]:        ErrBadDatabaseForTemporaryTable,
	_ErrorLowerName[9250:9282]:   ErrBadDatabaseForTemporaryTable,
	_ErrorName[9282:9322]:        ErrNoColumnsSerializedToProtobufFields,
	_ErrorLowerName[9282:9322]:   ErrNoColumnsSerializedToProtobufFields,
	_ErrorName[9322:9345]:        ErrUnknownProtobufFormat,
	_ErrorLowerName[9322:9345]:   ErrUnknownProtobufFormat,
	_ErrorName[9345:9360]:        ErrCannotMprotect,
	_ErrorLowerName[9345:9360]:   ErrCannotMprotect,
	_ErrorName[9360:9380]:        ErrFunctionNotAllowed,
	_ErrorLowerName[9360:9380]:   ErrFunctionNotAllowed,
	_ErrorName[9380:9406]:        ErrHyperscanCannotScanText,
	_ErrorLowerName[9380:9406]:   ErrHyperscanCannotScanText,
	_ErrorName[9406:9424]:        ErrBrotliReadFailed,
	_ErrorLowerName[9406:9424]:   ErrBrotliReadFailed,
	_ErrorName[9424:9443]:        ErrBrotliWriteFailed,
	_ErrorLowerName[9424:9443]:   ErrBrotliWriteFailed,
	_ErrorName[9443:9461]:        ErrBadTTLExpression,
	_ErrorLowerName[9443:9461]:   ErrBadTTLExpression,
	_ErrorName[9461:9473]:        ErrBadTTLFile,
	_ErrorLowerName[9461:9473]:   ErrBadTTLFile,
	_ErrorName[9473:9501]:        ErrSettingConstraintViolation,
	_ErrorLowerName[9473:9501]:   ErrSettingConstraintViolation,
	_ErrorName[9501:9539]:        ErrMysqlClientInsufficientCapabilities,
	_ErrorLowerName[9501:9539]:   ErrMysqlClientInsufficientCapabilities,
	_ErrorName[9539:9552]:        ErrOpensslError,
	_ErrorLowerName[9539:9552]:   ErrOpensslError,
	_ErrorName[9552:9587]:        ErrSuspiciousTypeForLowCardinality,
	_ErrorLowerName[9552:9587]:   ErrSuspiciousTypeForLowCardinality,
	_ErrorName[9587:9610]:        ErrUnknownQueryParameter,
	_ErrorLowerName[9587:9610]:   ErrUnknownQueryParameter,
	_ErrorName[9610:9629]:        ErrBadQueryParameter,
	_ErrorLowerName[9610:9629]:   ErrBadQueryParameter,
	_ErrorName[9629:9642]:        ErrCannotUnlink,
	_ErrorLowerName[9629:9642]:   ErrCannotUnlink,
	_ErrorName[9642:9668]:        ErrCannotSetThreadPriority,
	_ErrorLowerName[9642:9668]:   ErrCannotSetThreadPriority,
	_ErrorName[9668:9687]:        ErrCannotCreateTimer,
	_ErrorLowerName[9668:9687]:   ErrCannotCreateTimer,
	_ErrorName[9687:9710]:        ErrCannotSetTimerPeriod,
	_ErrorLowerName[9687:9710]:   ErrCannotSetTimerPeriod,
	_ErrorName[9710:9722]:        ErrCannotFcntl,
	_ErrorLowerName[9710:9722]:   ErrCannotFcntl,
	_ErrorName[9722:9738]:        ErrCannotParseElf,
	_ErrorLowerName[9722:9738]:   ErrCannotParseElf,
	_ErrorName[9738:9756]:        ErrCannotParseDwarf,
	_ErrorLowerName[9738:9756]:   ErrCannotParseDwarf,
	_ErrorName[9756:9769]:        ErrInsecurePath,
	_ErrorLowerName[9756:9769]:   ErrInsecurePath,
	_ErrorName[9769:9786]:        ErrCannotParseBool,
	_ErrorLowerName[9769:9786]:   ErrCannotParseBool,
	_ErrorName[9786:9805]:        ErrCannotPthreadAttr,
	_ErrorLowerName[9786:9805]:   ErrCannotPthreadAttr,
	_ErrorName[9805:9824]:        ErrViolatedConstraint,
	_ErrorLowerName[9805:9824]:   ErrViolatedConstraint,
	_ErrorName[9824:9845]:        ErrInvalidSettingValue,
	_ErrorLowerName[9824:9845]:   ErrInvalidSettingValue,
	_ErrorName[9845:9861]:        ErrReadonlySetting,
	_ErrorLowerName[9845:9861]:   ErrReadonlySetting,
	_ErrorName[9861:9877]:        ErrDeadlockAvoided,
	_ErrorLowerName[9861:9877]:   ErrDeadlockAvoided,
	_ErrorName[9877:9900]:        ErrInvalidTemplateFormat,
	_ErrorLowerName[9877:9900]:   ErrInvalidTemplateFormat,
	_ErrorName[9900:9928]:        ErrInvalidWithFillExpression,
	_ErrorLowerName[9900:9928]:   ErrInvalidWithFillExpression,
	_ErrorName[9928:9954]:        ErrWithTiesWithoutOrderBy,
	_ErrorLowerName[9928:9954]:   ErrWithTiesWithoutOrderBy,
	_ErrorName[9954:9976]:        ErrInvalidUsageOfInput,
	_ErrorLowerName[9954:9976]:   ErrInvalidUsageOfInput,
	_ErrorName[9976:9990]:        ErrUnknownPolicy,
	_ErrorLowerName[9976:9990]:   ErrUnknownPolicy,
	_ErrorName[9990:10002]:       ErrUnknownDisk,
	_ErrorLowerName[9990:10002]:  ErrUnknownDisk,
	_ErrorName[10002:10018]:      ErrUnknownProtocol,
	_ErrorLowerName[10002:10018]: ErrUnknownProtocol,
	_ErrorName[10018:10036]:      ErrPathAccessDenied,
	_ErrorLowerName[10018:10036]: ErrPathAccessDenied,
	_ErrorName[10036:10060]:      ErrDictionaryAccessDenied,
	_ErrorLowerName[10036:10060]: ErrDictionaryAccessDenied,
	_ErrorName[10060:10078]:      ErrTooManyRedirects,
	_ErrorLowerName[10060:10078]: ErrTooManyRedirects,
	_ErrorName[10078:10098]:      ErrInternalRedisError,
	_ErrorLowerName[10078:10098]: ErrInternalRedisError,
	_ErrorName[10098:10132]:      ErrCannotGetCreateDictionaryQuery,
	_ErrorLowerName[10098:10132]: ErrCannotGetCreateDictionaryQuery,
	_ErrorName[10132:10163]:      ErrIncorrectDictionaryDefinition,
	_ErrorLowerName[10132:10163]: ErrIncorrectDictionaryDefinition,
	_ErrorName[10163:10185]:      ErrCannotFormatDatetime,
	_ErrorLowerName[10163:10185]: ErrCannotFormatDatetime,
	_ErrorName[10185:10201]:      ErrUnacceptableURL,
	_ErrorLowerName[10185:10201]: ErrUnacceptableURL,
	_ErrorName[10201:10224]:      ErrAccessEntityNotFound,
	_ErrorLowerName[10201:10224]: ErrAccessEntityNotFound,
	_ErrorName[10224:10252]:      ErrAccessEntityAlreadyExists,
	_ErrorLowerName[10224:10252]: ErrAccessEntityAlreadyExists,
	_ErrorName[10252:10275]:      ErrAccessStorageReadonly,
	_ErrorLowerName[10252:10275]: ErrAccessStorageReadonly,
	_ErrorName[10275:10300]:      ErrQuotaRequiresClientKey,
	_ErrorLowerName[10275:10300]: ErrQuotaRequiresClientKey,
	_ErrorName[10300:10313]:      ErrAccessDenied,
	_ErrorLowerName[10300:10313]: ErrAccessDenied,
	_ErrorName[10313:10348]:      ErrLimitByWithTiesIsNotSupported,
	_ErrorLowerName[10313:10348]: ErrLimitByWithTiesIsNotSupported,
	_ErrorName[10348:10356]:      ErrS3Error,
	_ErrorLowerName[10348:10356]: ErrS3Error,
	_ErrorName[10356:10380]:      ErrAzureBlobStorageError,
	_ErrorLowerName[10356:10380]: ErrAzureBlobStorageError,
	_ErrorName[10380:10402]:      ErrCannotCreateDatabase,
	_ErrorLowerName[10380:10402]: ErrCannotCreateDatabase,
	_ErrorName[10402:10417]:      ErrCannotSigqueue,
	_ErrorLowerName[10402:10417]: ErrCannotSigqueue,
	_ErrorName[10417:10441]:      ErrAggregateFunctionThrow,
	_ErrorLowerName[10417:10441]: ErrAggregateFunctionThrow,
	_ErrorName[10441:10460]:      ErrFileAlreadyExists,
	_ErrorLowerName[10441:10460]: ErrFileAlreadyExists,
	_ErrorName[10460:10488]:      ErrUnableToSkipUnusedShards,
	_ErrorLowerName[10460:10488]: ErrUnableToSkipUnusedShards,
	_ErrorName[10488:10507]:      ErrUnknownAccessType,
	_ErrorLowerName[10488:10507]: ErrUnknownAccessType,
	_ErrorName[10507:10520]:      ErrInvalidGrant,
	_ErrorLowerName[10507:10520]: ErrInvalidGrant,
	_ErrorName[10520:10548]:      ErrCacheDictionaryUpdateFail,
	_ErrorLowerName[10520:10548]: ErrCacheDictionaryUpdateFail,
	_ErrorName[10548:10560]:      ErrUnknownRole,
	_ErrorLowerName[10548:10560]: ErrUnknownRole,
	_ErrorName[10560:10580]:      ErrSetNonGrantedRole,
	_ErrorLowerName[10560:10580]: ErrSetNonGrantedRole,
	_ErrorName[10580:10597]:      ErrUnknownPartType,
	_ErrorLowerName[10580:10597]: ErrUnknownPartType,
	_ErrorName[10597:10635]:      ErrAccessStorageForInsertionNotFound,
	_ErrorLowerName[10597:10635]: ErrAccessStorageForInsertionNotFound,
	_ErrorName[10635:10669]:      ErrIncorrectAccessEntityDefinition,
	_ErrorLowerName[10635:10669]: ErrIncorrectAccessEntityDefinition,
	_ErrorName[10669:10690]:      ErrAuthenticationFailed,
	_ErrorLowerName[10669:10690]: ErrAuthenticationFailed,
	_ErrorName[10690:10709]:      ErrCannotAssignAlter,
	_ErrorLowerName[10690:10709]: ErrCannotAssignAlter,
	_ErrorName[10709:10729]:      ErrCannotCommitOffset,
	_ErrorLowerName[10709:10729]: ErrCannotCommitOffset,
	_ErrorName[10729:10754]:      ErrNoRemoteShardAvailable,
	_ErrorLowerName[10729:10754]: ErrNoRemoteShardAvailable,
	_ErrorName[10754:10787]:      ErrCannotDetachDictionaryAsTable,
	_ErrorLowerName[10754:10787]: ErrCannotDetachDictionaryAsTable,
	_ErrorName[10787:10805]:      ErrAtomicRenameFail,
	_ErrorLowerName[10787:10805]: ErrAtomicRenameFail,
	_ErrorName[10805:10823]:      ErrUnknownRowPolicy,
	_ErrorLowerName[10805:10823]: ErrUnknownRowPolicy,
	_ErrorName[10823:10851]:      ErrAlterOfColumnIsForbidden,
	_ErrorLowerName[10823:10851]: ErrAlterOfColumnIsForbidden,
	_ErrorName[10851:10871]:      ErrIncorrectDiskIndex,
	_ErrorLowerName[10851:10871]: ErrIncorrectDiskIndex,
	_ErrorName[10871:10906]:      ErrNoSuitableFunctionImplementation,
	_ErrorLowerName[10871:10906]: ErrNoSuitableFunctionImplementation,
	_ErrorName[10906:10930]:      ErrCassandraInternalError,
	_ErrorLowerName[10906:10930]: ErrCassandraInternalError,
	_ErrorName[10930:10942]:      ErrNotALeader,
	_ErrorLowerName[10930:10942]: ErrNotALeader,
	_ErrorName[10942:10965]:      ErrCannotConnectRabbitmq,
	_ErrorLowerName[10942:10965]: ErrCannotConnectRabbitmq,
	_ErrorName[10965:10977]:      ErrCannotFstat,
	_ErrorLowerName[10965:10977]: ErrCannotFstat,
	_ErrorName[10977:10987]:      ErrLdapError,
	_ErrorLowerName[10977:10987]: ErrLdapError,
	_ErrorName[10987:11004]:      ErrUnknownRaidType,
	_ErrorLowerName[10987:11004]: ErrUnknownRaidType,
	_ErrorName[11004:11034]:      ErrCannotRestoreFromFieldDump,
	_ErrorLowerName[11004:11034]: ErrCannotRestoreFromFieldDump,
	_ErrorName[11034:11056]:      ErrIllegalMysqlVariable,
	_ErrorLowerName[11034:11056]: ErrIllegalMysqlVariable,
	_ErrorName[11056:11074]:      ErrMysqlSyntaxError,
	_ErrorLowerName[11056:11074]: ErrMysqlSyntaxError,
	_ErrorName[11074:11103]:      ErrCannotBindRabbitmqExchange,
	_ErrorLowerName[11074:11103]: ErrCannotBindRabbitmqExchange,
	_ErrorName[11103:11135]:      ErrCannotDeclareRabbitmqExchange,
	_ErrorLowerName[11103:11135]: ErrCannotDeclareRabbitmqExchange,
	_ErrorName[11135:11171]:      ErrCannotCreateRabbitmqQueueBinding,
	_ErrorLowerName[11135:11171]: ErrCannotCreateRabbitmqQueueBinding,
	_ErrorName[11171:11202]:      ErrCannotRemoveRabbitmqExchange,
	_ErrorLowerName[11171:11202]: ErrCannotRemoveRabbitmqExchange,
	_ErrorName[11202:11239]:      ErrUnknownMysqlDatatypesSupportLevel,
	_ErrorLowerName[11202:11239]: ErrUnknownMysqlDatatypesSupportLevel,
	_ErrorName[11239:11260]:      ErrRowAndRowsTogether,
	_ErrorLowerName[11239:11260]: ErrRowAndRowsTogether,
	_ErrorName[11260:11283]:      ErrFirstAndNextTogether,
	_ErrorLowerName[11260:11283]: ErrFirstAndNextTogether,
	_ErrorName[11283:11299]:      ErrNoRowDelimiter,
	_ErrorLowerName[11283:11299]: ErrNoRowDelimiter,
	_ErrorName[11299:11316]:      ErrInvalidRaidType,
	_ErrorLowerName[11299:11316]: ErrInvalidRaidType,
	_ErrorName[11316:11330]:      ErrUnknownVolume,
	_ErrorLowerName[11316:11330]: ErrUnknownVolume,
	_ErrorName[11330:11361]:      ErrDataTypeCannotBeUsedInKey,
	_ErrorLowerName[11330:11361]: ErrDataTypeCannotBeUsedInKey,
	_ErrorName[11361:11383]:      ErrUnrecognizedArguments,
	_ErrorLowerName[11361:11383]: ErrUnrecognizedArguments,
	_ErrorName[11383:11409]:      ErrLzmaStreamEncoderFailed,
	_ErrorLowerName[11383:11409]: ErrLzmaStreamEncoderFailed,
	_ErrorName[11409:11435]:      ErrLzmaStreamDecoderFailed,
	_ErrorLowerName[11409:11435]: ErrLzmaStreamDecoderFailed,
	_ErrorName[11435:11448]:      ErrRocksdbError,
	_ErrorLowerName[11435:11448]: ErrRocksdbError,
	_ErrorName[11448:11476]:      ErrSyncMysqlUserAccessError,
	_ErrorLowerName[11448:11476]: ErrSyncMysqlUserAccessError,
	_ErrorName[11476:11489]:      ErrUnknownUnion,
	_ErrorLowerName[11476:11489]: ErrUnknownUnion,
	_ErrorName[11489:11513]:      ErrExpectedAllOrDistinct,
	_ErrorLowerName[11489:11513]: ErrExpectedAllOrDistinct,
	_ErrorName[11513:11536]:      ErrInvalidGrpcQueryInfo,
	_ErrorLowerName[11513:11536]: ErrInvalidGrpcQueryInfo,
	_ErrorName[11536:11555]:      ErrZstdEncoderFailed,
	_ErrorLowerName[11536:11555]: ErrZstdEncoderFailed,
	_ErrorName[11555:11574]:      ErrZstdDecoderFailed,
	_ErrorLowerName[11555:11574]: ErrZstdDecoderFailed,
	_ErrorName[11574:11592]:      ErrTldListNotFound,
	_ErrorLowerName[11574:11592]: ErrTldListNotFound,
	_ErrorName[11592:11617]:      ErrCannotReadMapFromText,
	_ErrorLowerName[11592:11617]: ErrCannotReadMapFromText,
	_ErrorName[11617:11648]:      ErrInterserverSchemeDoesntMatch,
	_ErrorLowerName[11617:11648]: ErrInterserverSchemeDoesntMatch,
	_ErrorName[11648:11667]:      ErrTooManyPartitions,
	_ErrorLowerName[11648:11667]: ErrTooManyPartitions,
	_ErrorName[11667:11679]:      ErrCannotRmdir,
	_ErrorLowerName[11667:11679]: ErrCannotRmdir,
	_ErrorName[11679:11700]:      ErrDuplicatedPartUuids,
	_ErrorLowerName[11679:11700]: ErrDuplicatedPartUuids,
	_ErrorName[11700:11710]:      ErrRaftError,
	_ErrorLowerName[11700:11710]: ErrRaftError,
	_ErrorName[11710:11760]:      ErrMultipleColumnsSerializedToSameProtobufField,
	_ErrorLowerName[11710:11760]: ErrMultipleColumnsSerializedToSameProtobufField,
	_ErrorName[11760:11802]:      ErrDataTypeIncompatibleWithProtobufField,
	_ErrorLowerName[11760:11802]: ErrDataTypeIncompatibleWithProtobufField,
	_ErrorName[11802:11829]:      ErrDatabaseReplicationFailed,
	_ErrorLowerName[11802:11829]: ErrDatabaseReplicationFailed,
	_ErrorName[11829:11862]:      ErrTooManyQueryPlanOptimizations,
	_ErrorLowerName[11829:11862]: ErrTooManyQueryPlanOptimizations,
	_ErrorName[11862:11873]:      ErrEpollError,
	_ErrorLowerName[11862:11873]: ErrEpollError,
	_ErrorName[11873:11907]:      ErrDistributedTooManyPendingBytes,
	_ErrorLowerName[11873:11907]: ErrDistributedTooManyPendingBytes,
	_ErrorName[11907:11923]:      ErrUnknownSnapshot,
	_ErrorLowerName[11907:11923]: ErrUnknownSnapshot,
	_ErrorName[11923:11937]:      ErrKerberosError,
	_ErrorLowerName[11923:11937]: ErrKerberosError,
	_ErrorName[11937:11953]:      ErrInvalidShardID,
	_ErrorLowerName[11937:11953]: ErrInvalidShardID,
	_ErrorName[11953:11990]:      ErrInvalidFormatInsertQueryWithData,
	_ErrorLowerName[11953:11990]: ErrInvalidFormatInsertQueryWithData,
	_ErrorName[11990:12009]:      ErrIncorrectPartType,
	_ErrorLowerName[11990:12009]: ErrIncorrectPartType,
	_ErrorName[12009:12033]:      ErrCannotSetRoundingMode,
	_ErrorLowerName[12009:12033]: ErrCannotSetRoundingMode,
	_ErrorName[12033:12060]:      ErrTooLargeDistributedDepth,
	_ErrorLowerName[12033:12060]: ErrTooLargeDistributedDepth,
	_ErrorName[12060:12087]:      ErrNoSuchProjectionInTable,
	_ErrorLowerName[12060:12087]: ErrNoSuchProjectionInTable,
	_ErrorName[12087:12105]:      ErrIllegalProjection,
	_ErrorLowerName[12087:12105]: ErrIllegalProjection,
	_ErrorName[12105:12124]:      ErrProjectionNotUsed,
	_ErrorLowerName[12105:12124]: ErrProjectionNotUsed,
	_ErrorName[12124:12141]:      ErrCannotParseYaml,
	_ErrorLowerName[12124:12141]: ErrCannotParseYaml,
	_ErrorName[12141:12159]:      ErrCannotCreateFile,
	_ErrorLowerName[12141:12159]: ErrCannotCreateFile,
	_ErrorName[12159:12190]:      ErrConcurrentAccessNotSupported,
	_ErrorLowerName[12159:12190]: ErrConcurrentAccessNotSupported,
	_ErrorName[12190:12219]:      ErrDistributedBrokenBatchInfo,
	_ErrorLowerName[12190:12219]: ErrDistributedBrokenBatchInfo,
	_ErrorName[12219:12249]:      ErrDistributedBrokenBatchFiles,
	_ErrorLowerName[12219:12249]: ErrDistributedBrokenBatchFiles,
	_ErrorName[12249:12263]:      ErrCannotSysconf,
	_ErrorLowerName[12249:12263]: ErrCannotSysconf,
	_ErrorName[12263:12282]:      ErrSqliteEngineError,
	_ErrorLowerName[12263:12282]: ErrSqliteEngineError,
	_ErrorName[12282:12303]:      ErrDataEncryptionError,
	_ErrorLowerName[12282:12303]: ErrDataEncryptionError,
	_ErrorName[12303:12330]:      ErrZeroCopyReplicationError,
	_ErrorLowerName[12303:12330]: ErrZeroCopyReplicationError,
	_ErrorName[12330:12357]:      ErrBzip2StreamDecoderFailed,
	_ErrorLowerName[12330:12357]: ErrBzip2StreamDecoderFailed,
	_ErrorName[12357:12384]:      ErrBzip2StreamEncoderFailed,
	_ErrorLowerName[12357:12384]: ErrBzip2StreamEncoderFailed,
	_ErrorName[12384:12430]:      ErrIntersectOrExceptResultStructuresMismatch,
	_ErrorLowerName[12384:12430]: ErrIntersectOrExceptResultStructuresMismatch,
	_ErrorName[12430:12448]:      ErrNoSuchErrorCode,
	_ErrorLowerName[12430:12448]: ErrNoSuchErrorCode,
	_ErrorName[12448:12469]:      ErrBackupAlreadyExists,
	_ErrorLowerName[12448:12469]: ErrBackupAlreadyExists,
	_ErrorName[12469:12485]:      ErrBackupNotFound,
	_ErrorLowerName[12469:12485]: ErrBackupNotFound,
	_ErrorName[12485:12513]:      ErrBackupVersionNotSupported,
	_ErrorLowerName[12485:12513]: ErrBackupVersionNotSupported,
	_ErrorName[12513:12527]:      ErrBackupDamaged,
	_ErrorLowerName[12513:12527]: ErrBackupDamaged,
	_ErrorName[12527:12541]:      ErrNoBaseBackup,
	_ErrorLowerName[12527:12541]: ErrNoBaseBackup,
	_ErrorName[12541:12558]:      ErrWrongBaseBackup,
	_ErrorLowerName[12541:12558]: ErrWrongBaseBackup,
	_ErrorName[12558:12585]:      ErrBackupEntryAlreadyExists,
	_ErrorLowerName[12558:12585]: ErrBackupEntryAlreadyExists,
	_ErrorName[12585:12607]:      ErrBackupEntryNotFound,
	_ErrorLowerName[12585:12607]: ErrBackupEntryNotFound,
	_ErrorName[12607:12622]:      ErrBackupIsEmpty,
	_ErrorLowerName[12607:12622]: ErrBackupIsEmpty,
	_ErrorName[12622:12645]:      ErrCannotRestoreDatabase,
	_ErrorLowerName[12622:12645]: ErrCannotRestoreDatabase,
	_ErrorName[12645:12665]:      ErrCannotRestoreTable,
	_ErrorLowerName[12645:12665]: ErrCannotRestoreTable,
	_ErrorName[12665:12688]:      ErrFunctionAlreadyExists,
	_ErrorLowerName[12665:12688]: ErrFunctionAlreadyExists,
	_ErrorName[12688:12708]:      ErrCannotDropFunction,
	_ErrorLowerName[12688:12708]: ErrCannotDropFunction,
	_ErrorName[12708:12740]:      ErrCannotCreateRecursiveFunction,
	_ErrorLowerName[12708:12740]: ErrCannotCreateRecursiveFunction,
	_ErrorName[12740:12769]:      ErrPostgresqlConnectionFailure,
	_ErrorLowerName[12740:12769]: ErrPostgresqlConnectionFailure,
	_ErrorName[12769:12782]:      ErrCannotAdvise,
	_ErrorLowerName[12769:12782]: ErrCannotAdvise,
	_ErrorName[12782:12801]:      ErrUnknownReadMethod,
	_ErrorLowerName[12782:12801]: ErrUnknownReadMethod,
	_ErrorName[12801:12819]:      ErrLz4EncoderFailed,
	_ErrorLowerName[12801:12819]: ErrLz4EncoderFailed,
	_ErrorName[12819:12837]:      ErrLz4DecoderFailed,
	_ErrorLowerName[12819:12837]: ErrLz4DecoderFailed,
	_ErrorName[12837:12874]:      ErrPostgresqlReplicationInternalError,
	_ErrorLowerName[12837:12874]: ErrPostgresqlReplicationInternalError,
	_ErrorName[12874:12891]:      ErrQueryNotAllowed,
	_ErrorLowerName[12874:12891]: ErrQueryNotAllowed,
	_ErrorName[12891:12914]:      ErrCannotNormalizeString,
	_ErrorLowerName[12891:12914]: ErrCannotNormalizeString,
	_ErrorName[12914:12944]:      ErrCannotParseCapnProtoSchema,
	_ErrorLowerName[12914:12944]: ErrCannotParseCapnProtoSchema,
	_ErrorName[12944:12963]:      ErrCapnProtoBadCast,
	_ErrorLowerName[12944:12963]: ErrCapnProtoBadCast,
	_ErrorName[12963:12976]:      ErrBadFileType,
	_ErrorLowerName[12963:12976]: ErrBadFileType,
	_ErrorName[12976:12990]:      ErrIOSetupError,
	_ErrorLowerName[12976:12990]: ErrIOSetupError,
	_ErrorName[12990:13015]:      ErrCannotSkipUnknownField,
	_ErrorLowerName[12990:13015]: ErrCannotSkipUnknownField,
	_ErrorName[13015:13038]:      ErrBackupEngineNotFound,
	_ErrorLowerName[13015:13038]: ErrBackupEngineNotFound,
	_ErrorName[13038:13067]:      ErrOffsetFetchWithoutOrderBy,
	_ErrorLowerName[13038:13067]: ErrOffsetFetchWithoutOrderBy,
	_ErrorName[13067:13093]:      ErrHTTPRangeNotSatisfiable,
	_ErrorLowerName[13067:13093]: ErrHTTPRangeNotSatisfiable,
	_ErrorName[13093:13115]:      ErrHaveDependentObjects,
	_ErrorLowerName[13093:13115]: ErrHaveDependentObjects,
	_ErrorName[13115:13132]:      ErrUnknownFileSize,
	_ErrorLowerName[13115:13132]: ErrUnknownFileSize,
	_ErrorName[13132:13166]:      ErrUnexpectedDataAfterParsedValue,
	_ErrorLowerName[13132:13166]: ErrUnexpectedDataAfterParsedValue,
	_ErrorName[13166:13203]:      ErrQueryIsNotSupportedInWindowView,
	_ErrorLowerName[13166:13203]: ErrQueryIsNotSupportedInWindowView,
	_ErrorName[13203:13216]:      ErrMongodbError,
	_ErrorLowerName[13203:13216]: ErrMongodbError,
	_ErrorName[13216:13227]:      ErrCannotPoll,
	_ErrorLowerName[13216:13227]: ErrCannotPoll,
	_ErrorName[13227:13257]:      ErrCannotExtractTableStructure,
	_ErrorLowerName[13227:13257]: ErrCannotExtractTableStructure,
	_ErrorName[13257:13279]:      ErrInvalidTableOverride,
	_ErrorLowerName[13257:13279]: ErrInvalidTableOverride,
	_ErrorName[13279:13303]:      ErrSnappyUncompressFailed,
	_ErrorLowerName[13279:13303]: ErrSnappyUncompressFailed,
	_ErrorName[13303:13325]:      ErrSnappyCompressFailed,
	_ErrorLowerName[13303:13325]: ErrSnappyCompressFailed,
	_ErrorName[13325:13341]:      ErrNoHivemetastore,
	_ErrorLowerName[13325:13341]: ErrNoHivemetastore,
	_ErrorName[13341:13362]:      ErrCannotAppendToFile,
	_ErrorLowerName[13341:13362]: ErrCannotAppendToFile,
	_ErrorName[13362:13381]:      ErrCannotPackArchive,
	_ErrorLowerName[13362:13381]: ErrCannotPackArchive,
	_ErrorName[13381:13402]:      ErrCannotUnpackArchive,
	_ErrorLowerName[13381:13402]: ErrCannotUnpackArchive,
	_ErrorName[13402:13433]:      ErrNumberOfDimensionsMismatched,
	_ErrorLowerName[13402:13433]: ErrNumberOfDimensionsMismatched,
	_ErrorName[13433:13452]:      ErrCannotBackupTable,
	_ErrorLowerName[13433:13452]: ErrCannotBackupTable,
	_ErrorName[13452:13479]:      ErrWrongDdlRenamingSettings,
	_ErrorLowerName[13452:13479]: ErrWrongDdlRenamingSettings,
	_ErrorName[13479:13498]:      ErrInvalidTransaction,
	_ErrorLowerName[13479:13498]: ErrInvalidTransaction,
	_ErrorName[13498:13517]:      ErrSerializationError,
	_ErrorLowerName[13498:13517]: ErrSerializationError,
	_ErrorName[13517:13536]:      ErrCapnProtoBadType,
	_ErrorLowerName[13517:13536]: ErrCapnProtoBadType,
	_ErrorName[13536:13567]:      ErrOnlyNullsWhileReadingSchema,
	_ErrorLowerName[13536:13567]: ErrOnlyNullsWhileReadingSchema,
	_ErrorName[13567:13595]:      ErrCannotParseBackupSettings,
	_ErrorLowerName[13567:13595]: ErrCannotParseBackupSettings,
	_ErrorName[13595:13616]:      ErrWrongBackupSettings,
	_ErrorLowerName[13595:13616]: ErrWrongBackupSettings,
	_ErrorName[13616:13648]:      ErrFailedToSyncBackupOrRestore,
	_ErrorLowerName[13616:13648]: ErrFailedToSyncBackupOrRestore,
	_ErrorName[13648:13677]:      ErrUnknownStatusOfTransaction,
	_ErrorLowerName[13648:13677]: ErrUnknownStatusOfTransaction,
	_ErrorName[13677:13687]:      ErrHdfsError,
	_ErrorLowerName[13677:13687]: ErrHdfsError,
	_ErrorName[13687:13705]:      ErrCannotSendSignal,
	_ErrorLowerName[13687:13705]: ErrCannotSendSignal,
	_ErrorName[13705:13722]:      ErrFsMetadataError,
	_ErrorLowerName[13705:13722]: ErrFsMetadataError,
	_ErrorName[13722:13754]:      ErrInconsistentMetadataForBackup,
	_ErrorLowerName[13722:13754]: ErrInconsistentMetadataForBackup,
	_ErrorName[13754:13788]:      ErrAccessStorageDoesntAllowBackup,
	_ErrorLowerName[13754:13788]: ErrAccessStorageDoesntAllowBackup,
	_ErrorName[13788:13807]:      ErrCannotConnectNats,
	_ErrorLowerName[13788:13807]: ErrCannotConnectNats,
	_ErrorName[13807:13822]:      ErrNotInitialized,
	_ErrorLowerName[13807:13822]: ErrNotInitialized,
	_ErrorName[13822:13835]:      ErrInvalidState,
	_ErrorLowerName[13822:13835]: ErrInvalidState,
	_ErrorName[13835:13864]:      ErrNamedCollectionDoesntExist,
	_ErrorLowerName[13835:13864]: ErrNamedCollectionDoesntExist,
	_ErrorName[13864:13895]:      ErrNamedCollectionAlreadyExists,
	_ErrorLowerName[13864:13895]: ErrNamedCollectionAlreadyExists,
	_ErrorName[13895:13924]:      ErrNamedCollectionIsImmutable,
	_ErrorLowerName[13895:13924]: ErrNamedCollectionIsImmutable,
	_ErrorName[13924:13946]:      ErrInvalidSchedulerNode,
	_ErrorLowerName[13924:13946]: ErrInvalidSchedulerNode,
	_ErrorName[13946:13968]:      ErrResourceAccessDenied,
	_ErrorLowerName[13946:13968]: ErrResourceAccessDenied,
	_ErrorName[13968:13986]:      ErrResourceNotFound,
	_ErrorLowerName[13968:13986]: ErrResourceNotFound,
	_ErrorName[13986:14003]:      ErrCannotParseIpv4,
	_ErrorLowerName[13986:14003]: ErrCannotParseIpv4,
	_ErrorName[14003:14020]:      ErrCannotParseIpv6,
	_ErrorLowerName[14003:14020]: ErrCannotParseIpv6,
	_ErrorName[14020:14039]:      ErrThreadWasCanceled,
	_ErrorLowerName[14020:14039]: ErrThreadWasCanceled,
	_ErrorName[14039:14059]:      ErrIOUringInitFailed,
	_ErrorLowerName[14039:14059]: ErrIOUringInitFailed,
	_ErrorName[14059:14080]:      ErrIOUringSubmitError,
	_ErrorLowerName[14059:14080]: ErrIOUringSubmitError,
	_ErrorName[14080:14108]:      ErrMixedAccessParameterTypes,
	_ErrorLowerName[14080:14108]: ErrMixedAccessParameterTypes,
	_ErrorName[14108:14131]:      ErrUnknownElementOfEnum,
	_ErrorLowerName[14108:14131]: ErrUnknownElementOfEnum,
	_ErrorName[14131:14149]:      ErrTooManyMutations,
	_ErrorLowerName[14131:14149]: ErrTooManyMutations,
	_ErrorName[14149:14158]:      ErrAwsError,
	_ErrorLowerName[14149:14158]: ErrAwsError,
	_ErrorName[14158:14174]:      ErrAsyncLoadCycle,
	_ErrorLowerName[14158:14174]: ErrAsyncLoadCycle,
	_ErrorName[14174:14191]:      ErrAsyncLoadFailed,
	_ErrorLowerName[14174:14191]: ErrAsyncLoadFailed,
	_ErrorName[14191:14210]:      ErrAsyncLoadCanceled,
	_ErrorLowerName[14191:14210]: ErrAsyncLoadCanceled,
	_ErrorName[14210:14245]:      ErrCannotRestoreToNonencryptedDisk,
	_ErrorLowerName[14210:14245]: ErrCannotRestoreToNonencryptedDisk,
	_ErrorName[14245:14271]:      ErrInvalidRedisStorageType,
	_ErrorLowerName[14245:14271]: ErrInvalidRedisStorageType,
	_ErrorName[14271:14300]:      ErrInvalidRedisTableStructure,
	_ErrorLowerName[14271:14300]: ErrInvalidRedisTableStructure,
	_ErrorName[14300:14327]:      ErrUserSessionLimitExceeded,
	_ErrorLowerName[14300:14327]: ErrUserSessionLimitExceeded,
	_ErrorName[14327:14347]:      ErrClusterDoesntExist,
	_ErrorLowerName[14327:14347]: ErrClusterDoesntExist,
	_ErrorName[14347:14373]:      ErrClientInfoDoesNotMatch,
	_ErrorLowerName[14347:14373]: ErrClientInfoDoesNotMatch,
	_ErrorName[14373:14391]:      ErrInvalidIdentifier,
	_ErrorLowerName[14373:14391]: ErrInvalidIdentifier,
	_ErrorName[14391:14439]:      ErrQueryCacheUsedWithNondeterministicFunctions,
	_ErrorLowerName[14391:14439]: ErrQueryCacheUsedWithNondeterministicFunctions,
	_ErrorName[14439:14454]:      ErrTableNotEmpty,
	_ErrorLowerName[14439:14454]: ErrTableNotEmpty,
	_ErrorName[14454:14466]:      ErrLibsshError,
	_ErrorLowerName[14454:14466]: ErrLibsshError,
	_ErrorName[14466:14475]:      ErrGcpError,
	_ErrorLowerName[14466:14475]: ErrGcpError,
	_ErrorName[14475:14493]:      ErrIllegalStatistics,
	_ErrorLowerName[14475:14493]: ErrIllegalStatistics,
	_ErrorName[14493:14532]:      ErrCannotGetReplicatedDatabaseSnapshot,
	_ErrorLowerName[14493:14532]: ErrCannotGetReplicatedDatabaseSnapshot,
	_ErrorName[14532:14546]:      ErrFaultInjected,
	_ErrorLowerName[14532:14546]: ErrFaultInjected,
	_ErrorName[14546:14569]:      ErrFilecacheAccessDenied,
	_ErrorLowerName[14546:14569]: ErrFilecacheAccessDenied,
	_ErrorName[14569:14596]:      ErrTooManyMaterializedViews,
	_ErrorLowerName[14569:14596]: ErrTooManyMaterializedViews,
	_ErrorName[14596:14613]:      ErrBrokenProjection,
	_ErrorLowerName[14596:14613]: ErrBrokenProjection,
	_ErrorName[14613:14631]:      ErrUnexpectedCluster,
	_ErrorLowerName[14613:14631]: ErrUnexpectedCluster,
	_ErrorName[14631:14651]:      ErrCannotDetectFormat,
	_ErrorLowerName[14631:14651]: ErrCannotDetectFormat,
	_ErrorName[14651:14674]:      ErrCannotForgetPartition,
	_ErrorLowerName[14651:14674]: ErrCannotForgetPartition,
	_ErrorName[14674:14700]:      ErrExperimentalFeatureError,
	_ErrorLowerName[14674:14700]: ErrExperimentalFeatureError,
	_ErrorName[14700:14716]:      ErrTooSlowParsing,
	_ErrorLowerName[14700:14716]: ErrTooSlowParsing,
	_ErrorName[14716:14750]:      ErrQueryCacheUsedWithSystemTable,
	_ErrorLowerName[14716:14750]: ErrQueryCacheUsedWithSystemTable,
	_ErrorName[14750:14762]:      ErrUserExpired,
	_ErrorLowerName[14750:14762]: ErrUserExpired,
	_ErrorName[14762:14781]:      ErrDeprecatedFunction,
	_ErrorLowerName[14762:14781]: ErrDeprecatedFunction,
	_ErrorName[14781:14803]:      ErrAsyncLoadWaitFailed,
	_ErrorLowerName[14781:14803]: ErrAsyncLoadWaitFailed,
	_ErrorName[14803:14820]:      ErrParquetException,
	_ErrorLowerName[14803:14820]: ErrParquetException,
	_ErrorName[14820:14835]:      ErrTooManyTables,
	_ErrorLowerName[14820:14835]: ErrTooManyTables,
	_ErrorName[14835:14853]:      ErrTooManyDatabases,
	_ErrorLowerName[14835:14853]: ErrTooManyDatabases,
	_ErrorName[14853:14876]:      ErrUnexpectedHTTPHeaders,
	_ErrorLowerName[14853:14876]: ErrUnexpectedHTTPHeaders,
	_ErrorName[14876:14899]:      ErrUnexpectedTableEngine,
	_ErrorLowerName[14876:14899]: ErrUnexpectedTableEngine,
	_ErrorName[14899:14919]:      ErrUnexpectedDataType,
	_ErrorLowerName[14899:14919]: ErrUnexpectedDataType,
	_ErrorName[14919:14943]:      ErrIllegalTimeSeriesTags,
	_ErrorLowerName[14919:14943]: ErrIllegalTimeSeriesTags,
	_ErrorName[14943:14957]:      ErrRefreshFailed,
	_ErrorLowerName[14943:14957]: ErrRefreshFailed,
	_ErrorName[14957:15002]:      ErrQueryCacheUsedWithNonThrowOverflowMode,
	_ErrorLowerName[14957:15002]: ErrQueryCacheUsedWithNonThrowOverflowMode,
	_ErrorName[15002:15026]:      ErrTableIsBeingRestarted,
	_ErrorLowerName[15002:15026]: ErrTableIsBeingRestarted,
	_ErrorName[15026:15060]:      ErrCannotWriteAfterBufferCanceled,
	_ErrorLowerName[15026:15060]: ErrCannotWriteAfterBufferCanceled,
	_ErrorName[15060:15089]:      ErrQueryWasCancelledByClient,
	_ErrorLowerName[15060:15089]: ErrQueryWasCancelledByClient,
	_ErrorName[15089:15112]:      ErrDatalakeDatabaseError,
	_ErrorLowerName[15089:15112]: ErrDatalakeDatabaseError,
	_ErrorName[15112:15130]:      ErrGoogleCloudError,
	_ErrorLowerName[15112:15130]: ErrGoogleCloudError,
	_ErrorName[15130:15144]:      ErrPartIsLocked,
	_ErrorLowerName[15130:15144]: ErrPartIsLocked,
	_ErrorName[15144:15153]:      ErrBuzzhouse,
	_ErrorLowerName[15144:15153]: ErrBuzzhouse,
	_ErrorName[15153:15181]:      ErrPotentiallyBrokenDataPart,
	_ErrorLowerName[15153:15181]: ErrPotentiallyBrokenDataPart,
	_ErrorName[15181:15200]:      ErrTableUUIDMismatch,
	_ErrorLowerName[15181:15200]: ErrTableUUIDMismatch,
	_ErrorName[15200:15218]:      ErrDeltaKernelError,
	_ErrorLowerName[15200:15218]: ErrDeltaKernelError,
	_ErrorName[15218:15249]:      ErrIcebergSpecificationViolation,
	_ErrorLowerName[15218:15249]: ErrIcebergSpecificationViolation,
	_ErrorName[15249:15265]:      ErrSessionIDEmpty,
	_ErrorLowerName[15249:15265]: ErrSessionIDEmpty,
	_ErrorName[15265:15282]:      ErrServerOverloaded,
	_ErrorLowerName[15265:15282]: ErrServerOverloaded,
	_ErrorName[15282:15304]:      ErrDependenciesNotFound,
	_ErrorLowerName[15282:15304]: ErrDependenciesNotFound,
	_ErrorName[15304:15362]:      ErrFilecacheCannotWriteThroughCacheWithConcurrentReads,
	_ErrorLowerName[15304:15362]: ErrFilecacheCannotWriteThroughCacheWithConcurrentReads,
	_ErrorName[15362:15385]:      ErrDistributedCacheError,
	_ErrorLowerName[15362:15385]: ErrDistributedCacheError,
	_ErrorName[15385:15413]:      ErrCannotUseDistributedCache,
	_ErrorLowerName[15385:15413]: ErrCannotUseDistributedCache,
	_ErrorName[15413:15438]:      ErrProtocolVersionMismatch,
	_ErrorLowerName[15413:15438]: ErrProtocolVersionMismatch,
	_ErrorName[15438:15453]:      ErrLicenseExpired,
	_ErrorLowerName[15438:15453]: ErrLicenseExpired,
	_ErrorName[15453:15469]:      ErrKeeperException,
	_ErrorLowerName[15453:15469]: ErrKeeperException,
	_ErrorName[15469:15483]:      ErrPocoException,
	_ErrorLowerName[15469:15483]: ErrPocoException,
	_ErrorName[15483:15496]:      ErrStdException,
	_ErrorLowerName[15483:15496]: ErrStdException,
	_ErrorName[15496:15513]:      ErrUnknownException,
	_ErrorLowerName[15496:15513]: ErrUnknownException,
	_ErrorName[15513:15526]:      ErrSSHException,
	_ErrorLowerName[15513:15526]: ErrSSHException,
	_ErrorName[15526:15547]:      ErrStartupScriptsError,
	_ErrorLowerName[15526:15547]: ErrStartupScriptsError,
	_ErrorName[15547:15580]:      ErrConditionalTreeParentNotFound,
	_ErrorLowerName[15547:15580]: ErrConditionalTreeParentNotFound,
	_ErrorName[15580:15610]:      ErrIllegalProjectionManipulator,
	_ErrorLowerName[15580:15610]: ErrIllegalProjectionManipulator,
}

var _ErrorNames = []string{
	_ErrorName[0:18],
	_ErrorName[18:39],
	_ErrorName[39:61],
	_ErrorName[61:81],
	_ErrorName[81:98],
	_ErrorName[98:125],
	_ErrorName[125:143],
	_ErrorName[143:172],
	_ErrorName[172:197],
	_ErrorName[197:218],
	_ErrorName[218:240],
	_ErrorName[240:278],
	_ErrorName[278:294],
	_ErrorName[294:317],
	_ErrorName[317:357],
	_ErrorName[357:399],
	_ErrorName[399:432],
	_ErrorName[432:462],
	_ErrorName[462:507],
	_ErrorName[507:554],
	_ErrorName[554:578],
	_ErrorName[578:601],
	_ErrorName[601:629],
	_ErrorName[629:655],
	_ErrorName[655:690],
	_ErrorName[690:725],
	_ErrorName[725:745],
	_ErrorName[745:781],
	_ErrorName[781:809],
	_ErrorName[809:834],
	_ErrorName[834:854],
	_ErrorName[854:885],
	_ErrorName[885:915],
	_ErrorName[915:928],
	_ErrorName[928:950],
	_ErrorName[950:967],
	_ErrorName[967:992],
	_ErrorName[992:1013],
	_ErrorName[1013:1034],
	_ErrorName[1034:1066],
	_ErrorName[1066:1090],
	_ErrorName[1090:1104],
	_ErrorName[1104:1136],
	_ErrorName[1136:1152],
	_ErrorName[1152:1170],
	_ErrorName[1170:1185],
	_ErrorName[1185:1198],
	_ErrorName[1198:1210],
	_ErrorName[1210:1239],
	_ErrorName[1239:1268],
	_ErrorName[1268:1281],
	_ErrorName[1281:1312],
	_ErrorName[1312:1338],
	_ErrorName[1338:1353],
	_ErrorName[1353:1373],
	_ErrorName[1373:1402],
	_ErrorName[1402:1435],
	_ErrorName[1435:1448],
	_ErrorName[1448:1475],
	_ErrorName[1475:1487],
	_ErrorName[1487:1513],
	_ErrorName[1513:1553],
	_ErrorName[1553:1592],
	_ErrorName[1592:1604],
	_ErrorName[1604:1630],
	_ErrorName[1630:1654],
	_ErrorName[1654:1675],
	_ErrorName[1675:1694],
	_ErrorName[1694:1726],
	_ErrorName[1726:1745],
	_ErrorName[1745:1759],
	_ErrorName[1759:1791],
	_ErrorName[1791:1822],
	_ErrorName[1822:1838],
	_ErrorName[1838:1855],
	_ErrorName[1855:1876],
	_ErrorName[1876:1895],
	_ErrorName[1895:1910],
	_ErrorName[1910:1926],
	_ErrorName[1926:1949],
	_ErrorName[1949:1971],
	_ErrorName[1971:1995],
	_ErrorName[1995:2027],
	_ErrorName[2027:2063],
	_ErrorName[2063:2087],
	_ErrorName[2087:2107],
	_ErrorName[2107:2133],
	_ErrorName[2133:2161],
	_ErrorName[2161:2198],
	_ErrorName[2198:2215],
	_ErrorName[2215:2246],
	_ErrorName[2246:2293],
	_ErrorName[2293:2316],
	_ErrorName[2316:2338],
	_ErrorName[2338:2377],
	_ErrorName[2377:2418],
	_ErrorName[2418:2444],
	_ErrorName[2444:2470],
	_ErrorName[2470:2499],
	_ErrorName[2499:2528],
	_ErrorName[2528:2560],
	_ErrorName[2560:2581],
	_ErrorName[2581:2600],
	_ErrorName[2600:2621],
	_ErrorName[2621:2638],
	_ErrorName[2638:2655],
	_ErrorName[2655:2674],
	_ErrorName[2674:2695],
	_ErrorName[2695:2719],
	_ErrorName[2719:2741],
	_ErrorName[2741:2760],
	_ErrorName[2760:2780],
	_ErrorName[2780:2795],
	_ErrorName[2795:2820],
	_ErrorName[2820:2834],
	_ErrorName[2834:2849],
	_ErrorName[2849:2897],
	_ErrorName[2897:2918],
	_ErrorName[2918:2938],
	_ErrorName[2938:2962],
	_ErrorName[2962:2986],
	_ErrorName[2986:3021],
	_ErrorName[3021:3043],
	_ErrorName[3043:3056],
	_ErrorName[3056:3076],
	_ErrorName[3076:3095],
	_ErrorName[3095:3122],
	_ErrorName[3122:3143],
	_ErrorName[3143:3176],
	_ErrorName[3176:3218],
	_ErrorName[3218:3268],
	_ErrorName[3268:3293],
	_ErrorName[3293:3318],
	_ErrorName[3318:3345],
	_ErrorName[3345:3366],
	_ErrorName[3366:3399],
	_ErrorName[3399:3421],
	_ErrorName[3421:3435],
	_ErrorName[3435:3459],
	_ErrorName[3459:3494],
	_ErrorName[3494:3515],
	_ErrorName[3515:3546],
	_ErrorName[3546:3586],
	_ErrorName[3586:3626],
	_ErrorName[3626:3661],
	_ErrorName[3661:3681],
	_ErrorName[3681:3727],
	_ErrorName[3727:3755],
	_ErrorName[3755:3771],
	_ErrorName[3771:3804],
	_ErrorName[3804:3820],
	_ErrorName[3820:3847],
	_ErrorName[3847:3868],
	_ErrorName[3868:3881],
	_ErrorName[3881:3897],
	_ErrorName[3897:3905],
	_ErrorName[3905:3921],
	_ErrorName[3921:3940],
	_ErrorName[3940:3957],
	_ErrorName[3957:3965],
	_ErrorName[3965:3991],
	_ErrorName[3991:4027],
	_ErrorName[4027:4039],
	_ErrorName[4039:4050],
	_ErrorName[4050:4067],
	_ErrorName[4067:4074],
	_ErrorName[4074:4105],
	_ErrorName[4105:4128],
	_ErrorName[4128:4150],
	_ErrorName[4150:4164],
	_ErrorName[4164:4179],
	_ErrorName[4179:4199],
	_ErrorName[4199:4230],
	_ErrorName[4230:4260],
	_ErrorName[4260:4279],
	_ErrorName[4279:4292],
	_ErrorName[4292:4308],
	_ErrorName[4308:4329],
	_ErrorName[4329:4348],
	_ErrorName[4348:4377],
	_ErrorName[4377:4405],
	_ErrorName[4405:4432],
	_ErrorName[4432:4446],
	_ErrorName[4446:4480],
	_ErrorName[4480:4506],
	_ErrorName[4506:4529],
	_ErrorName[4529:4541],
	_ErrorName[4541:4555],
	_ErrorName[4555:4572],
	_ErrorName[4572:4594],
	_ErrorName[4594:4622],
	_ErrorName[4622:4648],
	_ErrorName[4648:4657],
	_ErrorName[4657:4670],
	_ErrorName[4670:4693],
	_ErrorName[4693:4706],
	_ErrorName[4706:4735],
	_ErrorName[4735:4753],
	_ErrorName[4753:4765],
	_ErrorName[4765:4785],
	_ErrorName[4785:4799],
	_ErrorName[4799:4819],
	_ErrorName[4819:4837],
	_ErrorName[4837:4851],
	_ErrorName[4851:4864],
	_ErrorName[4864:4875],
	_ErrorName[4875:4897],
	_ErrorName[4897:4916],
	_ErrorName[4916:4930],
	_ErrorName[4930:4946],
	_ErrorName[4946:4983],
	_ErrorName[4983:5017],
	_ErrorName[5017:5033],
	_ErrorName[5033:5051],
	_ErrorName[5051:5084],
	_ErrorName[5084:5115],
	_ErrorName[5115:5148],
	_ErrorName[5148:5172],
	_ErrorName[5172:5197],
	_ErrorName[5197:5209],
	_ErrorName[5209:5229],
	_ErrorName[5229:5257],
	_ErrorName[5257:5286],
	_ErrorName[5286:5304],
	_ErrorName[5304:5332],
	_ErrorName[5332:5362],
	_ErrorName[5362:5379],
	_ErrorName[5379:5397],
	_ErrorName[5397:5416],
	_ErrorName[5416:5435],
	_ErrorName[5435:5442],
	_ErrorName[5442:5463],
	_ErrorName[5463:5485],
	_ErrorName[5485:5498],
	_ErrorName[5498:5511],
	_ErrorName[5511:5532],
	_ErrorName[5532:5550],
	_ErrorName[5550:5566],
	_ErrorName[5566:5592],
	_ErrorName[5592:5606],
	_ErrorName[5606:5620],
	_ErrorName[5620:5643],
	_ErrorName[5643:5667],
	_ErrorName[5667:5682],
	_ErrorName[5682:5696],
	_ErrorName[5696:5720],
	_ErrorName[5720:5738],
	_ErrorName[5738:5769],
	_ErrorName[5769:5793],
	_ErrorName[5793:5815],
	_ErrorName[5815:5851],
	_ErrorName[5851:5881],
	_ErrorName[5881:5905],
	_ErrorName[5905:5918],
	_ErrorName[5918:5937],
	_ErrorName[5937:5962],
	_ErrorName[5962:5982],
	_ErrorName[5982:6012],
	_ErrorName[6012:6052],
	_ErrorName[6052:6063],
	_ErrorName[6063:6076],
	_ErrorName[6076:6091],
	_ErrorName[6091:6108],
	_ErrorName[6108:6124],
	_ErrorName[6124:6143],
	_ErrorName[6143:6157],
	_ErrorName[6157:6172],
	_ErrorName[6172:6186],
	_ErrorName[6186:6201],
	_ErrorName[6201:6228],
	_ErrorName[6228:6245],
	_ErrorName[6245:6264],
	_ErrorName[6264:6279],
	_ErrorName[6279:6311],
	_ErrorName[6311:6332],
	_ErrorName[6332:6353],
	_ErrorName[6353:6390],
	_ErrorName[6390:6412],
	_ErrorName[6412:6447],
	_ErrorName[6447:6471],
	_ErrorName[6471:6485],
	_ErrorName[6485:6507],
	_ErrorName[6507:6525],
	_ErrorName[6525:6552],
	_ErrorName[6552:6572],
	_ErrorName[6572:6591],
	_ErrorName[6591:6612],
	_ErrorName[6612:6636],
	_ErrorName[6636:6647],
	_ErrorName[6647:6658],
	_ErrorName[6658:6670],
	_ErrorName[6670:6697],
	_ErrorName[6697:6726],
	_ErrorName[6726:6739],
	_ErrorName[6739:6753],
	_ErrorName[6753:6774],
	_ErrorName[6774:6792],
	_ErrorName[6792:6806],
	_ErrorName[6806:6834],
	_ErrorName[6834:6865],
	_ErrorName[6865:6885],
	_ErrorName[6885:6909],
	_ErrorName[6909:6933],
	_ErrorName[6933:6967],
	_ErrorName[6967:6982],
	_ErrorName[6982:7005],
	_ErrorName[7005:7024],
	_ErrorName[7024:7034],
	_ErrorName[7034:7051],
	_ErrorName[7051:7070],
	_ErrorName[7070:7092],
	_ErrorName[7092:7114],
	_ErrorName[7114:7132],
	_ErrorName[7132:7169],
	_ErrorName[7169:7195],
	_ErrorName[7195:7215],
	_ErrorName[7215:7236],
	_ErrorName[7236:7280],
	_ErrorName[7280:7299],
	_ErrorName[7299:7318],
	_ErrorName[7318:7328],
	_ErrorName[7328:7352],
	_ErrorName[7352:7376],
	_ErrorName[7376:7414],
	_ErrorName[7414:7445],
	_ErrorName[7445:7471],
	_ErrorName[7471:7504],
	_ErrorName[7504:7527],
	_ErrorName[7527:7559],
	_ErrorName[7559:7579],
	_ErrorName[7579:7619],
	_ErrorName[7619:7635],
	_ErrorName[7635:7643],
	_ErrorName[7643:7665],
	_ErrorName[7665:7699],
	_ErrorName[7699:7730],
	_ErrorName[7730:7747],
	_ErrorName[7747:7764],
	_ErrorName[7764:7787],
	_ErrorName[7787:7800],
	_ErrorName[7800:7817],
	_ErrorName[7817:7845],
	_ErrorName[7845:7876],
	_ErrorName[7876:7914],
	_ErrorName[7914:7925],
	_ErrorName[7925:7945],
	_ErrorName[7945:7971],
	_ErrorName[7971:7998],
	_ErrorName[7998:8024],
	_ErrorName[8024:8049],
	_ErrorName[8049:8063],
	_ErrorName[8063:8095],
	_ErrorName[8095:8117],
	_ErrorName[8117:8140],
	_ErrorName[8140:8169],
	_ErrorName[8169:8191],
	_ErrorName[8191:8210],
	_ErrorName[8210:8227],
	_ErrorName[8227:8246],
	_ErrorName[8246:8281],
	_ErrorName[8281:8303],
	_ErrorName[8303:8346],
	_ErrorName[8346:8370],
	_ErrorName[8370:8403],
	_ErrorName[8403:8414],
	_ErrorName[8414:8450],
	_ErrorName[8450:8464],
	_ErrorName[8464:8490],
	_ErrorName[8490:8516],
	_ErrorName[8516:8538],
	_ErrorName[8538:8554],
	_ErrorName[8554:8575],
	_ErrorName[8575:8608],
	_ErrorName[8608:8621],
	_ErrorName[8621:8634],
	_ErrorName[8634:8659],
	_ErrorName[8659:8676],
	_ErrorName[8676:8698],
	_ErrorName[8698:8717],
	_ErrorName[8717:8729],
	_ErrorName[8729:8759],
	_ErrorName[8759:8779],
	_ErrorName[8779:8816],
	_ErrorName[8816:8838],
	_ErrorName[8838:8857],
	_ErrorName[8857:8868],
	_ErrorName[8868:8880],
	_ErrorName[8880:8901],
	_ErrorName[8901:8919],
	_ErrorName[8919:8957],
	_ErrorName[8957:8986],
	_ErrorName[8986:8999],
	_ErrorName[8999:9022],
	_ErrorName[9022:9050],
	_ErrorName[9050:9097],
	_ErrorName[9097:9114],
	_ErrorName[9114:9141],
	_ErrorName[9141:9169],
	_ErrorName[9169:9189],
	_ErrorName[9189:9213],
	_ErrorName[9213:9250],
	_ErrorName[9250:9282],
	_ErrorName[9282:9322],
	_ErrorName[9322:9345],
	_ErrorName[9345:9360],
	_ErrorName[9360:9380],
	_ErrorName[9380:9406],
	_ErrorName[9406:9424],
	_ErrorName[9424:9443],
	_ErrorName[9443:9461],
	_ErrorName[9461:9473],
	_ErrorName[9473:9501],
	_ErrorName[9501:9539],
	_ErrorName[9539:9552],
	_ErrorName[9552:9587],
	_ErrorName[9587:9610],
	_ErrorName[9610:9629],
	_ErrorName[9629:9642],
	_ErrorName[9642:9668],
	_ErrorName[9668:9687],
	_ErrorName[9687:9710],
	_ErrorName[9710:9722],
	_ErrorName[9722:9738],
	_ErrorName[9738:9756],
	_ErrorName[9756:9769],
	_ErrorName[9769:9786],
	_ErrorName[9786:9805],
	_ErrorName[9805:9824],
	_ErrorName[9824:9845],
	_ErrorName[9845:9861],
	_ErrorName[9861:9877],
	_ErrorName[9877:9900],
	_ErrorName[9900:9928],
	_ErrorName[9928:9954],
	_ErrorName[9954:9976],
	_ErrorName[9976:9990],
	_ErrorName[9990:10002],
	_ErrorName[10002:10018],
	_ErrorName[10018:10036],
	_ErrorName[10036:10060],
	_ErrorName[10060:10078],
	_ErrorName[10078:10098],
	_ErrorName[10098:10132],
	_ErrorName[10132:10163],
	_ErrorName[10163:10185],
	_ErrorName[10185:10201],
	_ErrorName[10201:10224],
	_ErrorName[10224:10252],
	_ErrorName[10252:10275],
	_ErrorName[10275:10300],
	_ErrorName[10300:10313],
	_ErrorName[10313:10348],
	_ErrorName[10348:10356],
	_ErrorName[10356:10380],
	_ErrorName[10380:10402],
	_ErrorName[10402:10417],
	_ErrorName[10417:10441],
	_ErrorName[10441:10460],
	_ErrorName[10460:10488],
	_ErrorName[10488:10507],
	_ErrorName[10507:10520],
	_ErrorName[10520:10548],
	_ErrorName[10548:10560],
	_ErrorName[10560:10580],
	_ErrorName[10580:10597],
	_ErrorName[10597:10635],
	_ErrorName[10635:10669],
	_ErrorName[10669:10690],
	_ErrorName[10690:10709],
	_ErrorName[10709:10729],
	_ErrorName[10729:10754],
	_ErrorName[10754:10787],
	_ErrorName[10787:10805],
	_ErrorName[10805:10823],
	_ErrorName[10823:10851],
	_ErrorName[10851:10871],
	_ErrorName[10871:10906],
	_ErrorName[10906:10930],
	_ErrorName[10930:10942],
	_ErrorName[10942:10965],
	_ErrorName[10965:10977],
	_ErrorName[10977:10987],
	_ErrorName[10987:11004],
	_ErrorName[11004:11034],
	_ErrorName[11034:11056],
	_ErrorName[11056:11074],
	_ErrorName[11074:11103],
	_ErrorName[11103:11135],
	_ErrorName[11135:11171],
	_ErrorName[11171:11202],
	_ErrorName[11202:11239],
	_ErrorName[11239:11260],
	_ErrorName[11260:11283],
	_ErrorName[11283:11299],
	_ErrorName[11299:11316],
	_ErrorName[11316:11330],
	_ErrorName[11330:11361],
	_ErrorName[11361:11383],
	_ErrorName[11383:11409],
	_ErrorName[11409:11435],
	_ErrorName[11435:11448],
	_ErrorName[11448:11476],
	_ErrorName[11476:11489],
	_ErrorName[11489:11513],
	_ErrorName[11513:11536],
	_ErrorName[11536:11555],
	_ErrorName[11555:11574],
	_ErrorName[11574:11592],
	_ErrorName[11592:11617],
	_ErrorName[11617:11648],
	_ErrorName[11648:11667],
	_ErrorName[11667:11679],
	_ErrorName[11679:11700],
	_ErrorName[11700:11710],
	_ErrorName[11710:11760],
	_ErrorName[11760:11802],
	_ErrorName[11802:11829],
	_ErrorName[11829:11862],
	_ErrorName[11862:11873],
	_ErrorName[11873:11907],
	_ErrorName[11907:11923],
	_ErrorName[11923:11937],
	_ErrorName[11937:11953],
	_ErrorName[11953:11990],
	_ErrorName[11990:12009],
	_ErrorName[12009:12033],
	_ErrorName[12033:12060],
	_ErrorName[12060:12087],
	_ErrorName[12087:12105],
	_ErrorName[12105:12124],
	_ErrorName[12124:12141],
	_ErrorName[12141:12159],
	_ErrorName[12159:12190],
	_ErrorName[12190:12219],
	_ErrorName[12219:12249],
	_ErrorName[12249:12263],
	_ErrorName[12263:12282],
	_ErrorName[12282:12303],
	_ErrorName[12303:12330],
	_ErrorName[12330:12357],
	_ErrorName[12357:12384],
	_ErrorName[12384:12430],
	_ErrorName[12430:12448],
	_ErrorName[12448:12469],
	_ErrorName[12469:12485],
	_ErrorName[12485:12513],
	_ErrorName[12513:12527],
	_ErrorName[12527:12541],
	_ErrorName[12541:12558],
	_ErrorName[12558:12585],
	_ErrorName[12585:12607],
	_ErrorName[12607:12622],
	_ErrorName[12622:12645],
	_ErrorName[12645:12665],
	_ErrorName[12665:12688],
	_ErrorName[12688:12708],
	_ErrorName[12708:12740],
	_ErrorName[12740:12769],
	_ErrorName[12769:12782],
	_ErrorName[12782:12801],
	_ErrorName[12801:12819],
	_ErrorName[12819:12837],
	_ErrorName[12837:12874],
	_ErrorName[12874:12891],
	_ErrorName[12891:12914],
	_ErrorName[12914:12944],
	_ErrorName[12944:12963],
	_ErrorName[12963:12976],
	_ErrorName[12976:12990],
	_ErrorName[12990:13015],
	_ErrorName[13015:13038],
	_ErrorName[13038:13067],
	_ErrorName[13067:13093],
	_ErrorName[13093:13115],
	_ErrorName[13115:13132],
	_ErrorName[13132:13166],
	_ErrorName[13166:13203],
	_ErrorName[13203:13216],
	_ErrorName[13216:13227],
	_ErrorName[13227:13257],
	_ErrorName[13257:13279],
	_ErrorName[13279:13303],
	_ErrorName[13303:13325],
	_ErrorName[13325:13341],
	_ErrorName[13341:13362],
	_ErrorName[13362:13381],
	_ErrorName[13381:13402],
	_ErrorName[13402:13433],
	_ErrorName[13433:13452],
	_ErrorName[13452:13479],
	_ErrorName[13479:13498],
	_ErrorName[13498:13517],
	_ErrorName[13517:13536],
	_ErrorName[13536:13567],
	_ErrorName[13567:13595],
	_ErrorName[13595:13616],
	_ErrorName[13616:13648],
	_ErrorName[13648:13677],
	_ErrorName[13677:13687],
	_ErrorName[13687:13705],
	_ErrorName[13705:13722],
	_ErrorName[13722:13754],
	_ErrorName[13754:13788],
	_ErrorName[13788:13807],
	_ErrorName[13807:13822],
	_ErrorName[13822:13835],
	_ErrorName[13835:13864],
	_ErrorName[13864:13895],
	_ErrorName[13895:13924],
	_ErrorName[13924:13946],
	_ErrorName[13946:13968],
	_ErrorName[13968:13986],
	_ErrorName[13986:14003],
	_ErrorName[14003:14020],
	_ErrorName[14020:14039],
	_ErrorName[14039:14059],
	_ErrorName[14059:14080],
	_ErrorName[14080:14108],
	_ErrorName[14108:14131],
	_ErrorName[14131:14149],
	_ErrorName[14149:14158],
	_ErrorName[14158:14174],
	_ErrorName[14174:14191],
	_ErrorName[14191:14210],
	_ErrorName[14210:14245],
	_ErrorName[14245:14271],
	_ErrorName[14271:14300],
	_ErrorName[14300:14327],
	_ErrorName[14327:14347],
	_ErrorName[14347:14373],
	_ErrorName[14373:14391],
	_ErrorName[14391:14439],
	_ErrorName[14439:14454],
	_ErrorName[14454:14466],
	_ErrorName[14466:14475],
	_ErrorName[14475:14493],
	_ErrorName[14493:14532],
	_ErrorName[14532:14546],
	_ErrorName[14546:14569],
	_ErrorName[14569:14596],
	_ErrorName[14596:14613],
	_ErrorName[14613:14631],
	_ErrorName[14631:14651],
	_ErrorName[14651:14674],
	_ErrorName[14674:14700],
	_ErrorName[14700:14716],
	_ErrorName[14716:14750],
	_ErrorName[14750:14762],
	_ErrorName[14762:14781],
	_ErrorName[14781:14803],
	_ErrorName[14803:14820],
	_ErrorName[14820:14835],
	_ErrorName[14835:14853],
	_ErrorName[14853:14876],
	_ErrorName[14876:14899],
	_ErrorName[14899:14919],
	_ErrorName[14919:14943],
	_ErrorName[14943:14957],
	_ErrorName[14957:15002],
	_ErrorName[15002:15026],
	_ErrorName[15026:15060],
	_ErrorName[15060:15089],
	_ErrorName[15089:15112],
	_ErrorName[15112:15130],
	_ErrorName[15130:15144],
	_ErrorName[15144:15153],
	_ErrorName[15153:15181],
	_ErrorName[15181:15200],
	_ErrorName[15200:15218],
	_ErrorName[15218:15249],
	_ErrorName[15249:15265],
	_ErrorName[15265:15282],
	_ErrorName[15282:15304],
	_ErrorName[15304:15362],
	_ErrorName[15362:15385],
	_ErrorName[15385:15413],
	_ErrorName[15413:15438],
	_ErrorName[15438:15453],
	_ErrorName[15453:15469],
	_ErrorName[15469:15483],
	_ErrorName[15483:15496],
	_ErrorName[15496:15513],
	_ErrorName[15513:15526],
	_ErrorName[15526:15547],
	_ErrorName[15547:15580],
	_ErrorName[15580:15610],
}

// ErrorString retrieves an enum value from the enum constants string name.
// Throws an error if the param is not part of the enum.
func ErrorString(s string) (Error, error) {
	if val, ok := _ErrorNameToValueMap[s]; ok {
		return val, nil
	}

	if val, ok := _ErrorNameToValueMap[strings.ToLower(s)]; ok {
		return val, nil
	}
	return 0, fmt.Errorf("%s does not belong to Error values", s)
}

// ErrorValues returns all values of the enum
func ErrorValues() []Error {
	return _ErrorValues
}

// ErrorStrings returns a slice of all String values of the enum
func ErrorStrings() []string {
	strs := make([]string, len(_ErrorNames))
	copy(strs, _ErrorNames)
	return strs
}

// IsAError returns "true" if the value is listed in the enum definition. "false" otherwise
func (i Error) IsAError() bool {
	_, ok := _ErrorMap[i]
	return ok
}
